Class: Google::Apis::DfareportingV4::AdSlot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Ad Slot

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdSlot

Returns a new instance of AdSlot.



931
932
933
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentString

Comment for this ad slot. Corresponds to the JSON property comment

Returns:

  • (String)


889
890
891
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 889

def comment
  @comment
end

#compatibilityString

Ad slot compatibility. DISPLAY and DISPLAY_INTERSTITIAL refer to rendering either on desktop, mobile devices or in mobile apps for regular or interstitial ads respectively. APP and APP_INTERSTITIAL are for rendering in mobile apps. IN_STREAM_VIDEO refers to rendering in in-stream video ads developed with the VAST standard. Corresponds to the JSON property compatibility

Returns:

  • (String)


898
899
900
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 898

def compatibility
  @compatibility
end

#heightFixnum

Height of this ad slot. Corresponds to the JSON property height

Returns:

  • (Fixnum)


903
904
905
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 903

def height
  @height
end

#linked_placement_idFixnum

ID of the placement from an external platform that is linked to this ad slot. Corresponds to the JSON property linkedPlacementId

Returns:

  • (Fixnum)


908
909
910
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 908

def linked_placement_id
  @linked_placement_id
end

#nameString

Name of this ad slot. Corresponds to the JSON property name

Returns:

  • (String)


913
914
915
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 913

def name
  @name
end

#payment_source_typeString

Payment source type of this ad slot. Corresponds to the JSON property paymentSourceType

Returns:

  • (String)


918
919
920
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 918

def payment_source_type
  @payment_source_type
end

#primaryBoolean Also known as: primary?

Primary ad slot of a roadblock inventory item. Corresponds to the JSON property primary

Returns:

  • (Boolean)


923
924
925
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 923

def primary
  @primary
end

#widthFixnum

Width of this ad slot. Corresponds to the JSON property width

Returns:

  • (Fixnum)


929
930
931
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 929

def width
  @width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



936
937
938
939
940
941
942
943
944
945
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 936

def update!(**args)
  @comment = args[:comment] if args.key?(:comment)
  @compatibility = args[:compatibility] if args.key?(:compatibility)
  @height = args[:height] if args.key?(:height)
  @linked_placement_id = args[:linked_placement_id] if args.key?(:linked_placement_id)
  @name = args[:name] if args.key?(:name)
  @payment_source_type = args[:payment_source_type] if args.key?(:payment_source_type)
  @primary = args[:primary] if args.key?(:primary)
  @width = args[:width] if args.key?(:width)
end