Class: Google::Apis::DfareportingV4::AdvertisersListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::AdvertisersListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Advertiser List Response
Instance Attribute Summary collapse
-
#advertisers ⇒ Array<Google::Apis::DfareportingV4::Advertiser>
Advertiser collection.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdvertisersListResponse
constructor
A new instance of AdvertisersListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdvertisersListResponse
Returns a new instance of AdvertisersListResponse.
1272 1273 1274 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertisers ⇒ Array<Google::Apis::DfareportingV4::Advertiser>
Advertiser collection.
Corresponds to the JSON property advertisers
1259 1260 1261 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1259 def advertisers @advertisers end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#advertisersListResponse".
Corresponds to the JSON property kind
1265 1266 1267 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1265 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
1270 1271 1272 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1270 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1277 1278 1279 1280 1281 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1277 def update!(**args) @advertisers = args[:advertisers] if args.key?(:advertisers) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |