Class: Google::Apis::DfareportingV4::BillingProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains properties of a Campaign Manager Billing Profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BillingProfile

Returns a new instance of BillingProfile.



1508
1509
1510
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consolidated_invoiceBoolean Also known as: consolidated_invoice?

Consolidated invoice option for this billing profile. Used to get a single, consolidated invoice across the chosen invoice level. Corresponds to the JSON property consolidatedInvoice

Returns:

  • (Boolean)


1435
1436
1437
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1435

def consolidated_invoice
  @consolidated_invoice
end

#country_codeString

Country code of this billing profile.This is a read-only field. Corresponds to the JSON property countryCode

Returns:

  • (String)


1441
1442
1443
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1441

def country_code
  @country_code
end

#currency_codeString

Billing currency code in ISO 4217 format.This is a read-only field. Corresponds to the JSON property currencyCode

Returns:

  • (String)


1446
1447
1448
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1446

def currency_code
  @currency_code
end

#idFixnum

ID of this billing profile. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


1451
1452
1453
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1451

def id
  @id
end

#invoice_levelString

Invoice level for this billing profile. Used to group fees into separate invoices by account, advertiser, or campaign. Corresponds to the JSON property invoiceLevel

Returns:

  • (String)


1457
1458
1459
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1457

def invoice_level
  @invoice_level
end

#is_defaultBoolean Also known as: is_default?

True if the billing profile is the account default profile. This is a read- only field. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


1463
1464
1465
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1463

def is_default
  @is_default
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#billingProfile". Corresponds to the JSON property kind

Returns:

  • (String)


1470
1471
1472
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1470

def kind
  @kind
end

#nameString

Name of this billing profile. This is a required field and must be less than 256 characters long and must be unique among billing profile in the same account. Corresponds to the JSON property name

Returns:

  • (String)


1477
1478
1479
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1477

def name
  @name
end

#payments_account_idString

The ID of the payment account the billing profile belongs to. This is a read- only field. Corresponds to the JSON property paymentsAccountId

Returns:

  • (String)


1483
1484
1485
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1483

def 
  @payments_account_id
end

#payments_customer_idString

The ID of the payment customer the billing profile belongs to. This is a read- only field. Corresponds to the JSON property paymentsCustomerId

Returns:

  • (String)


1489
1490
1491
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1489

def payments_customer_id
  @payments_customer_id
end

#purchase_orderString

Purchase order (PO) for this billing profile. This PO number is used in the invoices for all of the advertisers in this billing profile. Corresponds to the JSON property purchaseOrder

Returns:

  • (String)


1495
1496
1497
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1495

def purchase_order
  @purchase_order
end

#secondary_payments_customer_idString

The ID of the secondary payment customer the billing profile belongs to. This is a read-only field. Corresponds to the JSON property secondaryPaymentsCustomerId

Returns:

  • (String)


1501
1502
1503
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1501

def secondary_payments_customer_id
  @secondary_payments_customer_id
end

#statusString

Status of this billing profile.This is a read-only field. Corresponds to the JSON property status

Returns:

  • (String)


1506
1507
1508
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1506

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1513

def update!(**args)
  @consolidated_invoice = args[:consolidated_invoice] if args.key?(:consolidated_invoice)
  @country_code = args[:country_code] if args.key?(:country_code)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @id = args[:id] if args.key?(:id)
  @invoice_level = args[:invoice_level] if args.key?(:invoice_level)
  @is_default = args[:is_default] if args.key?(:is_default)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id)
  @payments_customer_id = args[:payments_customer_id] if args.key?(:payments_customer_id)
  @purchase_order = args[:purchase_order] if args.key?(:purchase_order)
  @secondary_payments_customer_id = args[:secondary_payments_customer_id] if args.key?(:secondary_payments_customer_id)
  @status = args[:status] if args.key?(:status)
end