Class: Google::Apis::DfareportingV4::BillingRatesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::BillingRatesListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Billing Rate List Response
Instance Attribute Summary collapse
-
#billing_rates ⇒ Array<Google::Apis::DfareportingV4::BillingRate>
Billing rates collection.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BillingRatesListResponse
constructor
A new instance of BillingRatesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BillingRatesListResponse
Returns a new instance of BillingRatesListResponse.
1681 1682 1683 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_rates ⇒ Array<Google::Apis::DfareportingV4::BillingRate>
Billing rates collection.
Corresponds to the JSON property billingRates
1668 1669 1670 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1668 def billing_rates @billing_rates end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#billingRatesListResponse".
Corresponds to the JSON property kind
1674 1675 1676 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1674 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
1679 1680 1681 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1679 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1686 1687 1688 1689 1690 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1686 def update!(**args) @billing_rates = args[:billing_rates] if args.key?(:billing_rates) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |