Class: Google::Apis::DfareportingV4::Campaign

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains properties of a Campaign Manager campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Campaign

Returns a new instance of Campaign.



1937
1938
1939
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this campaign. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


1790
1791
1792
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1790

def 
  @account_id
end

#ad_blocking_configurationGoogle::Apis::DfareportingV4::AdBlockingConfiguration

Campaign ad blocking settings. Corresponds to the JSON property adBlockingConfiguration



1795
1796
1797
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1795

def ad_blocking_configuration
  @ad_blocking_configuration
end

#additional_creative_optimization_configurationsArray<Google::Apis::DfareportingV4::CreativeOptimizationConfiguration>

Additional creative optimization configurations for the campaign. Corresponds to the JSON property additionalCreativeOptimizationConfigurations



1800
1801
1802
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1800

def additional_creative_optimization_configurations
  @additional_creative_optimization_configurations
end

#advertiser_group_idFixnum

Advertiser group ID of the associated advertiser. Corresponds to the JSON property advertiserGroupId

Returns:

  • (Fixnum)


1805
1806
1807
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1805

def advertiser_group_id
  @advertiser_group_id
end

#advertiser_idFixnum

Advertiser ID of this campaign. This is a required field. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


1810
1811
1812
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1810

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



1815
1816
1817
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1815

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#archivedBoolean Also known as: archived?

Whether this campaign has been archived. Corresponds to the JSON property archived

Returns:

  • (Boolean)


1820
1821
1822
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1820

def archived
  @archived
end

#audience_segment_groupsArray<Google::Apis::DfareportingV4::AudienceSegmentGroup>

Audience segment groups assigned to this campaign. Cannot have more than 300 segment groups. Corresponds to the JSON property audienceSegmentGroups



1827
1828
1829
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1827

def audience_segment_groups
  @audience_segment_groups
end

#billing_invoice_codeString

Billing invoice code included in the Campaign Manager client billing invoices associated with the campaign. Corresponds to the JSON property billingInvoiceCode

Returns:

  • (String)


1833
1834
1835
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1833

def billing_invoice_code
  @billing_invoice_code
end

#click_through_url_suffix_propertiesGoogle::Apis::DfareportingV4::ClickThroughUrlSuffixProperties

Click Through URL Suffix settings. Corresponds to the JSON property clickThroughUrlSuffixProperties



1838
1839
1840
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1838

def click_through_url_suffix_properties
  @click_through_url_suffix_properties
end

#commentString

Arbitrary comments about this campaign. Must be less than 256 characters long. Corresponds to the JSON property comment

Returns:

  • (String)


1843
1844
1845
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1843

def comment
  @comment
end

#create_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



1848
1849
1850
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1848

def create_info
  @create_info
end

#creative_group_idsArray<Fixnum>

List of creative group IDs that are assigned to the campaign. Corresponds to the JSON property creativeGroupIds

Returns:

  • (Array<Fixnum>)


1853
1854
1855
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1853

def creative_group_ids
  @creative_group_ids
end

#creative_optimization_configurationGoogle::Apis::DfareportingV4::CreativeOptimizationConfiguration

Creative optimization settings. Corresponds to the JSON property creativeOptimizationConfiguration



1858
1859
1860
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1858

def creative_optimization_configuration
  @creative_optimization_configuration
end

#default_click_through_event_tag_propertiesGoogle::Apis::DfareportingV4::DefaultClickThroughEventTagProperties

Properties of inheriting and overriding the default click-through event tag. A campaign may override the event tag defined at the advertiser level, and an ad may also override the campaign's setting further. Corresponds to the JSON property defaultClickThroughEventTagProperties



1865
1866
1867
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1865

def default_click_through_event_tag_properties
  @default_click_through_event_tag_properties
end

#default_landing_page_idFixnum

The default landing page ID for this campaign. Corresponds to the JSON property defaultLandingPageId

Returns:

  • (Fixnum)


1870
1871
1872
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1870

def default_landing_page_id
  @default_landing_page_id
end

#end_dateDate

Corresponds to the JSON property endDate

Returns:

  • (Date)


1875
1876
1877
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1875

def end_date
  @end_date
end

#eu_political_ads_declarationString

Optional. Whether the campaign has EU political ads. Campaign Manager 360 doesn't allow campaigns with EU political ads to serve in the EU. They can still serve in other regions. Corresponds to the JSON property euPoliticalAdsDeclaration

Returns:

  • (String)


1882
1883
1884
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1882

def eu_political_ads_declaration
  @eu_political_ads_declaration
end

#event_tag_overridesArray<Google::Apis::DfareportingV4::EventTagOverride>

Overrides that can be used to activate or deactivate advertiser event tags. Corresponds to the JSON property eventTagOverrides



1887
1888
1889
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1887

def event_tag_overrides
  @event_tag_overrides
end

#external_idString

External ID for this campaign. Corresponds to the JSON property externalId

Returns:

  • (String)


1892
1893
1894
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1892

def external_id
  @external_id
end

#idFixnum

ID of this campaign. This is a read-only auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


1897
1898
1899
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1897

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



1902
1903
1904
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1902

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#campaign". Corresponds to the JSON property kind

Returns:

  • (String)


1908
1909
1910
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1908

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



1913
1914
1915
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1913

def last_modified_info
  @last_modified_info
end

Measurement partner campaign link for tag wrapping. Corresponds to the JSON property measurementPartnerLink



1918
1919
1920
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1918

def measurement_partner_link
  @measurement_partner_link
end

#nameString

Name of this campaign. This is a required field and must be less than 512 characters long and unique among campaigns of the same advertiser. Corresponds to the JSON property name

Returns:

  • (String)


1924
1925
1926
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1924

def name
  @name
end

#start_dateDate

Corresponds to the JSON property startDate

Returns:

  • (Date)


1929
1930
1931
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1929

def start_date
  @start_date
end

#subaccount_idFixnum

Subaccount ID of this campaign. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


1935
1936
1937
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1935

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 1942

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @ad_blocking_configuration = args[:ad_blocking_configuration] if args.key?(:ad_blocking_configuration)
  @additional_creative_optimization_configurations = args[:additional_creative_optimization_configurations] if args.key?(:additional_creative_optimization_configurations)
  @advertiser_group_id = args[:advertiser_group_id] if args.key?(:advertiser_group_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @archived = args[:archived] if args.key?(:archived)
  @audience_segment_groups = args[:audience_segment_groups] if args.key?(:audience_segment_groups)
  @billing_invoice_code = args[:billing_invoice_code] if args.key?(:billing_invoice_code)
  @click_through_url_suffix_properties = args[:click_through_url_suffix_properties] if args.key?(:click_through_url_suffix_properties)
  @comment = args[:comment] if args.key?(:comment)
  @create_info = args[:create_info] if args.key?(:create_info)
  @creative_group_ids = args[:creative_group_ids] if args.key?(:creative_group_ids)
  @creative_optimization_configuration = args[:creative_optimization_configuration] if args.key?(:creative_optimization_configuration)
  @default_click_through_event_tag_properties = args[:default_click_through_event_tag_properties] if args.key?(:default_click_through_event_tag_properties)
  @default_landing_page_id = args[:default_landing_page_id] if args.key?(:default_landing_page_id)
  @end_date = args[:end_date] if args.key?(:end_date)
  @eu_political_ads_declaration = args[:eu_political_ads_declaration] if args.key?(:eu_political_ads_declaration)
  @event_tag_overrides = args[:event_tag_overrides] if args.key?(:event_tag_overrides)
  @external_id = args[:external_id] if args.key?(:external_id)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @measurement_partner_link = args[:measurement_partner_link] if args.key?(:measurement_partner_link)
  @name = args[:name] if args.key?(:name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end