Class: Google::Apis::DfareportingV4::CampaignSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Represents a summarized campaign information associated with this invoice.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CampaignSummary

Returns a new instance of CampaignSummary.



2062
2063
2064
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_invoice_codeString

Campaign billing invoice code. Corresponds to the JSON property billingInvoiceCode

Returns:

  • (String)


2039
2040
2041
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2039

def billing_invoice_code
  @billing_invoice_code
end

#campaign_idFixnum

Campaign ID. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


2044
2045
2046
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2044

def campaign_id
  @campaign_id
end

#pre_tax_amount_microsFixnum

The pre-tax amount for this campaign, in micros of the invoice's currency. Corresponds to the JSON property preTaxAmountMicros

Returns:

  • (Fixnum)


2049
2050
2051
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2049

def pre_tax_amount_micros
  @pre_tax_amount_micros
end

#tax_amount_microsFixnum

The tax amount for this campaign, in micros of the invoice's currency. Corresponds to the JSON property taxAmountMicros

Returns:

  • (Fixnum)


2054
2055
2056
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2054

def tax_amount_micros
  @tax_amount_micros
end

#total_amount_microsFixnum

The total amount of charges for this campaign, in micros of the invoice's currency. Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


2060
2061
2062
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2060

def total_amount_micros
  @total_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2067
2068
2069
2070
2071
2072
2073
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2067

def update!(**args)
  @billing_invoice_code = args[:billing_invoice_code] if args.key?(:billing_invoice_code)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @pre_tax_amount_micros = args[:pre_tax_amount_micros] if args.key?(:pre_tax_amount_micros)
  @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
end