Class: Google::Apis::DfareportingV4::CartData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains additional information about cart data. This field may only be used when calling batchinsert; it is not supported by batchupdate. Cart data reporting is only supported in SA360. Learn more

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CartData

Returns a new instance of CartData.



2141
2142
2143
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::DfareportingV4::CartDataItem>

Data of the items purchased. Corresponds to the JSON property items



2118
2119
2120
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2118

def items
  @items
end

#merchant_feed_labelString

The feed labels associated with the feed where your items are uploaded. For more information, please refer to ​​ https://support.google.com/merchants/ answer/12453549. Providing the feed label reduces ambiguity in identifying the right offer details. Corresponds to the JSON property merchantFeedLabel

Returns:

  • (String)


2126
2127
2128
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2126

def merchant_feed_label
  @merchant_feed_label
end

#merchant_feed_languageString

The language associated with the feed where your items are uploaded. Use ISO 639-1 language codes. Providing the feed language reduces ambiguity in identifying the right offer details. Corresponds to the JSON property merchantFeedLanguage

Returns:

  • (String)


2133
2134
2135
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2133

def merchant_feed_language
  @merchant_feed_language
end

#merchant_idFixnum

The Merchant Center ID where the items are uploaded. Providing Merchant Center ID reduces ambiguity in identifying the right offer details. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


2139
2140
2141
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2139

def merchant_id
  @merchant_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2146
2147
2148
2149
2150
2151
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2146

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @merchant_feed_label = args[:merchant_feed_label] if args.key?(:merchant_feed_label)
  @merchant_feed_language = args[:merchant_feed_language] if args.key?(:merchant_feed_language)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
end