Class: Google::Apis::DfareportingV4::City

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains information about a city that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ City

Returns a new instance of City.



2397
2398
2399
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Country code of the country to which this city belongs. Corresponds to the JSON property countryCode

Returns:

  • (String)


2354
2355
2356
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2354

def country_code
  @country_code
end

#country_dart_idFixnum

DART ID of the country to which this city belongs. Corresponds to the JSON property countryDartId

Returns:

  • (Fixnum)


2359
2360
2361
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2359

def country_dart_id
  @country_dart_id
end

#dart_idFixnum

DART ID of this city. This is the ID used for targeting and generating reports. Corresponds to the JSON property dartId

Returns:

  • (Fixnum)


2364
2365
2366
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2364

def dart_id
  @dart_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#city". Corresponds to the JSON property kind

Returns:

  • (String)


2370
2371
2372
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2370

def kind
  @kind
end

#metro_codeString

Metro region code of the metro region (DMA) to which this city belongs. Corresponds to the JSON property metroCode

Returns:

  • (String)


2375
2376
2377
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2375

def metro_code
  @metro_code
end

#metro_dma_idFixnum

ID of the metro region (DMA) to which this city belongs. Corresponds to the JSON property metroDmaId

Returns:

  • (Fixnum)


2380
2381
2382
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2380

def metro_dma_id
  @metro_dma_id
end

#nameString

Name of this city. Corresponds to the JSON property name

Returns:

  • (String)


2385
2386
2387
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2385

def name
  @name
end

#region_codeString

Region code of the region to which this city belongs. Corresponds to the JSON property regionCode

Returns:

  • (String)


2390
2391
2392
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2390

def region_code
  @region_code
end

#region_dart_idFixnum

DART ID of the region to which this city belongs. Corresponds to the JSON property regionDartId

Returns:

  • (Fixnum)


2395
2396
2397
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2395

def region_dart_id
  @region_dart_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2402

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @country_dart_id = args[:country_dart_id] if args.key?(:country_dart_id)
  @dart_id = args[:dart_id] if args.key?(:dart_id)
  @kind = args[:kind] if args.key?(:kind)
  @metro_code = args[:metro_code] if args.key?(:metro_code)
  @metro_dma_id = args[:metro_dma_id] if args.key?(:metro_dma_id)
  @name = args[:name] if args.key?(:name)
  @region_code = args[:region_code] if args.key?(:region_code)
  @region_dart_id = args[:region_dart_id] if args.key?(:region_dart_id)
end