Class: Google::Apis::DfareportingV4::CompanionSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::CompanionSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Companion Settings
Instance Attribute Summary collapse
-
#companions_disabled ⇒ Boolean
(also: #companions_disabled?)
Whether companions are disabled for this placement.
-
#enabled_sizes ⇒ Array<Google::Apis::DfareportingV4::Size>
Allowlist of companion sizes to be served to this placement.
-
#image_only ⇒ Boolean
(also: #image_only?)
Whether to serve only static images as companions.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompanionSetting
constructor
A new instance of CompanionSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompanionSetting
Returns a new instance of CompanionSetting.
2576 2577 2578 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#companions_disabled ⇒ Boolean Also known as: companions_disabled?
Whether companions are disabled for this placement.
Corresponds to the JSON property companionsDisabled
2555 2556 2557 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2555 def companions_disabled @companions_disabled end |
#enabled_sizes ⇒ Array<Google::Apis::DfareportingV4::Size>
Allowlist of companion sizes to be served to this placement. Set this list to
null or empty to serve all companion sizes.
Corresponds to the JSON property enabledSizes
2562 2563 2564 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2562 def enabled_sizes @enabled_sizes end |
#image_only ⇒ Boolean Also known as: image_only?
Whether to serve only static images as companions.
Corresponds to the JSON property imageOnly
2567 2568 2569 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2567 def image_only @image_only end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#companionSetting".
Corresponds to the JSON property kind
2574 2575 2576 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2574 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2581 2582 2583 2584 2585 2586 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2581 def update!(**args) @companions_disabled = args[:companions_disabled] if args.key?(:companions_disabled) @enabled_sizes = args[:enabled_sizes] if args.key?(:enabled_sizes) @image_only = args[:image_only] if args.key?(:image_only) @kind = args[:kind] if args.key?(:kind) end |