Class: Google::Apis::DfareportingV4::CompatibleFields

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Represents a response to the queryCompatibleFields method. Next ID: 10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompatibleFields

Returns a new instance of CompatibleFields.



2634
2635
2636
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cross_dimension_reach_report_compatible_fieldsGoogle::Apis::DfareportingV4::CrossDimensionReachReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " CROSS_DIMENSION_REACH". Corresponds to the JSON property crossDimensionReachReportCompatibleFields



2597
2598
2599
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2597

def cross_dimension_reach_report_compatible_fields
  @cross_dimension_reach_report_compatible_fields
end

#cross_media_reach_report_compatible_fieldsGoogle::Apis::DfareportingV4::CrossMediaReachReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " CROSS_MEDIA_REACH". Corresponds to the JSON property crossMediaReachReportCompatibleFields



2603
2604
2605
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2603

def cross_media_reach_report_compatible_fields
  @cross_media_reach_report_compatible_fields
end

#floodlight_report_compatible_fieldsGoogle::Apis::DfareportingV4::FloodlightReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " FlOODLIGHT". Corresponds to the JSON property floodlightReportCompatibleFields



2609
2610
2611
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2609

def floodlight_report_compatible_fields
  @floodlight_report_compatible_fields
end

#kindString

The kind of resource this is, in this case dfareporting#compatibleFields. Corresponds to the JSON property kind

Returns:

  • (String)


2614
2615
2616
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2614

def kind
  @kind
end

#path_to_conversion_report_compatible_fieldsGoogle::Apis::DfareportingV4::PathToConversionReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " PATH_TO_CONVERSION". Corresponds to the JSON property pathToConversionReportCompatibleFields



2620
2621
2622
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2620

def path_to_conversion_report_compatible_fields
  @path_to_conversion_report_compatible_fields
end

#reach_report_compatible_fieldsGoogle::Apis::DfareportingV4::ReachReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " REACH". Corresponds to the JSON property reachReportCompatibleFields



2626
2627
2628
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2626

def reach_report_compatible_fields
  @reach_report_compatible_fields
end

#report_compatible_fieldsGoogle::Apis::DfareportingV4::ReportCompatibleFields

Represents fields that are compatible to be selected for a report of type " STANDARD". Corresponds to the JSON property reportCompatibleFields



2632
2633
2634
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2632

def report_compatible_fields
  @report_compatible_fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2639
2640
2641
2642
2643
2644
2645
2646
2647
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2639

def update!(**args)
  @cross_dimension_reach_report_compatible_fields = args[:cross_dimension_reach_report_compatible_fields] if args.key?(:cross_dimension_reach_report_compatible_fields)
  @cross_media_reach_report_compatible_fields = args[:cross_media_reach_report_compatible_fields] if args.key?(:cross_media_reach_report_compatible_fields)
  @floodlight_report_compatible_fields = args[:floodlight_report_compatible_fields] if args.key?(:floodlight_report_compatible_fields)
  @kind = args[:kind] if args.key?(:kind)
  @path_to_conversion_report_compatible_fields = args[:path_to_conversion_report_compatible_fields] if args.key?(:path_to_conversion_report_compatible_fields)
  @reach_report_compatible_fields = args[:reach_report_compatible_fields] if args.key?(:reach_report_compatible_fields)
  @report_compatible_fields = args[:report_compatible_fields] if args.key?(:report_compatible_fields)
end