Class: Google::Apis::DfareportingV4::ContentSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains the content source of the dynamic feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentSource

Returns a new instance of ContentSource.



2816
2817
2818
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_source_nameString

Optional. The name of the content source. It is defaulted to content source file name if not provided. Corresponds to the JSON property contentSourceName

Returns:

  • (String)


2789
2790
2791
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2789

def content_source_name
  @content_source_name
end

#create_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



2794
2795
2796
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2794

def create_info
  @create_info
end

#last_modified_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



2799
2800
2801
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2799

def last_modified_info
  @last_modified_info
end

#meta_dataGoogle::Apis::DfareportingV4::ContentSourceMetaData

Contains the meta data of the content source. This is a read-only field. Corresponds to the JSON property metaData



2804
2805
2806
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2804

def 
  @meta_data
end

Required. The link to the file of the content source. Corresponds to the JSON property resourceLink

Returns:

  • (String)


2809
2810
2811
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2809

def resource_link
  @resource_link
end

#resource_typeString

Required. The resource type of the content source. Corresponds to the JSON property resourceType

Returns:

  • (String)


2814
2815
2816
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2814

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2821
2822
2823
2824
2825
2826
2827
2828
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2821

def update!(**args)
  @content_source_name = args[:content_source_name] if args.key?(:content_source_name)
  @create_info = args[:create_info] if args.key?(:create_info)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @meta_data = args[:meta_data] if args.key?(:meta_data)
  @resource_link = args[:resource_link] if args.key?(:resource_link)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end