Class: Google::Apis::DfareportingV4::Conversion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

A Conversion represents when a user successfully performs a desired action after seeing an ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Conversion

Returns a new instance of Conversion.



3071
3072
3073
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

This represents consent for ad user data. Corresponds to the JSON property adUserDataConsent

Returns:

  • (String)


2914
2915
2916
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2914

def ad_user_data_consent
  @ad_user_data_consent
end

#cart_dataGoogle::Apis::DfareportingV4::CartData

Contains additional information about cart data. This field may only be used when calling batchinsert; it is not supported by batchupdate. Cart data reporting is only supported in SA360. Learn more Corresponds to the JSON property cartData



2922
2923
2924
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2922

def cart_data
  @cart_data
end

#child_directed_treatmentBoolean Also known as: child_directed_treatment?

Whether this particular request may come from a user under the age of 13, under COPPA compliance. Corresponds to the JSON property childDirectedTreatment

Returns:

  • (Boolean)


2928
2929
2930
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2928

def child_directed_treatment
  @child_directed_treatment
end

#custom_variablesArray<Google::Apis::DfareportingV4::CustomFloodlightVariable>

Custom floodlight variables. Corresponds to the JSON property customVariables



2934
2935
2936
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2934

def custom_variables
  @custom_variables
end

#dclidString

The display click ID. This field is mutually exclusive with encryptedUserId, encryptedUserIdCandidates[], matchId, mobileDeviceId, gclid, and impressionId. This or encryptedUserId or encryptedUserIdCandidates[] or matchId or mobileDeviceId or gclid or impressionId is a required field. Corresponds to the JSON property dclid

Returns:

  • (String)


2942
2943
2944
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2942

def dclid
  @dclid
end

#encrypted_user_idString

The alphanumeric encrypted user ID. When set, encryptionInfo should also be specified. This field is mutually exclusive with encryptedUserIdCandidates[], matchId, mobileDeviceId, gclid, dclid, and impressionId. This or encryptedUserIdCandidates[] or matchId or mobileDeviceId or gclid or dclid or impressionId is a required field. Corresponds to the JSON property encryptedUserId

Returns:

  • (String)


2951
2952
2953
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2951

def encrypted_user_id
  @encrypted_user_id
end

#encrypted_user_id_candidatesArray<String>

A list of the alphanumeric encrypted user IDs. Any user ID with exposure prior to the conversion timestamp will be used in the inserted conversion. If no such user ID is found then the conversion will be rejected with INVALID_ARGUMENT error. When set, encryptionInfo should also be specified. This field may only be used when calling batchinsert; it is not supported by batchupdate. This field is mutually exclusive with encryptedUserId, matchId, mobileDeviceId, gclid dclid, and impressionId. This or encryptedUserId or matchId or mobileDeviceId or gclid or dclid or impressionId is a required field. Corresponds to the JSON property encryptedUserIdCandidates

Returns:

  • (Array<String>)


2964
2965
2966
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2964

def encrypted_user_id_candidates
  @encrypted_user_id_candidates
end

#floodlight_activity_idFixnum

Floodlight Activity ID of this conversion. This is a required field. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


2969
2970
2971
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2969

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_configuration_idFixnum

Floodlight Configuration ID of this conversion. This is a required field. Corresponds to the JSON property floodlightConfigurationId

Returns:

  • (Fixnum)


2974
2975
2976
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2974

def floodlight_configuration_id
  @floodlight_configuration_id
end

#gclidString

The Google click ID. This field is mutually exclusive with encryptedUserId, encryptedUserIdCandidates[], matchId, mobileDeviceId, dclid, and impressionId. This or encryptedUserId or encryptedUserIdCandidates[] or matchId or mobileDeviceId or dclid or impressionId is a required field. Corresponds to the JSON property gclid

Returns:

  • (String)


2982
2983
2984
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2982

def gclid
  @gclid
end

#impression_idString

The impression ID. This field is mutually exclusive with encryptedUserId, encryptedUserIdCandidates[], matchId, mobileDeviceId, and gclid. One of these identifiers must be set. Corresponds to the JSON property impressionId

Returns:

  • (String)


2989
2990
2991
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2989

def impression_id
  @impression_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#conversion". Corresponds to the JSON property kind

Returns:

  • (String)


2995
2996
2997
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2995

def kind
  @kind
end

#limit_ad_trackingBoolean Also known as: limit_ad_tracking?

Whether Limit Ad Tracking is enabled. When set to true, the conversion will be used for reporting but not targeting. This will prevent remarketing. Corresponds to the JSON property limitAdTracking

Returns:

  • (Boolean)


3001
3002
3003
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3001

def limit_ad_tracking
  @limit_ad_tracking
end

#match_idString

The match ID field. A match ID is your own first-party identifier that has been synced with Google using the match ID feature in Floodlight. This field is mutually exclusive with encryptedUserId, encryptedUserIdCandidates[], mobileDeviceId, gclid, dclid, and impressionId. This or encryptedUserId orencryptedUserIdCandidates[] or mobileDeviceId or gclid or dclid or impressionIdis a required field. Corresponds to the JSON property matchId

Returns:

  • (String)


3012
3013
3014
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3012

def match_id
  @match_id
end

#mobile_device_idString

The mobile device ID. This field is mutually exclusive with encryptedUserId, encryptedUserIdCandidates[], matchId, gclid, dclid, and impressionId. This or encryptedUserId or encryptedUserIdCandidates[] or matchId or gclid or dclid or impressionId is a required field. Corresponds to the JSON property mobileDeviceId

Returns:

  • (String)


3020
3021
3022
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3020

def mobile_device_id
  @mobile_device_id
end

#non_personalized_adBoolean Also known as: non_personalized_ad?

Whether the conversion was for a non personalized ad. Corresponds to the JSON property nonPersonalizedAd

Returns:

  • (Boolean)


3025
3026
3027
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3025

def non_personalized_ad
  @non_personalized_ad
end

#ordinalString

The ordinal of the conversion. Use this field to control how conversions of the same user and day are de-duplicated. This is a required field. Corresponds to the JSON property ordinal

Returns:

  • (String)


3032
3033
3034
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3032

def ordinal
  @ordinal
end

#quantityFixnum

The quantity of the conversion. This is a required field. Corresponds to the JSON property quantity

Returns:

  • (Fixnum)


3037
3038
3039
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3037

def quantity
  @quantity
end

#session_attributes_encodedString

Session attributes for the conversion, encoded as based64 bytes. This field may only be used when calling batchinsert; it is not supported by batchupdate. Corresponds to the JSON property sessionAttributesEncoded NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3044
3045
3046
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3044

def session_attributes_encoded
  @session_attributes_encoded
end

#timestamp_microsFixnum

The timestamp of conversion, in Unix epoch micros. This is a required field. Corresponds to the JSON property timestampMicros

Returns:

  • (Fixnum)


3049
3050
3051
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3049

def timestamp_micros
  @timestamp_micros
end

#treatment_for_underageBoolean Also known as: treatment_for_underage?

Whether this particular request may come from a user under the age of 16 (may differ by country), under compliance with the European Union's General Data Protection Regulation (GDPR). Corresponds to the JSON property treatmentForUnderage

Returns:

  • (Boolean)


3056
3057
3058
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3056

def treatment_for_underage
  @treatment_for_underage
end

#user_identifiersArray<Google::Apis::DfareportingV4::UserIdentifier>

The user identifiers to enhance the conversion. The maximum number of user identifiers for each conversion is 5. Corresponds to the JSON property userIdentifiers



3063
3064
3065
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3063

def user_identifiers
  @user_identifiers
end

#valueFloat

The value of the conversion. Interpreted in CM360 Floodlight config parent advertiser's currency code. This is a required field. Corresponds to the JSON property value

Returns:

  • (Float)


3069
3070
3071
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3069

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3076

def update!(**args)
  @ad_user_data_consent = args[:ad_user_data_consent] if args.key?(:ad_user_data_consent)
  @cart_data = args[:cart_data] if args.key?(:cart_data)
  @child_directed_treatment = args[:child_directed_treatment] if args.key?(:child_directed_treatment)
  @custom_variables = args[:custom_variables] if args.key?(:custom_variables)
  @dclid = args[:dclid] if args.key?(:dclid)
  @encrypted_user_id = args[:encrypted_user_id] if args.key?(:encrypted_user_id)
  @encrypted_user_id_candidates = args[:encrypted_user_id_candidates] if args.key?(:encrypted_user_id_candidates)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_configuration_id = args[:floodlight_configuration_id] if args.key?(:floodlight_configuration_id)
  @gclid = args[:gclid] if args.key?(:gclid)
  @impression_id = args[:impression_id] if args.key?(:impression_id)
  @kind = args[:kind] if args.key?(:kind)
  @limit_ad_tracking = args[:limit_ad_tracking] if args.key?(:limit_ad_tracking)
  @match_id = args[:match_id] if args.key?(:match_id)
  @mobile_device_id = args[:mobile_device_id] if args.key?(:mobile_device_id)
  @non_personalized_ad = args[:non_personalized_ad] if args.key?(:non_personalized_ad)
  @ordinal = args[:ordinal] if args.key?(:ordinal)
  @quantity = args[:quantity] if args.key?(:quantity)
  @session_attributes_encoded = args[:session_attributes_encoded] if args.key?(:session_attributes_encoded)
  @timestamp_micros = args[:timestamp_micros] if args.key?(:timestamp_micros)
  @treatment_for_underage = args[:treatment_for_underage] if args.key?(:treatment_for_underage)
  @user_identifiers = args[:user_identifiers] if args.key?(:user_identifiers)
  @value = args[:value] if args.key?(:value)
end