Class: Google::Apis::DfareportingV4::ConversionStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

The original conversion that was inserted or updated and whether there were any errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversionStatus

Returns a new instance of ConversionStatus.



3158
3159
3160
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversionGoogle::Apis::DfareportingV4::Conversion

A Conversion represents when a user successfully performs a desired action after seeing an ad. Corresponds to the JSON property conversion



3145
3146
3147
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3145

def conversion
  @conversion
end

#errorsArray<Google::Apis::DfareportingV4::ConversionError>

A list of errors related to this conversion. Corresponds to the JSON property errors



3150
3151
3152
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3150

def errors
  @errors
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#conversionStatus". Corresponds to the JSON property kind

Returns:

  • (String)


3156
3157
3158
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3156

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3163
3164
3165
3166
3167
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3163

def update!(**args)
  @conversion = args[:conversion] if args.key?(:conversion)
  @errors = args[:errors] if args.key?(:errors)
  @kind = args[:kind] if args.key?(:kind)
end