Class: Google::Apis::DfareportingV4::ConversionsBatchUpdateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Update Conversions Response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversionsBatchUpdateResponse

Returns a new instance of ConversionsBatchUpdateResponse.



3290
3291
3292
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#has_failuresBoolean Also known as: has_failures?

Indicates that some or all conversions failed to update. Corresponds to the JSON property hasFailures

Returns:

  • (Boolean)


3275
3276
3277
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3275

def has_failures
  @has_failures
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#conversionsBatchUpdateResponse". Corresponds to the JSON property kind

Returns:

  • (String)


3282
3283
3284
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3282

def kind
  @kind
end

#statusArray<Google::Apis::DfareportingV4::ConversionStatus>

The update status of each conversion. Statuses are returned in the same order that conversions are updated. Corresponds to the JSON property status



3288
3289
3290
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3288

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3295
3296
3297
3298
3299
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 3295

def update!(**args)
  @has_failures = args[:has_failures] if args.key?(:has_failures)
  @kind = args[:kind] if args.key?(:kind)
  @status = args[:status] if args.key?(:status)
end