Class: Google::Apis::DfareportingV4::CreativeCustomEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Creative Custom Event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeCustomEvent

Returns a new instance of CreativeCustomEvent.



4688
4689
4690
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_custom_event_idFixnum

Unique ID of this event used by Reporting and Data Transfer. This is a read- only field. Corresponds to the JSON property advertiserCustomEventId

Returns:

  • (Fixnum)


4638
4639
4640
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4638

def advertiser_custom_event_id
  @advertiser_custom_event_id
end

#advertiser_custom_event_nameString

User-entered name for the event. Corresponds to the JSON property advertiserCustomEventName

Returns:

  • (String)


4643
4644
4645
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4643

def advertiser_custom_event_name
  @advertiser_custom_event_name
end

#advertiser_custom_event_typeString

Type of the event. This is a read-only field. Corresponds to the JSON property advertiserCustomEventType

Returns:

  • (String)


4648
4649
4650
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4648

def advertiser_custom_event_type
  @advertiser_custom_event_type
end

#artwork_labelString

Artwork label column, used to link events in Campaign Manager back to events in Studio. This is a required field and should not be modified after insertion. Corresponds to the JSON property artworkLabel

Returns:

  • (String)


4654
4655
4656
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4654

def artwork_label
  @artwork_label
end

#artwork_typeString

Artwork type used by the creative.This is a read-only field. Corresponds to the JSON property artworkType

Returns:

  • (String)


4659
4660
4661
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4659

def artwork_type
  @artwork_type
end

#exit_click_through_urlGoogle::Apis::DfareportingV4::CreativeClickThroughUrl

Click-through URL Corresponds to the JSON property exitClickThroughUrl



4664
4665
4666
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4664

def exit_click_through_url
  @exit_click_through_url
end

#idFixnum

ID of this event. This is a required field and should not be modified after insertion. Corresponds to the JSON property id

Returns:

  • (Fixnum)


4670
4671
4672
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4670

def id
  @id
end

Popup Window Properties. Corresponds to the JSON property popupWindowProperties



4675
4676
4677
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4675

def popup_window_properties
  @popup_window_properties
end

#target_typeString

Target type used by the event. Corresponds to the JSON property targetType

Returns:

  • (String)


4680
4681
4682
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4680

def target_type
  @target_type
end

#video_reporting_idString

Video reporting ID, used to differentiate multiple videos in a single creative. This is a read-only field. Corresponds to the JSON property videoReportingId

Returns:

  • (String)


4686
4687
4688
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4686

def video_reporting_id
  @video_reporting_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4693

def update!(**args)
  @advertiser_custom_event_id = args[:advertiser_custom_event_id] if args.key?(:advertiser_custom_event_id)
  @advertiser_custom_event_name = args[:advertiser_custom_event_name] if args.key?(:advertiser_custom_event_name)
  @advertiser_custom_event_type = args[:advertiser_custom_event_type] if args.key?(:advertiser_custom_event_type)
  @artwork_label = args[:artwork_label] if args.key?(:artwork_label)
  @artwork_type = args[:artwork_type] if args.key?(:artwork_type)
  @exit_click_through_url = args[:exit_click_through_url] if args.key?(:exit_click_through_url)
  @id = args[:id] if args.key?(:id)
  @popup_window_properties = args[:popup_window_properties] if args.key?(:popup_window_properties)
  @target_type = args[:target_type] if args.key?(:target_type)
  @video_reporting_id = args[:video_reporting_id] if args.key?(:video_reporting_id)
end