Class: Google::Apis::DfareportingV4::CreativeFieldsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::CreativeFieldsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Creative Field List Response
Instance Attribute Summary collapse
-
#creative_fields ⇒ Array<Google::Apis::DfareportingV4::CreativeField>
Creative field collection.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreativeFieldsListResponse
constructor
A new instance of CreativeFieldsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreativeFieldsListResponse
Returns a new instance of CreativeFieldsListResponse.
4876 4877 4878 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creative_fields ⇒ Array<Google::Apis::DfareportingV4::CreativeField>
Creative field collection.
Corresponds to the JSON property creativeFields
4863 4864 4865 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4863 def creative_fields @creative_fields end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#creativeFieldsListResponse".
Corresponds to the JSON property kind
4869 4870 4871 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4869 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
4874 4875 4876 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4874 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4881 4882 4883 4884 4885 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 4881 def update!(**args) @creative_fields = args[:creative_fields] if args.key?(:creative_fields) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |