Class: Google::Apis::DfareportingV4::CreativeRotation
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::CreativeRotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Creative Rotation.
Instance Attribute Summary collapse
-
#creative_assignments ⇒ Array<Google::Apis::DfareportingV4::CreativeAssignment>
Creative assignments in this creative rotation.
-
#creative_optimization_configuration_id ⇒ Fixnum
Creative optimization configuration that is used by this ad.
-
#type ⇒ String
Type of creative rotation.
-
#weight_calculation_strategy ⇒ String
Strategy for calculating weights.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreativeRotation
constructor
A new instance of CreativeRotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreativeRotation
Returns a new instance of CreativeRotation.
5080 5081 5082 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creative_assignments ⇒ Array<Google::Apis::DfareportingV4::CreativeAssignment>
Creative assignments in this creative rotation.
Corresponds to the JSON property creativeAssignments
5059 5060 5061 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5059 def creative_assignments @creative_assignments end |
#creative_optimization_configuration_id ⇒ Fixnum
Creative optimization configuration that is used by this ad. It should refer
to one of the existing optimization configurations in the ad's campaign. If it
is unset or set to 0, then the campaign's default optimization configuration
will be used for this ad.
Corresponds to the JSON property creativeOptimizationConfigurationId
5067 5068 5069 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5067 def creative_optimization_configuration_id @creative_optimization_configuration_id end |
#type ⇒ String
Type of creative rotation. Can be used to specify whether to use sequential or
random rotation.
Corresponds to the JSON property type
5073 5074 5075 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5073 def type @type end |
#weight_calculation_strategy ⇒ String
Strategy for calculating weights. Used with CREATIVE_ROTATION_TYPE_RANDOM.
Corresponds to the JSON property weightCalculationStrategy
5078 5079 5080 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5078 def weight_calculation_strategy @weight_calculation_strategy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5085 5086 5087 5088 5089 5090 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5085 def update!(**args) @creative_assignments = args[:creative_assignments] if args.key?(:creative_assignments) @creative_optimization_configuration_id = args[:creative_optimization_configuration_id] if args.key?(:creative_optimization_configuration_id) @type = args[:type] if args.key?(:type) @weight_calculation_strategy = args[:weight_calculation_strategy] if args.key?(:weight_calculation_strategy) end |