Class: Google::Apis::DfareportingV4::CustomFloodlightVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

A custom floodlight variable. Can be used in both batchinsert and batchupdate. Adding this in batchupdate will update or append the variable to the existing list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomFloodlightVariable

Returns a new instance of CustomFloodlightVariable.



5240
5241
5242
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#customFloodlightVariable". Corresponds to the JSON property kind

Returns:

  • (String)


5226
5227
5228
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5226

def kind
  @kind
end

#typeString

The type of custom floodlight variable to supply a value for. These map to the "u[1-100]=" in the tags. Corresponds to the JSON property type

Returns:

  • (String)


5232
5233
5234
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5232

def type
  @type
end

#valueString

The value of the custom floodlight variable. The length of string must not exceed 100 characters. Corresponds to the JSON property value

Returns:

  • (String)


5238
5239
5240
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5238

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5245
5246
5247
5248
5249
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5245

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end