Class: Google::Apis::DfareportingV4::DateRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Represents a date range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DateRange

Returns a new instance of DateRange.



5434
5435
5436
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dateDate

Corresponds to the JSON property endDate

Returns:

  • (Date)


5417
5418
5419
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5417

def end_date
  @end_date
end

#kindString

The kind of resource this is, in this case dfareporting#dateRange. Corresponds to the JSON property kind

Returns:

  • (String)


5422
5423
5424
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5422

def kind
  @kind
end

#relative_date_rangeString

The date range relative to the date of when the report is run. Corresponds to the JSON property relativeDateRange

Returns:

  • (String)


5427
5428
5429
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5427

def relative_date_range
  @relative_date_range
end

#start_dateDate

Corresponds to the JSON property startDate

Returns:

  • (Date)


5432
5433
5434
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5432

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5439
5440
5441
5442
5443
5444
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5439

def update!(**args)
  @end_date = args[:end_date] if args.key?(:end_date)
  @kind = args[:kind] if args.key?(:kind)
  @relative_date_range = args[:relative_date_range] if args.key?(:relative_date_range)
  @start_date = args[:start_date] if args.key?(:start_date)
end