Class: Google::Apis::DfareportingV4::DeepLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains information about a landing page deep link.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeepLink

Returns a new instance of DeepLink.



5518
5519
5520
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5518

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_urlString

The URL of the mobile app being linked to. Corresponds to the JSON property appUrl

Returns:

  • (String)


5493
5494
5495
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5493

def app_url
  @app_url
end

#fallback_urlString

The fallback URL. This URL will be served to users who do not have the mobile app installed. Corresponds to the JSON property fallbackUrl

Returns:

  • (String)


5499
5500
5501
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5499

def fallback_url
  @fallback_url
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#deepLink". Corresponds to the JSON property kind

Returns:

  • (String)


5505
5506
5507
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5505

def kind
  @kind
end

#mobile_appGoogle::Apis::DfareportingV4::MobileApp

Contains information about a mobile app. Used as a landing page deep link. Corresponds to the JSON property mobileApp



5510
5511
5512
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5510

def mobile_app
  @mobile_app
end

#remarketing_list_idsArray<Fixnum>

Ads served to users on these remarketing lists will use this deep link. Applicable when mobileApp.directory is APPLE_APP_STORE. Corresponds to the JSON property remarketingListIds

Returns:

  • (Array<Fixnum>)


5516
5517
5518
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5516

def remarketing_list_ids
  @remarketing_list_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5523
5524
5525
5526
5527
5528
5529
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5523

def update!(**args)
  @app_url = args[:app_url] if args.key?(:app_url)
  @fallback_url = args[:fallback_url] if args.key?(:fallback_url)
  @kind = args[:kind] if args.key?(:kind)
  @mobile_app = args[:mobile_app] if args.key?(:mobile_app)
  @remarketing_list_ids = args[:remarketing_list_ids] if args.key?(:remarketing_list_ids)
end