Class: Google::Apis::DfareportingV4::DeliverySchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Delivery Schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeliverySchedule

Returns a new instance of DeliverySchedule.



5592
5593
5594
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frequency_capGoogle::Apis::DfareportingV4::FrequencyCap

Frequency Cap. Corresponds to the JSON property frequencyCap



5568
5569
5570
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5568

def frequency_cap
  @frequency_cap
end

#hard_cutoffBoolean Also known as: hard_cutoff?

Whether or not hard cutoff is enabled. If true, the ad will not serve after the end date and time. Otherwise the ad will continue to be served until it has reached its delivery goals. Corresponds to the JSON property hardCutoff

Returns:

  • (Boolean)


5575
5576
5577
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5575

def hard_cutoff
  @hard_cutoff
end

#impression_ratioFixnum

Impression ratio for this ad. This ratio determines how often each ad is served relative to the others. For example, if ad A has an impression ratio of 1 and ad B has an impression ratio of 3, then Campaign Manager will serve ad B three times as often as ad A. Acceptable values are 1 to 10, inclusive. Corresponds to the JSON property impressionRatio

Returns:

  • (Fixnum)


5584
5585
5586
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5584

def impression_ratio
  @impression_ratio
end

#priorityString

Serving priority of an ad, with respect to other ads. The lower the priority number, the greater the priority with which it is served. Corresponds to the JSON property priority

Returns:

  • (String)


5590
5591
5592
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5590

def priority
  @priority
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5597
5598
5599
5600
5601
5602
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5597

def update!(**args)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @hard_cutoff = args[:hard_cutoff] if args.key?(:hard_cutoff)
  @impression_ratio = args[:impression_ratio] if args.key?(:impression_ratio)
  @priority = args[:priority] if args.key?(:priority)
end