Class: Google::Apis::DfareportingV4::DimensionValueList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Represents the list of DimensionValue resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DimensionValueList

Returns a new instance of DimensionValueList.



5851
5852
5853
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

The eTag of this response for caching purposes. Corresponds to the JSON property etag

Returns:

  • (String)


5831
5832
5833
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5831

def etag
  @etag
end

#itemsArray<Google::Apis::DfareportingV4::DimensionValue>

The dimension values returned in this response. Corresponds to the JSON property items



5836
5837
5838
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5836

def items
  @items
end

#kindString

The kind of list this is, in this case dfareporting#dimensionValueList. Corresponds to the JSON property kind

Returns:

  • (String)


5841
5842
5843
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5841

def kind
  @kind
end

#next_page_tokenString

Continuation token used to page through dimension values. To retrieve the next page of results, set the next request's "pageToken" to the value of this field. The page token is only valid for a limited amount of time and should not be persisted. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5849
5850
5851
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5849

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5856
5857
5858
5859
5860
5861
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5856

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end