Class: Google::Apis::DfareportingV4::DimensionValueRequest
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::DimensionValueRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Represents a DimensionValuesRequest.
Instance Attribute Summary collapse
-
#dimension_name ⇒ String
The name of the dimension for which values should be requested.
-
#end_date ⇒ Date
Corresponds to the JSON property
endDate. -
#filters ⇒ Array<Google::Apis::DfareportingV4::DimensionFilter>
The list of filters by which to filter values.
-
#kind ⇒ String
The kind of request this is, in this case dfareporting#dimensionValueRequest .
-
#start_date ⇒ Date
Corresponds to the JSON property
startDate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DimensionValueRequest
constructor
A new instance of DimensionValueRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DimensionValueRequest
Returns a new instance of DimensionValueRequest.
5893 5894 5895 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension_name ⇒ String
The name of the dimension for which values should be requested.
Corresponds to the JSON property dimensionName
5871 5872 5873 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5871 def dimension_name @dimension_name end |
#end_date ⇒ Date
Corresponds to the JSON property endDate
5876 5877 5878 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5876 def end_date @end_date end |
#filters ⇒ Array<Google::Apis::DfareportingV4::DimensionFilter>
The list of filters by which to filter values. The filters are ANDed.
Corresponds to the JSON property filters
5881 5882 5883 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5881 def filters @filters end |
#kind ⇒ String
The kind of request this is, in this case dfareporting#dimensionValueRequest .
Corresponds to the JSON property kind
5886 5887 5888 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5886 def kind @kind end |
#start_date ⇒ Date
Corresponds to the JSON property startDate
5891 5892 5893 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5891 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5898 5899 5900 5901 5902 5903 5904 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5898 def update!(**args) @dimension_name = args[:dimension_name] if args.key?(:dimension_name) @end_date = args[:end_date] if args.key?(:end_date) @filters = args[:filters] if args.key?(:filters) @kind = args[:kind] if args.key?(:kind) @start_date = args[:start_date] if args.key?(:start_date) end |