Class: Google::Apis::DfareportingV4::DirectorySite
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::DirectorySite
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
DirectorySites contains properties of a website from the Site Directory. Sites need to be added to an account via the Sites resource before they can be assigned to a placement.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
ID of this directory site.
-
#id_dimension_value ⇒ Google::Apis::DfareportingV4::DimensionValue
Represents a DimensionValue resource.
-
#inpage_tag_formats ⇒ Array<String>
Tag types for regular placements.
-
#interstitial_tag_formats ⇒ Array<String>
Tag types for interstitial placements.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this directory site.
-
#publisher_specification_id ⇒ Fixnum
Output only.
-
#settings ⇒ Google::Apis::DfareportingV4::DirectorySiteSettings
Directory Site Settings Corresponds to the JSON property
settings. -
#url ⇒ String
URL of this directory site.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DirectorySite
constructor
A new instance of DirectorySite.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DirectorySite
Returns a new instance of DirectorySite.
5970 5971 5972 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
ID of this directory site. This is a read-only, auto-generated field.
Corresponds to the JSON property id
5916 5917 5918 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5916 def id @id end |
#id_dimension_value ⇒ Google::Apis::DfareportingV4::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property idDimensionValue
5921 5922 5923 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5921 def id_dimension_value @id_dimension_value end |
#inpage_tag_formats ⇒ Array<String>
Tag types for regular placements. Acceptable values are: - "STANDARD" - "
IFRAME_JAVASCRIPT_INPAGE" - "INTERNAL_REDIRECT_INPAGE" - "JAVASCRIPT_INPAGE"
Corresponds to the JSON property inpageTagFormats
5927 5928 5929 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5927 def inpage_tag_formats @inpage_tag_formats end |
#interstitial_tag_formats ⇒ Array<String>
Tag types for interstitial placements. Acceptable values are: - "
IFRAME_JAVASCRIPT_INTERSTITIAL" - "INTERNAL_REDIRECT_INTERSTITIAL" - "
JAVASCRIPT_INTERSTITIAL"
Corresponds to the JSON property interstitialTagFormats
5934 5935 5936 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5934 def interstitial_tag_formats @interstitial_tag_formats end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#directorySite".
Corresponds to the JSON property kind
5940 5941 5942 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5940 def kind @kind end |
#name ⇒ String
Name of this directory site.
Corresponds to the JSON property name
5945 5946 5947 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5945 def name @name end |
#publisher_specification_id ⇒ Fixnum
Output only. Default publisher specification ID of video placements under this
directory site. Possible values are: * 1, Hulu * 2, NBC * 3, CBS * 4,
CBS Desktop * 5, Discovery * 6, VEVO HD * 7, VEVO Vertical * 8, Fox *
9, CW Network * 10, Disney * 11, IGN * 12, NFL.com * 13, Turner
Broadcasting * 14, Tubi on Fox * 15, Hearst Corporation * 16, Twitch
Desktop * 17, ABC * 18, Univision * 19, MLB.com * 20, MLB.com Mobile *
21, MLB.com OTT * 22, Polsat * 23, TVN * 24, Mediaset * 25, Antena 3
26, Mediamond *27, Sky Italia *28, Tubi on CBS *29, Spotify *30, Paramount *31, Max Corresponds to the JSON propertypublisherSpecificationId
5958 5959 5960 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5958 def publisher_specification_id @publisher_specification_id end |
#settings ⇒ Google::Apis::DfareportingV4::DirectorySiteSettings
Directory Site Settings
Corresponds to the JSON property settings
5963 5964 5965 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5963 def settings @settings end |
#url ⇒ String
URL of this directory site.
Corresponds to the JSON property url
5968 5969 5970 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5968 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5975 def update!(**args) @id = args[:id] if args.key?(:id) @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value) @inpage_tag_formats = args[:inpage_tag_formats] if args.key?(:inpage_tag_formats) @interstitial_tag_formats = args[:interstitial_tag_formats] if args.key?(:interstitial_tag_formats) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @publisher_specification_id = args[:publisher_specification_id] if args.key?(:publisher_specification_id) @settings = args[:settings] if args.key?(:settings) @url = args[:url] if args.key?(:url) end |