Class: Google::Apis::DfareportingV4::DynamicFeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains dynamic feed information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DynamicFeed

Returns a new instance of DynamicFeed.



6132
6133
6134
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_sourceGoogle::Apis::DfareportingV4::ContentSource

Contains the content source of the dynamic feed. Corresponds to the JSON property contentSource



6069
6070
6071
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6069

def content_source
  @content_source
end

#create_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



6074
6075
6076
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6074

def create_info
  @create_info
end

#dynamic_feed_idFixnum

Output only. Unique ID of this dynamic feed. This is a read-only, auto- generated field. Corresponds to the JSON property dynamicFeedId

Returns:

  • (Fixnum)


6080
6081
6082
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6080

def dynamic_feed_id
  @dynamic_feed_id
end

#dynamic_feed_nameString

Optional. Name of this dynamic feed. It is defaulted to content source file name if not provided. Corresponds to the JSON property dynamicFeedName

Returns:

  • (String)


6086
6087
6088
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6086

def dynamic_feed_name
  @dynamic_feed_name
end

#elementGoogle::Apis::DfareportingV4::Element

Contains the element of the dynamic feed. Corresponds to the JSON property element



6091
6092
6093
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6091

def element
  @element
end

#feed_ingestion_statusGoogle::Apis::DfareportingV4::FeedIngestionStatus

Contains the ingestion status of the dynamic feed. Feed ingestion is an asynchronous process. If the feed create request is successful, feed ingestion will be processed in the background, including validation, assets retrieval, and saving the data from the resource link. The processing time is dependent on the data size in the resource link. This read-only status field contains the current stage of that processing and its ingestion state. Corresponds to the JSON property feedIngestionStatus



6101
6102
6103
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6101

def feed_ingestion_status
  @feed_ingestion_status
end

#feed_scheduleGoogle::Apis::DfareportingV4::FeedSchedule

Contains the schedule of the dynamic feed. Corresponds to the JSON property feedSchedule



6106
6107
6108
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6106

def feed_schedule
  @feed_schedule
end

#has_publishedBoolean Also known as: has_published?

Output only. Indicates whether the dynamic feed has a published version. This is a read-only field. Corresponds to the JSON property hasPublished

Returns:

  • (Boolean)


6112
6113
6114
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6112

def has_published
  @has_published
end

#last_modified_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



6118
6119
6120
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6118

def last_modified_info
  @last_modified_info
end

#statusString

Output only. The status of the feed. It is a read-only field that depends on the the feed ingestion status. The default value is INACTIVE, and it will be updated to ACTIVE once the feed is ingested successfully. Corresponds to the JSON property status

Returns:

  • (String)


6125
6126
6127
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6125

def status
  @status
end

#studio_advertiser_idFixnum

Required. Advertiser ID of this dynamic feed. This is a required field. Corresponds to the JSON property studioAdvertiserId

Returns:

  • (Fixnum)


6130
6131
6132
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6130

def studio_advertiser_id
  @studio_advertiser_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6137

def update!(**args)
  @content_source = args[:content_source] if args.key?(:content_source)
  @create_info = args[:create_info] if args.key?(:create_info)
  @dynamic_feed_id = args[:dynamic_feed_id] if args.key?(:dynamic_feed_id)
  @dynamic_feed_name = args[:dynamic_feed_name] if args.key?(:dynamic_feed_name)
  @element = args[:element] if args.key?(:element)
  @feed_ingestion_status = args[:feed_ingestion_status] if args.key?(:feed_ingestion_status)
  @feed_schedule = args[:feed_schedule] if args.key?(:feed_schedule)
  @has_published = args[:has_published] if args.key?(:has_published)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @status = args[:status] if args.key?(:status)
  @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id)
end