Class: Google::Apis::DfareportingV4::DynamicFeedsInsertRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Dynamic profile ID is required for dynamic feed insert as the current GPA API only can create a dynamic feed under profile context,even though the dynamic feed itself don't need the dynamic profile id.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DynamicFeedsInsertRequest

Returns a new instance of DynamicFeedsInsertRequest.



6170
6171
6172
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_feedGoogle::Apis::DfareportingV4::DynamicFeed

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains dynamic feed information. Corresponds to the JSON property dynamicFeed



6163
6164
6165
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6163

def dynamic_feed
  @dynamic_feed
end

#dynamic_profile_idFixnum

Required. Dynamic profile ID of the inserted dynamic feed. Corresponds to the JSON property dynamicProfileId

Returns:

  • (Fixnum)


6168
6169
6170
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6168

def dynamic_profile_id
  @dynamic_profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6175
6176
6177
6178
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6175

def update!(**args)
  @dynamic_feed = args[:dynamic_feed] if args.key?(:dynamic_feed)
  @dynamic_profile_id = args[:dynamic_profile_id] if args.key?(:dynamic_profile_id)
end