Class: Google::Apis::DfareportingV4::DynamicProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains dynamic profile information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DynamicProfile

Returns a new instance of DynamicProfile.



6246
6247
6248
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeGoogle::Apis::DfareportingV4::DynamicProfileVersion

Contains dynamic profile version information. Corresponds to the JSON property active



6190
6191
6192
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6190

def active
  @active
end

#archive_statusString

Optional. Archive status of this dynamic profile. Corresponds to the JSON property archiveStatus

Returns:

  • (String)


6195
6196
6197
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6195

def archive_status
  @archive_status
end

#create_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



6200
6201
6202
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6200

def create_info
  @create_info
end

#descriptionString

Optional. Description of this dynamic profile. Corresponds to the JSON property description

Returns:

  • (String)


6205
6206
6207
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6205

def description
  @description
end

#draftGoogle::Apis::DfareportingV4::DynamicProfileVersion

Contains dynamic profile version information. Corresponds to the JSON property draft



6210
6211
6212
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6210

def draft
  @draft
end

#dynamic_profile_idFixnum

Output only. Unique ID of this dynamic profile. This is a read-only, auto- generated field. Corresponds to the JSON property dynamicProfileId

Returns:

  • (Fixnum)


6216
6217
6218
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6216

def dynamic_profile_id
  @dynamic_profile_id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "dfareporting#dynamicProfile". Corresponds to the JSON property kind

Returns:

  • (String)


6222
6223
6224
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6222

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



6227
6228
6229
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6227

def last_modified_info
  @last_modified_info
end

#nameString

Required. Identifier. Name of this dynamic profile. This is a required field and must be less than 256 characters long. Corresponds to the JSON property name

Returns:

  • (String)


6233
6234
6235
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6233

def name
  @name
end

#statusString

Optional. Status of this dynamic profile. Corresponds to the JSON property status

Returns:

  • (String)


6238
6239
6240
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6238

def status
  @status
end

#studio_advertiser_idFixnum

Required. Advertiser ID of this dynamic profile. This is a required field on insertion. Corresponds to the JSON property studioAdvertiserId

Returns:

  • (Fixnum)


6244
6245
6246
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6244

def studio_advertiser_id
  @studio_advertiser_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6251

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @archive_status = args[:archive_status] if args.key?(:archive_status)
  @create_info = args[:create_info] if args.key?(:create_info)
  @description = args[:description] if args.key?(:description)
  @draft = args[:draft] if args.key?(:draft)
  @dynamic_profile_id = args[:dynamic_profile_id] if args.key?(:dynamic_profile_id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id)
end