Class: Google::Apis::DfareportingV4::DynamicProfileFeedSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains dynamic profile specific settings for an associated dynamic feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DynamicProfileFeedSettings

Returns a new instance of DynamicProfileFeedSettings.



6286
6287
6288
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_feed_idFixnum

Optional. Dynamic feed ID associated with dynamic profile version. Corresponds to the JSON property dynamicFeedId

Returns:

  • (Fixnum)


6273
6274
6275
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6273

def dynamic_feed_id
  @dynamic_feed_id
end

#dynamic_rulesGoogle::Apis::DfareportingV4::DynamicRules

Contains dynamic rules information. Corresponds to the JSON property dynamicRules



6278
6279
6280
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6278

def dynamic_rules
  @dynamic_rules
end

#quantityFixnum

Optional. The number of this dynamic feed rows needed by the dynamic profile, default value is 1. Acceptable values are between 1 to 99, inclusive. Corresponds to the JSON property quantity

Returns:

  • (Fixnum)


6284
6285
6286
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6284

def quantity
  @quantity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6291
6292
6293
6294
6295
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6291

def update!(**args)
  @dynamic_feed_id = args[:dynamic_feed_id] if args.key?(:dynamic_feed_id)
  @dynamic_rules = args[:dynamic_rules] if args.key?(:dynamic_rules)
  @quantity = args[:quantity] if args.key?(:quantity)
end