Class: Google::Apis::DfareportingV4::DynamicTargetingKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains properties of a dynamic targeting key. Dynamic targeting keys are unique, user-friendly labels, created at the advertiser level in DCM, that can be assigned to ads, creatives, and placements and used for targeting with Studio dynamic creatives. Use these labels instead of numeric Campaign Manager IDs (such as placement IDs) to save time and avoid errors in your dynamic feeds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DynamicTargetingKey

Returns a new instance of DynamicTargetingKey.



6443
6444
6445
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#dynamicTargetingKey". Corresponds to the JSON property kind

Returns:

  • (String)


6424
6425
6426
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6424

def kind
  @kind
end

#nameString

Name of this dynamic targeting key. This is a required field. Must be less than 256 characters long and cannot contain commas. All characters are converted to lowercase. Corresponds to the JSON property name

Returns:

  • (String)


6431
6432
6433
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6431

def name
  @name
end

#object_id_propFixnum

ID of the object of this dynamic targeting key. This is a required field. Corresponds to the JSON property objectId

Returns:

  • (Fixnum)


6436
6437
6438
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6436

def object_id_prop
  @object_id_prop
end

#object_typeString

Type of the object of this dynamic targeting key. This is a required field. Corresponds to the JSON property objectType

Returns:

  • (String)


6441
6442
6443
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6441

def object_type
  @object_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6448
6449
6450
6451
6452
6453
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6448

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
  @object_type = args[:object_type] if args.key?(:object_type)
end