Class: Google::Apis::DfareportingV4::EncryptionInfo
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::EncryptionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
A description of how user IDs are encrypted.
Instance Attribute Summary collapse
-
#encryption_entity_id ⇒ Fixnum
The encryption entity ID.
-
#encryption_entity_type ⇒ String
The encryption entity type.
-
#encryption_source ⇒ String
Describes whether the encrypted cookie was received from ad serving (the %m macro) or from Data Transfer.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionInfo
constructor
A new instance of EncryptionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionInfo
Returns a new instance of EncryptionInfo.
6605 6606 6607 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_entity_id ⇒ Fixnum
The encryption entity ID. This should match the encryption configuration for
ad serving or Data Transfer.
Corresponds to the JSON property encryptionEntityId
6585 6586 6587 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6585 def encryption_entity_id @encryption_entity_id end |
#encryption_entity_type ⇒ String
The encryption entity type. This should match the encryption configuration for
ad serving or Data Transfer.
Corresponds to the JSON property encryptionEntityType
6591 6592 6593 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6591 def encryption_entity_type @encryption_entity_type end |
#encryption_source ⇒ String
Describes whether the encrypted cookie was received from ad serving (the %m
macro) or from Data Transfer.
Corresponds to the JSON property encryptionSource
6597 6598 6599 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6597 def encryption_source @encryption_source end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#encryptionInfo".
Corresponds to the JSON property kind
6603 6604 6605 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6603 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6610 6611 6612 6613 6614 6615 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6610 def update!(**args) @encryption_entity_id = args[:encryption_entity_id] if args.key?(:encryption_entity_id) @encryption_entity_type = args[:encryption_entity_type] if args.key?(:encryption_entity_type) @encryption_source = args[:encryption_source] if args.key?(:encryption_source) @kind = args[:kind] if args.key?(:kind) end |