Class: Google::Apis::DfareportingV4::FeedSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains the schedule of the dynamic feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeedSchedule

Returns a new instance of FeedSchedule.



6954
6955
6956
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#repeat_valueFixnum

Optional. The number of times the feed retransforms within one day. This is a required field if the schedule is enabled. Acceptable values are between 1 to 6, inclusive. Corresponds to the JSON property repeatValue

Returns:

  • (Fixnum)


6928
6929
6930
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6928

def repeat_value
  @repeat_value
end

#schedule_enabledBoolean Also known as: schedule_enabled?

Optional. Whether the schedule is enabled. Corresponds to the JSON property scheduleEnabled

Returns:

  • (Boolean)


6933
6934
6935
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6933

def schedule_enabled
  @schedule_enabled
end

#start_hourString

Optional. The hour of the day to start the feed. It is applicable if the repeat value is equal to 1. Default value is 0. Corresponds to the JSON property startHour

Returns:

  • (String)


6940
6941
6942
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6940

def start_hour
  @start_hour
end

#start_minuteString

Optional. The minute of the hour to start the feed. It is applicable if the repeat value is equal to 1. Default value is 0. Corresponds to the JSON property startMinute

Returns:

  • (String)


6946
6947
6948
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6946

def start_minute
  @start_minute
end

#time_zoneString

Optional. The time zone to schedule the feed. It is applicable if the repeat value is equal to 1. Default value is "America/Los_Angeles". Corresponds to the JSON property timeZone

Returns:

  • (String)


6952
6953
6954
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6952

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6959
6960
6961
6962
6963
6964
6965
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6959

def update!(**args)
  @repeat_value = args[:repeat_value] if args.key?(:repeat_value)
  @schedule_enabled = args[:schedule_enabled] if args.key?(:schedule_enabled)
  @start_hour = args[:start_hour] if args.key?(:start_hour)
  @start_minute = args[:start_minute] if args.key?(:start_minute)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end