Class: Google::Apis::DfareportingV4::File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Represents a File resource. A file contains the metadata for a report run. It shows the status of the run and holds the URLs to the generated report data if the run is finished and the status is "REPORT_AVAILABLE".

Defined Under Namespace

Classes: Urls

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ File

Returns a new instance of File.



7125
7126
7127
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_rangeGoogle::Apis::DfareportingV4::DateRange

Represents a date range. Corresponds to the JSON property dateRange



7077
7078
7079
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7077

def date_range
  @date_range
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7082
7083
7084
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7082

def etag
  @etag
end

#file_nameString

The filename of the file. Corresponds to the JSON property fileName

Returns:

  • (String)


7087
7088
7089
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7087

def file_name
  @file_name
end

#formatString

The output format of the report. Only available once the file is available. Corresponds to the JSON property format

Returns:

  • (String)


7092
7093
7094
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7092

def format
  @format
end

#idFixnum

The unique ID of this report file. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7097
7098
7099
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7097

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#file". Corresponds to the JSON property kind

Returns:

  • (String)


7103
7104
7105
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7103

def kind
  @kind
end

#last_modified_timeFixnum

The timestamp in milliseconds since epoch when this file was last modified. Corresponds to the JSON property lastModifiedTime

Returns:

  • (Fixnum)


7108
7109
7110
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7108

def last_modified_time
  @last_modified_time
end

#report_idFixnum

The ID of the report this file was generated from. Corresponds to the JSON property reportId

Returns:

  • (Fixnum)


7113
7114
7115
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7113

def report_id
  @report_id
end

#statusString

The status of the report file. Corresponds to the JSON property status

Returns:

  • (String)


7118
7119
7120
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7118

def status
  @status
end

#urlsGoogle::Apis::DfareportingV4::File::Urls

The URLs where the completed report file can be downloaded. Corresponds to the JSON property urls



7123
7124
7125
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7123

def urls
  @urls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7130

def update!(**args)
  @date_range = args[:date_range] if args.key?(:date_range)
  @etag = args[:etag] if args.key?(:etag)
  @file_name = args[:file_name] if args.key?(:file_name)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @report_id = args[:report_id] if args.key?(:report_id)
  @status = args[:status] if args.key?(:status)
  @urls = args[:urls] if args.key?(:urls)
end