Class: Google::Apis::DfareportingV4::File::Urls

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

The URLs where the completed report file can be downloaded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Urls

Returns a new instance of Urls.



7157
7158
7159
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_urlString

The URL for downloading the report data through the API. Corresponds to the JSON property apiUrl

Returns:

  • (String)


7150
7151
7152
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7150

def api_url
  @api_url
end

#browser_urlString

The URL for downloading the report data through a browser. Corresponds to the JSON property browserUrl

Returns:

  • (String)


7155
7156
7157
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7155

def browser_url
  @browser_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7162
7163
7164
7165
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7162

def update!(**args)
  @api_url = args[:api_url] if args.key?(:api_url)
  @browser_url = args[:browser_url] if args.key?(:browser_url)
end