Class: Google::Apis::DfareportingV4::FileList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

List of files for a report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileList

Returns a new instance of FileList.



7197
7198
7199
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7176
7177
7178
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7176

def etag
  @etag
end

#itemsArray<Google::Apis::DfareportingV4::File>

The files returned in this response. Corresponds to the JSON property items



7181
7182
7183
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7181

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#fileList". Corresponds to the JSON property kind

Returns:

  • (String)


7187
7188
7189
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7187

def kind
  @kind
end

#next_page_tokenString

Continuation token used to page through files. To retrieve the next page of results, set the next request's "pageToken" to the value of this field. The page token is only valid for a limited amount of time and should not be persisted. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7195
7196
7197
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7195

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7202
7203
7204
7205
7206
7207
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7202

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end