Class: Google::Apis::DfareportingV4::FloodlightActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains properties of a Floodlight activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightActivity

Returns a new instance of FloodlightActivity.



7495
7496
7497
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this floodlight activity. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


7322
7323
7324
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7322

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this floodlight activity. If this field is left blank, the value will be copied over either from the activity group's advertiser or the existing activity's advertiser. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7329
7330
7331
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7329

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



7334
7335
7336
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7334

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#attribution_enabledBoolean Also known as: attribution_enabled?

Whether the activity is enabled for attribution. Corresponds to the JSON property attributionEnabled

Returns:

  • (Boolean)


7339
7340
7341
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7339

def attribution_enabled
  @attribution_enabled
end

#cache_busting_typeString

Code type used for cache busting in the generated tag. Applicable only when floodlightActivityGroupType is COUNTER and countingMethod is STANDARD_COUNTING or UNIQUE_COUNTING. Corresponds to the JSON property cacheBustingType

Returns:

  • (String)


7347
7348
7349
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7347

def cache_busting_type
  @cache_busting_type
end

#counting_methodString

Counting method for conversions for this floodlight activity. This is a required field. Corresponds to the JSON property countingMethod

Returns:

  • (String)


7353
7354
7355
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7353

def counting_method
  @counting_method
end

#default_tagsArray<Google::Apis::DfareportingV4::FloodlightActivityDynamicTag>

Dynamic floodlight tags. Corresponds to the JSON property defaultTags



7358
7359
7360
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7358

def default_tags
  @default_tags
end

#expected_urlString

URL where this tag will be deployed. If specified, must be less than 256 characters long. Corresponds to the JSON property expectedUrl

Returns:

  • (String)


7364
7365
7366
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7364

def expected_url
  @expected_url
end

#floodlight_activity_group_idFixnum

Floodlight activity group ID of this floodlight activity. This is a required field. Corresponds to the JSON property floodlightActivityGroupId

Returns:

  • (Fixnum)


7370
7371
7372
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7370

def floodlight_activity_group_id
  @floodlight_activity_group_id
end

#floodlight_activity_group_nameString

Name of the associated floodlight activity group. This is a read-only field. Corresponds to the JSON property floodlightActivityGroupName

Returns:

  • (String)


7375
7376
7377
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7375

def floodlight_activity_group_name
  @floodlight_activity_group_name
end

#floodlight_activity_group_tag_stringString

Tag string of the associated floodlight activity group. This is a read-only field. Corresponds to the JSON property floodlightActivityGroupTagString

Returns:

  • (String)


7381
7382
7383
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7381

def floodlight_activity_group_tag_string
  @floodlight_activity_group_tag_string
end

#floodlight_activity_group_typeString

Type of the associated floodlight activity group. This is a read-only field. Corresponds to the JSON property floodlightActivityGroupType

Returns:

  • (String)


7386
7387
7388
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7386

def floodlight_activity_group_type
  @floodlight_activity_group_type
end

#floodlight_configuration_idFixnum

Floodlight configuration ID of this floodlight activity. If this field is left blank, the value will be copied over either from the activity group's floodlight configuration or from the existing activity's floodlight configuration. Corresponds to the JSON property floodlightConfigurationId

Returns:

  • (Fixnum)


7394
7395
7396
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7394

def floodlight_configuration_id
  @floodlight_configuration_id
end

#floodlight_configuration_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightConfigurationIdDimensionValue



7399
7400
7401
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7399

def floodlight_configuration_id_dimension_value
  @floodlight_configuration_id_dimension_value
end

#floodlight_tag_typeString

The type of Floodlight tag this activity will generate. This is a required field. Corresponds to the JSON property floodlightTagType

Returns:

  • (String)


7405
7406
7407
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7405

def floodlight_tag_type
  @floodlight_tag_type
end

#idFixnum

ID of this floodlight activity. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7410
7411
7412
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7410

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



7415
7416
7417
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7415

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#floodlightActivity". Corresponds to the JSON property kind

Returns:

  • (String)


7421
7422
7423
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7421

def kind
  @kind
end

#nameString

Name of this floodlight activity. This is a required field. Must be less than 129 characters long and cannot contain quotes. Corresponds to the JSON property name

Returns:

  • (String)


7427
7428
7429
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7427

def name
  @name
end

#notesString

General notes or implementation instructions for the tag. Corresponds to the JSON property notes

Returns:

  • (String)


7432
7433
7434
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7432

def notes
  @notes
end

#publisher_tagsArray<Google::Apis::DfareportingV4::FloodlightActivityPublisherDynamicTag>

Publisher dynamic floodlight tags. Corresponds to the JSON property publisherTags



7437
7438
7439
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7437

def publisher_tags
  @publisher_tags
end

#secureBoolean Also known as: secure?

Whether this tag should use SSL. Corresponds to the JSON property secure

Returns:

  • (Boolean)


7442
7443
7444
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7442

def secure
  @secure
end

#ssl_compliantBoolean Also known as: ssl_compliant?

Whether the floodlight activity is SSL-compliant. This is a read-only field, its value detected by the system from the floodlight tags. Corresponds to the JSON property sslCompliant

Returns:

  • (Boolean)


7449
7450
7451
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7449

def ssl_compliant
  @ssl_compliant
end

#ssl_requiredBoolean Also known as: ssl_required?

Whether this floodlight activity must be SSL-compliant. Corresponds to the JSON property sslRequired

Returns:

  • (Boolean)


7455
7456
7457
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7455

def ssl_required
  @ssl_required
end

#statusString

The status of the activity. This can only be set to ACTIVE or ARCHIVED_AND_DISABLED. The ARCHIVED status is no longer supported and cannot be set for Floodlight activities. The DISABLED_POLICY status indicates that a Floodlight activity is violating Google policy. Contact your account manager for more information. Corresponds to the JSON property status

Returns:

  • (String)


7465
7466
7467
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7465

def status
  @status
end

#subaccount_idFixnum

Subaccount ID of this floodlight activity. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


7471
7472
7473
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7471

def subaccount_id
  @subaccount_id
end

#tag_formatString

Tag format type for the floodlight activity. If left blank, the tag format will default to HTML. Corresponds to the JSON property tagFormat

Returns:

  • (String)


7477
7478
7479
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7477

def tag_format
  @tag_format
end

#tag_stringString

Value of the cat= parameter in the floodlight tag, which the ad servers use to identify the activity. This is optional: if empty, a new tag string will be generated for you. This string must be 1 to 8 characters long, with valid characters being a-z0-9[ _ ]. This tag string must also be unique among activities of the same activity group. This field is read-only after insertion. Corresponds to the JSON property tagString

Returns:

  • (String)


7486
7487
7488
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7486

def tag_string
  @tag_string
end

#user_defined_variable_typesArray<String>

List of the user-defined variables used by this conversion tag. These map to the "u[1-100]=" in the tags. Each of these can have a user defined type. Acceptable values are U1 to U100, inclusive. Corresponds to the JSON property userDefinedVariableTypes

Returns:

  • (Array<String>)


7493
7494
7495
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7493

def user_defined_variable_types
  @user_defined_variable_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7500
7501
7502
7503
7504
7505
7506
7507
7508
7509
7510
7511
7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7500

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @attribution_enabled = args[:attribution_enabled] if args.key?(:attribution_enabled)
  @cache_busting_type = args[:cache_busting_type] if args.key?(:cache_busting_type)
  @counting_method = args[:counting_method] if args.key?(:counting_method)
  @default_tags = args[:default_tags] if args.key?(:default_tags)
  @expected_url = args[:expected_url] if args.key?(:expected_url)
  @floodlight_activity_group_id = args[:floodlight_activity_group_id] if args.key?(:floodlight_activity_group_id)
  @floodlight_activity_group_name = args[:floodlight_activity_group_name] if args.key?(:floodlight_activity_group_name)
  @floodlight_activity_group_tag_string = args[:floodlight_activity_group_tag_string] if args.key?(:floodlight_activity_group_tag_string)
  @floodlight_activity_group_type = args[:floodlight_activity_group_type] if args.key?(:floodlight_activity_group_type)
  @floodlight_configuration_id = args[:floodlight_configuration_id] if args.key?(:floodlight_configuration_id)
  @floodlight_configuration_id_dimension_value = args[:floodlight_configuration_id_dimension_value] if args.key?(:floodlight_configuration_id_dimension_value)
  @floodlight_tag_type = args[:floodlight_tag_type] if args.key?(:floodlight_tag_type)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @publisher_tags = args[:publisher_tags] if args.key?(:publisher_tags)
  @secure = args[:secure] if args.key?(:secure)
  @ssl_compliant = args[:ssl_compliant] if args.key?(:ssl_compliant)
  @ssl_required = args[:ssl_required] if args.key?(:ssl_required)
  @status = args[:status] if args.key?(:status)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @tag_format = args[:tag_format] if args.key?(:tag_format)
  @tag_string = args[:tag_string] if args.key?(:tag_string)
  @user_defined_variable_types = args[:user_defined_variable_types] if args.key?(:user_defined_variable_types)
end