Class: Google::Apis::DfareportingV4::FloodlightActivityGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains properties of a Floodlight activity group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightActivityGroup

Returns a new instance of FloodlightActivityGroup.



7642
7643
7644
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this floodlight activity group. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


7572
7573
7574
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7572

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this floodlight activity group. If this field is left blank, the value will be copied over either from the floodlight configuration's advertiser or from the existing activity group's advertiser. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7579
7580
7581
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7579

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



7584
7585
7586
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7584

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#floodlight_configuration_idFixnum

Floodlight configuration ID of this floodlight activity group. This is a required field. Corresponds to the JSON property floodlightConfigurationId

Returns:

  • (Fixnum)


7590
7591
7592
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7590

def floodlight_configuration_id
  @floodlight_configuration_id
end

#floodlight_configuration_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightConfigurationIdDimensionValue



7595
7596
7597
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7595

def floodlight_configuration_id_dimension_value
  @floodlight_configuration_id_dimension_value
end

#idFixnum

ID of this floodlight activity group. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7601
7602
7603
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7601

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



7606
7607
7608
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7606

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#floodlightActivityGroup". Corresponds to the JSON property kind

Returns:

  • (String)


7612
7613
7614
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7612

def kind
  @kind
end

#nameString

Name of this floodlight activity group. This is a required field. Must be less than 65 characters long and cannot contain quotes. Corresponds to the JSON property name

Returns:

  • (String)


7618
7619
7620
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7618

def name
  @name
end

#subaccount_idFixnum

Subaccount ID of this floodlight activity group. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


7624
7625
7626
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7624

def subaccount_id
  @subaccount_id
end

#tag_stringString

Value of the type= parameter in the floodlight tag, which the ad servers use to identify the activity group that the activity belongs to. This is optional: if empty, a new tag string will be generated for you. This string must be 1 to 8 characters long, with valid characters being a-z0-9[ _ ]. This tag string must also be unique among activity groups of the same floodlight configuration. This field is read-only after insertion. Corresponds to the JSON property tagString

Returns:

  • (String)


7634
7635
7636
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7634

def tag_string
  @tag_string
end

#typeString

Type of the floodlight activity group. This is a required field that is read- only after insertion. Corresponds to the JSON property type

Returns:

  • (String)


7640
7641
7642
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7640

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7647
7648
7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7647

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @floodlight_configuration_id = args[:floodlight_configuration_id] if args.key?(:floodlight_configuration_id)
  @floodlight_configuration_id_dimension_value = args[:floodlight_configuration_id_dimension_value] if args.key?(:floodlight_configuration_id_dimension_value)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @tag_string = args[:tag_string] if args.key?(:tag_string)
  @type = args[:type] if args.key?(:type)
end