Class: Google::Apis::DfareportingV4::FloodlightConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains properties of a Floodlight configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightConfiguration

Returns a new instance of FloodlightConfiguration.



7850
7851
7852
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this floodlight configuration. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


7756
7757
7758
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7756

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of the parent advertiser of this floodlight configuration. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7761
7762
7763
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7761

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



7766
7767
7768
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7766

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#analytics_data_sharing_enabledBoolean Also known as: analytics_data_sharing_enabled?

Whether advertiser data is shared with Google Analytics. Corresponds to the JSON property analyticsDataSharingEnabled

Returns:

  • (Boolean)


7771
7772
7773
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7771

def analytics_data_sharing_enabled
  @analytics_data_sharing_enabled
end

#custom_viewability_metricGoogle::Apis::DfareportingV4::CustomViewabilityMetric

Custom Viewability Metric Corresponds to the JSON property customViewabilityMetric



7777
7778
7779
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7777

def custom_viewability_metric
  @custom_viewability_metric
end

#exposure_to_conversion_enabledBoolean Also known as: exposure_to_conversion_enabled?

Whether the exposure-to-conversion report is enabled. This report shows detailed pathway information on up to 10 of the most recent ad exposures seen by a user before converting. Corresponds to the JSON property exposureToConversionEnabled

Returns:

  • (Boolean)


7784
7785
7786
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7784

def exposure_to_conversion_enabled
  @exposure_to_conversion_enabled
end

#first_day_of_weekString

Corresponds to the JSON property firstDayOfWeek

Returns:

  • (String)


7790
7791
7792
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7790

def first_day_of_week
  @first_day_of_week
end

#idFixnum

ID of this floodlight configuration. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7795
7796
7797
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7795

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



7800
7801
7802
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7800

def id_dimension_value
  @id_dimension_value
end

#in_app_attribution_tracking_enabledBoolean Also known as: in_app_attribution_tracking_enabled?

Whether in-app attribution tracking is enabled. Corresponds to the JSON property inAppAttributionTrackingEnabled

Returns:

  • (Boolean)


7805
7806
7807
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7805

def in_app_attribution_tracking_enabled
  @in_app_attribution_tracking_enabled
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#floodlightConfiguration". Corresponds to the JSON property kind

Returns:

  • (String)


7812
7813
7814
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7812

def kind
  @kind
end

#lookback_configurationGoogle::Apis::DfareportingV4::LookbackConfiguration

Lookback configuration settings. Corresponds to the JSON property lookbackConfiguration



7817
7818
7819
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7817

def lookback_configuration
  @lookback_configuration
end

#natural_search_conversion_attribution_optionString

Types of attribution options for natural search conversions. Corresponds to the JSON property naturalSearchConversionAttributionOption

Returns:

  • (String)


7822
7823
7824
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7822

def natural_search_conversion_attribution_option
  @natural_search_conversion_attribution_option
end

#omniture_settingsGoogle::Apis::DfareportingV4::OmnitureSettings

Omniture Integration Settings. Corresponds to the JSON property omnitureSettings



7827
7828
7829
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7827

def omniture_settings
  @omniture_settings
end

#subaccount_idFixnum

Subaccount ID of this floodlight configuration. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


7833
7834
7835
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7833

def subaccount_id
  @subaccount_id
end

#tag_settingsGoogle::Apis::DfareportingV4::TagSettings

Dynamic and Image Tag Settings. Corresponds to the JSON property tagSettings



7838
7839
7840
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7838

def tag_settings
  @tag_settings
end

#third_party_authentication_tokensArray<Google::Apis::DfareportingV4::ThirdPartyAuthenticationToken>

List of third-party authentication tokens enabled for this configuration. Corresponds to the JSON property thirdPartyAuthenticationTokens



7843
7844
7845
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7843

def third_party_authentication_tokens
  @third_party_authentication_tokens
end

#user_defined_variable_configurationsArray<Google::Apis::DfareportingV4::UserDefinedVariableConfiguration>

List of user defined variables enabled for this configuration. Corresponds to the JSON property userDefinedVariableConfigurations



7848
7849
7850
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7848

def user_defined_variable_configurations
  @user_defined_variable_configurations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 7855

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @analytics_data_sharing_enabled = args[:analytics_data_sharing_enabled] if args.key?(:analytics_data_sharing_enabled)
  @custom_viewability_metric = args[:custom_viewability_metric] if args.key?(:custom_viewability_metric)
  @exposure_to_conversion_enabled = args[:exposure_to_conversion_enabled] if args.key?(:exposure_to_conversion_enabled)
  @first_day_of_week = args[:first_day_of_week] if args.key?(:first_day_of_week)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @in_app_attribution_tracking_enabled = args[:in_app_attribution_tracking_enabled] if args.key?(:in_app_attribution_tracking_enabled)
  @kind = args[:kind] if args.key?(:kind)
  @lookback_configuration = args[:lookback_configuration] if args.key?(:lookback_configuration)
  @natural_search_conversion_attribution_option = args[:natural_search_conversion_attribution_option] if args.key?(:natural_search_conversion_attribution_option)
  @omniture_settings = args[:omniture_settings] if args.key?(:omniture_settings)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @tag_settings = args[:tag_settings] if args.key?(:tag_settings)
  @third_party_authentication_tokens = args[:third_party_authentication_tokens] if args.key?(:third_party_authentication_tokens)
  @user_defined_variable_configurations = args[:user_defined_variable_configurations] if args.key?(:user_defined_variable_configurations)
end