Class: Google::Apis::DfareportingV4::IngestionErrorRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains the ingestion error record of the dynamic feed. limited to 100 records.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestionErrorRecord

Returns a new instance of IngestionErrorRecord.



8098
8099
8100
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::DfareportingV4::FieldError>

Output only. The list of field errors of the ingestion error record. Corresponds to the JSON property errors



8091
8092
8093
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8091

def errors
  @errors
end

#record_idString

Output only. The record ID of the ingestion error record. Corresponds to the JSON property recordId

Returns:

  • (String)


8096
8097
8098
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8096

def record_id
  @record_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8103
8104
8105
8106
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8103

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
  @record_id = args[:record_id] if args.key?(:record_id)
end