Class: Google::Apis::DfareportingV4::Invoice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains information about a single invoice

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Invoice

Returns a new instance of Invoice.



8428
8429
8430
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_summariesArray<Google::Apis::DfareportingV4::CampaignSummary>

The list of summarized campaign information associated with this invoice. Corresponds to the JSON property campaign_summaries



8331
8332
8333
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8331

def campaign_summaries
  @campaign_summaries
end

#corrected_invoice_idString

The originally issued invoice that is being adjusted by this invoice, if applicable. May appear on invoice PDF as Reference invoice number. Corresponds to the JSON property correctedInvoiceId

Returns:

  • (String)


8337
8338
8339
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8337

def corrected_invoice_id
  @corrected_invoice_id
end

#currency_codeString

Invoice currency code in ISO 4217 format. Corresponds to the JSON property currencyCode

Returns:

  • (String)


8342
8343
8344
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8342

def currency_code
  @currency_code
end

#due_dateString

The invoice due date. Corresponds to the JSON property dueDate

Returns:

  • (String)


8347
8348
8349
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8347

def due_date
  @due_date
end

#idString

ID of this invoice. Corresponds to the JSON property id

Returns:

  • (String)


8352
8353
8354
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8352

def id
  @id
end

#invoice_typeString

The type of invoice document. Corresponds to the JSON property invoiceType

Returns:

  • (String)


8357
8358
8359
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8357

def invoice_type
  @invoice_type
end

#issue_dateString

The date when the invoice was issued. Corresponds to the JSON property issueDate

Returns:

  • (String)


8362
8363
8364
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8362

def issue_date
  @issue_date
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#invoice". Corresponds to the JSON property kind

Returns:

  • (String)


8368
8369
8370
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8368

def kind
  @kind
end

#payments_account_idString

The ID of the payments account the invoice belongs to. Appears on the invoice PDF as Billing Account Number. Corresponds to the JSON property paymentsAccountId

Returns:

  • (String)


8374
8375
8376
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8374

def 
  @payments_account_id
end

#payments_profile_idString

The ID of the payments profile the invoice belongs to. Appears on the invoice PDF as Billing ID. Corresponds to the JSON property paymentsProfileId

Returns:

  • (String)


8380
8381
8382
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8380

def payments_profile_id
  @payments_profile_id
end

#pdf_urlString

The URL to download a PDF copy of the invoice. Note that this URL is user specific and requires a valid OAuth 2.0 access token to access. The access token must be provided in an Authorization: Bearer HTTP header. The URL will only be usable for 7 days from when the api is called. Corresponds to the JSON property pdfUrl

Returns:

  • (String)


8388
8389
8390
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8388

def pdf_url
  @pdf_url
end

#purchase_order_numberString

Purchase order number associated with the invoice. Corresponds to the JSON property purchaseOrderNumber

Returns:

  • (String)


8393
8394
8395
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8393

def purchase_order_number
  @purchase_order_number
end

#replaced_invoice_idsArray<String>

The originally issued invoice(s) that is being cancelled by this invoice, if applicable. May appear on invoice PDF as Replaced invoice numbers. Note: There may be multiple replaced invoices due to consolidation of multiple invoices into a single invoice. Corresponds to the JSON property replacedInvoiceIds

Returns:

  • (Array<String>)


8401
8402
8403
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8401

def replaced_invoice_ids
  @replaced_invoice_ids
end

#service_end_dateString

The invoice service end date. Corresponds to the JSON property serviceEndDate

Returns:

  • (String)


8406
8407
8408
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8406

def service_end_date
  @service_end_date
end

#service_start_dateString

The invoice service start date. Corresponds to the JSON property serviceStartDate

Returns:

  • (String)


8411
8412
8413
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8411

def service_start_date
  @service_start_date
end

#subtotal_amount_microsFixnum

The pre-tax subtotal amount, in micros of the invoice's currency. Corresponds to the JSON property subtotalAmountMicros

Returns:

  • (Fixnum)


8416
8417
8418
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8416

def subtotal_amount_micros
  @subtotal_amount_micros
end

#total_amount_microsFixnum

The invoice total amount, in micros of the invoice's currency. Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


8421
8422
8423
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8421

def total_amount_micros
  @total_amount_micros
end

#total_tax_amount_microsFixnum

The sum of all taxes in invoice, in micros of the invoice's currency. Corresponds to the JSON property totalTaxAmountMicros

Returns:

  • (Fixnum)


8426
8427
8428
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8426

def total_tax_amount_micros
  @total_tax_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8433
8434
8435
8436
8437
8438
8439
8440
8441
8442
8443
8444
8445
8446
8447
8448
8449
8450
8451
8452
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8433

def update!(**args)
  @campaign_summaries = args[:campaign_summaries] if args.key?(:campaign_summaries)
  @corrected_invoice_id = args[:corrected_invoice_id] if args.key?(:corrected_invoice_id)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @due_date = args[:due_date] if args.key?(:due_date)
  @id = args[:id] if args.key?(:id)
  @invoice_type = args[:invoice_type] if args.key?(:invoice_type)
  @issue_date = args[:issue_date] if args.key?(:issue_date)
  @kind = args[:kind] if args.key?(:kind)
  @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id)
  @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id)
  @pdf_url = args[:pdf_url] if args.key?(:pdf_url)
  @purchase_order_number = args[:purchase_order_number] if args.key?(:purchase_order_number)
  @replaced_invoice_ids = args[:replaced_invoice_ids] if args.key?(:replaced_invoice_ids)
  @service_end_date = args[:service_end_date] if args.key?(:service_end_date)
  @service_start_date = args[:service_start_date] if args.key?(:service_start_date)
  @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
  @total_tax_amount_micros = args[:total_tax_amount_micros] if args.key?(:total_tax_amount_micros)
end