Class: Google::Apis::DfareportingV4::LandingPage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains information about where a user's browser is taken after the user clicks an ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LandingPage

Returns a new instance of LandingPage.



8517
8518
8519
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Advertiser ID of this landing page. This is a required field. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


8482
8483
8484
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8482

def advertiser_id
  @advertiser_id
end

#archivedBoolean Also known as: archived?

Whether this landing page has been archived. Corresponds to the JSON property archived

Returns:

  • (Boolean)


8487
8488
8489
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8487

def archived
  @archived
end

Links that will direct the user to a mobile app, if installed. Corresponds to the JSON property deepLinks



8493
8494
8495
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8493

def deep_links
  @deep_links
end

#idFixnum

ID of this landing page. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


8498
8499
8500
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8498

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#landingPage". Corresponds to the JSON property kind

Returns:

  • (String)


8504
8505
8506
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8504

def kind
  @kind
end

#nameString

Name of this landing page. This is a required field. It must be less than 256 characters long. Corresponds to the JSON property name

Returns:

  • (String)


8510
8511
8512
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8510

def name
  @name
end

#urlString

URL of this landing page. This is a required field. Corresponds to the JSON property url

Returns:

  • (String)


8515
8516
8517
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8515

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8522
8523
8524
8525
8526
8527
8528
8529
8530
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8522

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @archived = args[:archived] if args.key?(:archived)
  @deep_links = args[:deep_links] if args.key?(:deep_links)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @url = args[:url] if args.key?(:url)
end