Class: Google::Apis::DfareportingV4::ListPopulationClause
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::ListPopulationClause
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
A group clause made up of list population terms representing constraints joined by ORs.
Instance Attribute Summary collapse
-
#terms ⇒ Array<Google::Apis::DfareportingV4::ListPopulationTerm>
Terms of this list population clause.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPopulationClause
constructor
A new instance of ListPopulationClause.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPopulationClause
Returns a new instance of ListPopulationClause.
8651 8652 8653 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#terms ⇒ Array<Google::Apis::DfareportingV4::ListPopulationTerm>
Terms of this list population clause. Each clause is made up of list
population terms representing constraints and are joined by ORs.
Corresponds to the JSON property terms
8649 8650 8651 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8649 def terms @terms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8656 8657 8658 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8656 def update!(**args) @terms = args[:terms] if args.key?(:terms) end |