Class: Google::Apis::DfareportingV4::ListPopulationRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Remarketing List Population Rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPopulationRule

Returns a new instance of ListPopulationRule.



8683
8684
8685
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activity_idFixnum

Floodlight activity ID associated with this rule. This field can be left blank. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


8668
8669
8670
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8668

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_activity_nameString

Name of floodlight activity associated with this rule. This is a read-only, auto-generated field. Corresponds to the JSON property floodlightActivityName

Returns:

  • (String)


8674
8675
8676
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8674

def floodlight_activity_name
  @floodlight_activity_name
end

#list_population_clausesArray<Google::Apis::DfareportingV4::ListPopulationClause>

Clauses that make up this list population rule. Clauses are joined by ANDs, and the clauses themselves are made up of list population terms which are joined by ORs. Corresponds to the JSON property listPopulationClauses



8681
8682
8683
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8681

def list_population_clauses
  @list_population_clauses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8688
8689
8690
8691
8692
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8688

def update!(**args)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_activity_name = args[:floodlight_activity_name] if args.key?(:floodlight_activity_name)
  @list_population_clauses = args[:list_population_clauses] if args.key?(:list_population_clauses)
end