Class: Google::Apis::DfareportingV4::Metro

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains information about a metro region that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Metro

Returns a new instance of Metro.



8987
8988
8989
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Country code of the country to which this metro region belongs. Corresponds to the JSON property countryCode

Returns:

  • (String)


8953
8954
8955
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8953

def country_code
  @country_code
end

#country_dart_idFixnum

DART ID of the country to which this metro region belongs. Corresponds to the JSON property countryDartId

Returns:

  • (Fixnum)


8958
8959
8960
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8958

def country_dart_id
  @country_dart_id
end

#dart_idFixnum

DART ID of this metro region. Corresponds to the JSON property dartId

Returns:

  • (Fixnum)


8963
8964
8965
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8963

def dart_id
  @dart_id
end

#dma_idFixnum

DMA ID of this metro region. This is the ID used for targeting and generating reports, and is equivalent to metro_code. Corresponds to the JSON property dmaId

Returns:

  • (Fixnum)


8969
8970
8971
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8969

def dma_id
  @dma_id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#metro". Corresponds to the JSON property kind

Returns:

  • (String)


8975
8976
8977
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8975

def kind
  @kind
end

#metro_codeString

Metro code of this metro region. This is equivalent to dma_id. Corresponds to the JSON property metroCode

Returns:

  • (String)


8980
8981
8982
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8980

def metro_code
  @metro_code
end

#nameString

Name of this metro region. Corresponds to the JSON property name

Returns:

  • (String)


8985
8986
8987
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8985

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8992
8993
8994
8995
8996
8997
8998
8999
9000
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8992

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @country_dart_id = args[:country_dart_id] if args.key?(:country_dart_id)
  @dart_id = args[:dart_id] if args.key?(:dart_id)
  @dma_id = args[:dma_id] if args.key?(:dma_id)
  @kind = args[:kind] if args.key?(:kind)
  @metro_code = args[:metro_code] if args.key?(:metro_code)
  @name = args[:name] if args.key?(:name)
end