Class: Google::Apis::DfareportingV4::MobileAppsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::MobileAppsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Mobile app List Response
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#mobile_apps ⇒ Array<Google::Apis::DfareportingV4::MobileApp>
Mobile apps collection.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MobileAppsListResponse
constructor
A new instance of MobileAppsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MobileAppsListResponse
Returns a new instance of MobileAppsListResponse.
9093 9094 9095 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#mobileAppsListResponse".
Corresponds to the JSON property kind
9081 9082 9083 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9081 def kind @kind end |
#mobile_apps ⇒ Array<Google::Apis::DfareportingV4::MobileApp>
Mobile apps collection.
Corresponds to the JSON property mobileApps
9086 9087 9088 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9086 def mobile_apps @mobile_apps end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
9091 9092 9093 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9091 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9098 9099 9100 9101 9102 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9098 def update!(**args) @kind = args[:kind] if args.key?(:kind) @mobile_apps = args[:mobile_apps] if args.key?(:mobile_apps) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |