Class: Google::Apis::DfareportingV4::ObaIcon
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::ObaIcon
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Online Behavioral Advertiser icon.
Instance Attribute Summary collapse
-
#icon_click_through_url ⇒ String
URL to redirect to when an OBA icon is clicked.
-
#icon_click_tracking_url ⇒ String
URL to track click when an OBA icon is clicked.
-
#icon_view_tracking_url ⇒ String
URL to track view when an OBA icon is clicked.
-
#program ⇒ String
Identifies the industry initiative that the icon supports.
-
#resource_url ⇒ String
OBA icon resource URL.
-
#size ⇒ Google::Apis::DfareportingV4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#x_position ⇒ String
OBA icon x coordinate position.
-
#y_position ⇒ String
OBA icon y coordinate position.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObaIcon
constructor
A new instance of ObaIcon.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObaIcon
Returns a new instance of ObaIcon.
9221 9222 9223 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#icon_click_through_url ⇒ String
URL to redirect to when an OBA icon is clicked.
Corresponds to the JSON property iconClickThroughUrl
9182 9183 9184 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9182 def icon_click_through_url @icon_click_through_url end |
#icon_click_tracking_url ⇒ String
URL to track click when an OBA icon is clicked.
Corresponds to the JSON property iconClickTrackingUrl
9187 9188 9189 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9187 def icon_click_tracking_url @icon_click_tracking_url end |
#icon_view_tracking_url ⇒ String
URL to track view when an OBA icon is clicked.
Corresponds to the JSON property iconViewTrackingUrl
9192 9193 9194 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9192 def icon_view_tracking_url @icon_view_tracking_url end |
#program ⇒ String
Identifies the industry initiative that the icon supports. For example,
AdChoices.
Corresponds to the JSON property program
9198 9199 9200 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9198 def program @program end |
#resource_url ⇒ String
OBA icon resource URL. Campaign Manager only supports image and JavaScript
icons. Learn more
Corresponds to the JSON property resourceUrl
9204 9205 9206 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9204 def resource_url @resource_url end |
#size ⇒ Google::Apis::DfareportingV4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property size
9209 9210 9211 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9209 def size @size end |
#x_position ⇒ String
OBA icon x coordinate position. Accepted values are left or right.
Corresponds to the JSON property xPosition
9214 9215 9216 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9214 def x_position @x_position end |
#y_position ⇒ String
OBA icon y coordinate position. Accepted values are top or bottom.
Corresponds to the JSON property yPosition
9219 9220 9221 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9219 def y_position @y_position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9226 9227 9228 9229 9230 9231 9232 9233 9234 9235 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9226 def update!(**args) @icon_click_through_url = args[:icon_click_through_url] if args.key?(:icon_click_through_url) @icon_click_tracking_url = args[:icon_click_tracking_url] if args.key?(:icon_click_tracking_url) @icon_view_tracking_url = args[:icon_view_tracking_url] if args.key?(:icon_view_tracking_url) @program = args[:program] if args.key?(:program) @resource_url = args[:resource_url] if args.key?(:resource_url) @size = args[:size] if args.key?(:size) @x_position = args[:x_position] if args.key?(:x_position) @y_position = args[:y_position] if args.key?(:y_position) end |