Class: Google::Apis::DfareportingV4::OfflineUserAddressInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Identify a user by name and address.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OfflineUserAddressInfo

Returns a new instance of OfflineUserAddressInfo.



9315
9316
9317
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cityString

City of the address. Corresponds to the JSON property city

Returns:

  • (String)


9280
9281
9282
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9280

def city
  @city
end

#country_codeString

2-letter country code in ISO-3166-1 alpha-2 of the user's address. Corresponds to the JSON property countryCode

Returns:

  • (String)


9285
9286
9287
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9285

def country_code
  @country_code
end

#hashed_first_nameString

First name of the user, which is hashed as SHA-256 after normalized (Lowercase all characters; Remove any extra spaces before, after, and in between). Corresponds to the JSON property hashedFirstName

Returns:

  • (String)


9291
9292
9293
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9291

def hashed_first_name
  @hashed_first_name
end

#hashed_last_nameString

Last name of the user, which is hashed as SHA-256 after normalized (lower case only and no punctuation). Corresponds to the JSON property hashedLastName

Returns:

  • (String)


9297
9298
9299
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9297

def hashed_last_name
  @hashed_last_name
end

#hashed_street_addressString

The street address of the user hashed using SHA-256 hash function after normalization (lower case only). Corresponds to the JSON property hashedStreetAddress

Returns:

  • (String)


9303
9304
9305
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9303

def hashed_street_address
  @hashed_street_address
end

#postal_codeString

Postal code of the user's address. Corresponds to the JSON property postalCode

Returns:

  • (String)


9308
9309
9310
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9308

def postal_code
  @postal_code
end

#stateString

State code of the address. Corresponds to the JSON property state

Returns:

  • (String)


9313
9314
9315
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9313

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9320
9321
9322
9323
9324
9325
9326
9327
9328
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9320

def update!(**args)
  @city = args[:city] if args.key?(:city)
  @country_code = args[:country_code] if args.key?(:country_code)
  @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name)
  @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name)
  @hashed_street_address = args[:hashed_street_address] if args.key?(:hashed_street_address)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @state = args[:state] if args.key?(:state)
end