Class: Google::Apis::DfareportingV4::OffsetPosition
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::OffsetPosition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Offset Position.
Instance Attribute Summary collapse
-
#left ⇒ Fixnum
Offset distance from left side of an asset or a window.
-
#top ⇒ Fixnum
Offset distance from top side of an asset or a window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OffsetPosition
constructor
A new instance of OffsetPosition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OffsetPosition
Returns a new instance of OffsetPosition.
9345 9346 9347 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9345 def initialize(**args) update!(**args) end |
Instance Attribute Details
#left ⇒ Fixnum
Offset distance from left side of an asset or a window.
Corresponds to the JSON property left
9338 9339 9340 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9338 def left @left end |
#top ⇒ Fixnum
Offset distance from top side of an asset or a window.
Corresponds to the JSON property top
9343 9344 9345 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9343 def top @top end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9350 9351 9352 9353 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9350 def update!(**args) @left = args[:left] if args.key?(:left) @top = args[:top] if args.key?(:top) end |