Class: Google::Apis::DfareportingV4::OperatingSystemVersion
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::OperatingSystemVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains information about a particular version of an operating system that can be targeted by ads.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
ID of this operating system version.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#major_version ⇒ String
Major version (leftmost number) of this operating system version.
-
#minor_version ⇒ String
Minor version (number after the first dot) of this operating system version.
-
#name ⇒ String
Name of this operating system version.
-
#operating_system ⇒ Google::Apis::DfareportingV4::OperatingSystem
Contains information about an operating system that can be targeted by ads.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperatingSystemVersion
constructor
A new instance of OperatingSystemVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperatingSystemVersion
Returns a new instance of OperatingSystemVersion.
9467 9468 9469 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
ID of this operating system version.
Corresponds to the JSON property id
9439 9440 9441 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9439 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#operatingSystemVersion".
Corresponds to the JSON property kind
9445 9446 9447 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9445 def kind @kind end |
#major_version ⇒ String
Major version (leftmost number) of this operating system version.
Corresponds to the JSON property majorVersion
9450 9451 9452 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9450 def major_version @major_version end |
#minor_version ⇒ String
Minor version (number after the first dot) of this operating system version.
Corresponds to the JSON property minorVersion
9455 9456 9457 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9455 def minor_version @minor_version end |
#name ⇒ String
Name of this operating system version.
Corresponds to the JSON property name
9460 9461 9462 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9460 def name @name end |
#operating_system ⇒ Google::Apis::DfareportingV4::OperatingSystem
Contains information about an operating system that can be targeted by ads.
Corresponds to the JSON property operatingSystem
9465 9466 9467 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9465 def @operating_system end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9472 9473 9474 9475 9476 9477 9478 9479 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9472 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @major_version = args[:major_version] if args.key?(:major_version) @minor_version = args[:minor_version] if args.key?(:minor_version) @name = args[:name] if args.key?(:name) @operating_system = args[:operating_system] if args.key?(:operating_system) end |