Class: Google::Apis::DfareportingV4::OptimizationActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Creative optimization activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OptimizationActivity

Returns a new instance of OptimizationActivity.



9555
9556
9557
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activity_idFixnum

Floodlight activity ID of this optimization activity. This is a required field. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


9541
9542
9543
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9541

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_activity_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightActivityIdDimensionValue



9546
9547
9548
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9546

def floodlight_activity_id_dimension_value
  @floodlight_activity_id_dimension_value
end

#weightFixnum

Weight associated with this optimization. The weight assigned will be understood in proportion to the weights assigned to the other optimization activities. Value must be greater than or equal to 1. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


9553
9554
9555
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9553

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9560
9561
9562
9563
9564
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9560

def update!(**args)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_activity_id_dimension_value = args[:floodlight_activity_id_dimension_value] if args.key?(:floodlight_activity_id_dimension_value)
  @weight = args[:weight] if args.key?(:weight)
end