Class: Google::Apis::DfareportingV4::Order

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Describes properties of a Planning order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Order

Returns a new instance of Order.



9672
9673
9674
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this order. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


9574
9575
9576
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9574

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this order. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


9579
9580
9581
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9579

def advertiser_id
  @advertiser_id
end

#approver_user_profile_idsArray<Fixnum>

IDs for users that have to approve documents created for this order. Corresponds to the JSON property approverUserProfileIds

Returns:

  • (Array<Fixnum>)


9584
9585
9586
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9584

def 
  @approver_user_profile_ids
end

#buyer_invoice_idString

Buyer invoice ID associated with this order. Corresponds to the JSON property buyerInvoiceId

Returns:

  • (String)


9589
9590
9591
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9589

def buyer_invoice_id
  @buyer_invoice_id
end

#buyer_organization_nameString

Name of the buyer organization. Corresponds to the JSON property buyerOrganizationName

Returns:

  • (String)


9594
9595
9596
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9594

def buyer_organization_name
  @buyer_organization_name
end

#commentsString

Comments in this order. Corresponds to the JSON property comments

Returns:

  • (String)


9599
9600
9601
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9599

def comments
  @comments
end

#contactsArray<Google::Apis::DfareportingV4::OrderContact>

Contacts for this order. Corresponds to the JSON property contacts



9604
9605
9606
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9604

def contacts
  @contacts
end

#idFixnum

ID of this order. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


9609
9610
9611
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9609

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#order". Corresponds to the JSON property kind

Returns:

  • (String)


9615
9616
9617
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9615

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



9620
9621
9622
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9620

def last_modified_info
  @last_modified_info
end

#nameString

Name of this order. Corresponds to the JSON property name

Returns:

  • (String)


9625
9626
9627
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9625

def name
  @name
end

#notesString

Notes of this order. Corresponds to the JSON property notes

Returns:

  • (String)


9630
9631
9632
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9630

def notes
  @notes
end

#planning_term_idFixnum

ID of the terms and conditions template used in this order. Corresponds to the JSON property planningTermId

Returns:

  • (Fixnum)


9635
9636
9637
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9635

def planning_term_id
  @planning_term_id
end

#project_idFixnum

Project ID of this order. Corresponds to the JSON property projectId

Returns:

  • (Fixnum)


9640
9641
9642
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9640

def project_id
  @project_id
end

#seller_order_idString

Seller order ID associated with this order. Corresponds to the JSON property sellerOrderId

Returns:

  • (String)


9645
9646
9647
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9645

def seller_order_id
  @seller_order_id
end

#seller_organization_nameString

Name of the seller organization. Corresponds to the JSON property sellerOrganizationName

Returns:

  • (String)


9650
9651
9652
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9650

def seller_organization_name
  @seller_organization_name
end

#site_idArray<Fixnum>

Site IDs this order is associated with. Corresponds to the JSON property siteId

Returns:

  • (Array<Fixnum>)


9655
9656
9657
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9655

def site_id
  @site_id
end

#site_namesArray<String>

Free-form site names this order is associated with. Corresponds to the JSON property siteNames

Returns:

  • (Array<String>)


9660
9661
9662
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9660

def site_names
  @site_names
end

#subaccount_idFixnum

Subaccount ID of this order. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


9665
9666
9667
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9665

def subaccount_id
  @subaccount_id
end

#terms_and_conditionsString

Terms and conditions of this order. Corresponds to the JSON property termsAndConditions

Returns:

  • (String)


9670
9671
9672
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9670

def terms_and_conditions
  @terms_and_conditions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9677
9678
9679
9680
9681
9682
9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
9694
9695
9696
9697
9698
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9677

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @approver_user_profile_ids = args[:approver_user_profile_ids] if args.key?(:approver_user_profile_ids)
  @buyer_invoice_id = args[:buyer_invoice_id] if args.key?(:buyer_invoice_id)
  @buyer_organization_name = args[:buyer_organization_name] if args.key?(:buyer_organization_name)
  @comments = args[:comments] if args.key?(:comments)
  @contacts = args[:contacts] if args.key?(:contacts)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @planning_term_id = args[:planning_term_id] if args.key?(:planning_term_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @seller_order_id = args[:seller_order_id] if args.key?(:seller_order_id)
  @seller_organization_name = args[:seller_organization_name] if args.key?(:seller_organization_name)
  @site_id = args[:site_id] if args.key?(:site_id)
  @site_names = args[:site_names] if args.key?(:site_names)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @terms_and_conditions = args[:terms_and_conditions] if args.key?(:terms_and_conditions)
end