Class: Google::Apis::DfareportingV4::OrderContact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contact of an order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrderContact

Returns a new instance of OrderContact.



9733
9734
9735
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9733

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contact_infoString

Free-form information about this contact. It could be any information related to this contact in addition to type, title, name, and signature user profile ID. Corresponds to the JSON property contactInfo

Returns:

  • (String)


9710
9711
9712
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9710

def contact_info
  @contact_info
end

#contact_nameString

Name of this contact. Corresponds to the JSON property contactName

Returns:

  • (String)


9715
9716
9717
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9715

def contact_name
  @contact_name
end

#contact_titleString

Title of this contact. Corresponds to the JSON property contactTitle

Returns:

  • (String)


9720
9721
9722
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9720

def contact_title
  @contact_title
end

#contact_typeString

Type of this contact. Corresponds to the JSON property contactType

Returns:

  • (String)


9725
9726
9727
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9725

def contact_type
  @contact_type
end

#signature_user_profile_idFixnum

ID of the user profile containing the signature that will be embedded into order documents. Corresponds to the JSON property signatureUserProfileId

Returns:

  • (Fixnum)


9731
9732
9733
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9731

def 
  @signature_user_profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9738
9739
9740
9741
9742
9743
9744
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9738

def update!(**args)
  @contact_info = args[:contact_info] if args.key?(:contact_info)
  @contact_name = args[:contact_name] if args.key?(:contact_name)
  @contact_title = args[:contact_title] if args.key?(:contact_title)
  @contact_type = args[:contact_type] if args.key?(:contact_type)
  @signature_user_profile_id = args[:signature_user_profile_id] if args.key?(:signature_user_profile_id)
end