Class: Google::Apis::DfareportingV4::PathToConversionReportCompatibleFields

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Represents fields that are compatible to be selected for a report of type " PATH_TO_CONVERSION".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PathToConversionReportCompatibleFields

Returns a new instance of PathToConversionReportCompatibleFields.



9814
9815
9816
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_dimensionsArray<Google::Apis::DfareportingV4::Dimension>

Conversion dimensions which are compatible to be selected in the " conversionDimensions" section of the report. Corresponds to the JSON property conversionDimensions



9788
9789
9790
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9788

def conversion_dimensions
  @conversion_dimensions
end

#custom_floodlight_variablesArray<Google::Apis::DfareportingV4::Dimension>

Custom floodlight variables which are compatible to be selected in the " customFloodlightVariables" section of the report. Corresponds to the JSON property customFloodlightVariables



9794
9795
9796
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9794

def custom_floodlight_variables
  @custom_floodlight_variables
end

#kindString

The kind of resource this is, in this case dfareporting# pathToConversionReportCompatibleFields. Corresponds to the JSON property kind

Returns:

  • (String)


9800
9801
9802
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9800

def kind
  @kind
end

#metricsArray<Google::Apis::DfareportingV4::Metric>

Metrics which are compatible to be selected in the "metricNames" section of the report. Corresponds to the JSON property metrics



9806
9807
9808
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9806

def metrics
  @metrics
end

#per_interaction_dimensionsArray<Google::Apis::DfareportingV4::Dimension>

Per-interaction dimensions which are compatible to be selected in the " perInteractionDimensions" section of the report. Corresponds to the JSON property perInteractionDimensions



9812
9813
9814
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9812

def per_interaction_dimensions
  @per_interaction_dimensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9819
9820
9821
9822
9823
9824
9825
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9819

def update!(**args)
  @conversion_dimensions = args[:conversion_dimensions] if args.key?(:conversion_dimensions)
  @custom_floodlight_variables = args[:custom_floodlight_variables] if args.key?(:custom_floodlight_variables)
  @kind = args[:kind] if args.key?(:kind)
  @metrics = args[:metrics] if args.key?(:metrics)
  @per_interaction_dimensions = args[:per_interaction_dimensions] if args.key?(:per_interaction_dimensions)
end