Class: Google::Apis::DfareportingV4::PlacementGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains properties of a package or roadblock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlacementGroup

Returns a new instance of PlacementGroup.



10399
10400
10401
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this placement group. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


10254
10255
10256
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10254

def 
  @account_id
end

#active_statusString

Whether this placement group is active, inactive, archived or permanently archived. Corresponds to the JSON property activeStatus

Returns:

  • (String)


10260
10261
10262
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10260

def active_status
  @active_status
end

#advertiser_idFixnum

Advertiser ID of this placement group. This is a required field on insertion. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


10265
10266
10267
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10265

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



10270
10271
10272
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10270

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#campaign_idFixnum

Campaign ID of this placement group. This field is required on insertion. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


10275
10276
10277
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10275

def campaign_id
  @campaign_id
end

#campaign_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property campaignIdDimensionValue



10280
10281
10282
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10280

def campaign_id_dimension_value
  @campaign_id_dimension_value
end

#child_placement_idsArray<Fixnum>

IDs of placements which are assigned to this placement group. This is a read- only, auto-generated field. Corresponds to the JSON property childPlacementIds

Returns:

  • (Array<Fixnum>)


10286
10287
10288
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10286

def child_placement_ids
  @child_placement_ids
end

#commentString

Comments for this placement group. Corresponds to the JSON property comment

Returns:

  • (String)


10291
10292
10293
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10291

def comment
  @comment
end

#content_category_idFixnum

ID of the content category assigned to this placement group. Corresponds to the JSON property contentCategoryId

Returns:

  • (Fixnum)


10296
10297
10298
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10296

def 
  @content_category_id
end

#create_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



10301
10302
10303
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10301

def create_info
  @create_info
end

#directory_site_idFixnum

Directory site ID associated with this placement group. On insert, you must set either this field or the site_id field to specify the site associated with this placement group. This is a required field that is read-only after insertion. Corresponds to the JSON property directorySiteId

Returns:

  • (Fixnum)


10309
10310
10311
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10309

def directory_site_id
  @directory_site_id
end

#directory_site_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property directorySiteIdDimensionValue



10314
10315
10316
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10314

def directory_site_id_dimension_value
  @directory_site_id_dimension_value
end

#external_idString

External ID for this placement. Corresponds to the JSON property externalId

Returns:

  • (String)


10319
10320
10321
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10319

def external_id
  @external_id
end

#idFixnum

ID of this placement group. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


10324
10325
10326
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10324

def id
  @id
end

#id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property idDimensionValue



10329
10330
10331
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10329

def id_dimension_value
  @id_dimension_value
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#placementGroup". Corresponds to the JSON property kind

Returns:

  • (String)


10335
10336
10337
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10335

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



10340
10341
10342
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10340

def last_modified_info
  @last_modified_info
end

#nameString

Name of this placement group. This is a required field and must be less than 256 characters long. Corresponds to the JSON property name

Returns:

  • (String)


10346
10347
10348
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10346

def name
  @name
end

#placement_group_typeString

Type of this placement group. A package is a simple group of placements that acts as a single pricing point for a group of tags. A roadblock is a group of placements that not only acts as a single pricing point, but also assumes that all the tags in it will be served at the same time. A roadblock requires one of its assigned placements to be marked as primary for reporting. This field is required on insertion. Corresponds to the JSON property placementGroupType

Returns:

  • (String)


10356
10357
10358
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10356

def placement_group_type
  @placement_group_type
end

#placement_strategy_idFixnum

ID of the placement strategy assigned to this placement group. Corresponds to the JSON property placementStrategyId

Returns:

  • (Fixnum)


10361
10362
10363
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10361

def placement_strategy_id
  @placement_strategy_id
end

#pricing_scheduleGoogle::Apis::DfareportingV4::PricingSchedule

Pricing Schedule Corresponds to the JSON property pricingSchedule



10366
10367
10368
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10366

def pricing_schedule
  @pricing_schedule
end

#primary_placement_idFixnum

ID of the primary placement, used to calculate the media cost of a roadblock ( placement group). Modifying this field will automatically modify the primary field on all affected roadblock child placements. Corresponds to the JSON property primaryPlacementId

Returns:

  • (Fixnum)


10373
10374
10375
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10373

def primary_placement_id
  @primary_placement_id
end

#primary_placement_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property primaryPlacementIdDimensionValue



10378
10379
10380
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10378

def primary_placement_id_dimension_value
  @primary_placement_id_dimension_value
end

#site_idFixnum

Site ID associated with this placement group. On insert, you must set either this field or the directorySiteId field to specify the site associated with this placement group. This is a required field that is read-only after insertion. Corresponds to the JSON property siteId

Returns:

  • (Fixnum)


10386
10387
10388
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10386

def site_id
  @site_id
end

#site_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property siteIdDimensionValue



10391
10392
10393
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10391

def site_id_dimension_value
  @site_id_dimension_value
end

#subaccount_idFixnum

Subaccount ID of this placement group. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


10397
10398
10399
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10397

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10404
10405
10406
10407
10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
10426
10427
10428
10429
10430
10431
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10404

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @active_status = args[:active_status] if args.key?(:active_status)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @campaign_id_dimension_value = args[:campaign_id_dimension_value] if args.key?(:campaign_id_dimension_value)
  @child_placement_ids = args[:child_placement_ids] if args.key?(:child_placement_ids)
  @comment = args[:comment] if args.key?(:comment)
  @content_category_id = args[:content_category_id] if args.key?(:content_category_id)
  @create_info = args[:create_info] if args.key?(:create_info)
  @directory_site_id = args[:directory_site_id] if args.key?(:directory_site_id)
  @directory_site_id_dimension_value = args[:directory_site_id_dimension_value] if args.key?(:directory_site_id_dimension_value)
  @external_id = args[:external_id] if args.key?(:external_id)
  @id = args[:id] if args.key?(:id)
  @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @placement_group_type = args[:placement_group_type] if args.key?(:placement_group_type)
  @placement_strategy_id = args[:placement_strategy_id] if args.key?(:placement_strategy_id)
  @pricing_schedule = args[:pricing_schedule] if args.key?(:pricing_schedule)
  @primary_placement_id = args[:primary_placement_id] if args.key?(:primary_placement_id)
  @primary_placement_id_dimension_value = args[:primary_placement_id_dimension_value] if args.key?(:primary_placement_id_dimension_value)
  @site_id = args[:site_id] if args.key?(:site_id)
  @site_id_dimension_value = args[:site_id_dimension_value] if args.key?(:site_id_dimension_value)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end