Class: Google::Apis::DfareportingV4::PopupWindowProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Popup Window Properties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PopupWindowProperties

Returns a new instance of PopupWindowProperties.



10759
10760
10761
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionGoogle::Apis::DfareportingV4::Size

Represents the dimensions of ads, placements, creatives, or creative assets. Corresponds to the JSON property dimension



10712
10713
10714
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10712

def dimension
  @dimension
end

#offsetGoogle::Apis::DfareportingV4::OffsetPosition

Offset Position. Corresponds to the JSON property offset



10717
10718
10719
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10717

def offset
  @offset
end

#position_typeString

Popup window position either centered or at specific coordinate. Corresponds to the JSON property positionType

Returns:

  • (String)


10722
10723
10724
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10722

def position_type
  @position_type
end

#show_address_barBoolean Also known as: show_address_bar?

Whether to display the browser address bar. Corresponds to the JSON property showAddressBar

Returns:

  • (Boolean)


10727
10728
10729
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10727

def show_address_bar
  @show_address_bar
end

#show_menu_barBoolean Also known as: show_menu_bar?

Whether to display the browser menu bar. Corresponds to the JSON property showMenuBar

Returns:

  • (Boolean)


10733
10734
10735
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10733

def show_menu_bar
  @show_menu_bar
end

#show_scroll_barBoolean Also known as: show_scroll_bar?

Whether to display the browser scroll bar. Corresponds to the JSON property showScrollBar

Returns:

  • (Boolean)


10739
10740
10741
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10739

def show_scroll_bar
  @show_scroll_bar
end

#show_status_barBoolean Also known as: show_status_bar?

Whether to display the browser status bar. Corresponds to the JSON property showStatusBar

Returns:

  • (Boolean)


10745
10746
10747
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10745

def show_status_bar
  @show_status_bar
end

#show_tool_barBoolean Also known as: show_tool_bar?

Whether to display the browser tool bar. Corresponds to the JSON property showToolBar

Returns:

  • (Boolean)


10751
10752
10753
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10751

def show_tool_bar
  @show_tool_bar
end

#titleString

Title of popup window. Corresponds to the JSON property title

Returns:

  • (String)


10757
10758
10759
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10757

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10764

def update!(**args)
  @dimension = args[:dimension] if args.key?(:dimension)
  @offset = args[:offset] if args.key?(:offset)
  @position_type = args[:position_type] if args.key?(:position_type)
  @show_address_bar = args[:show_address_bar] if args.key?(:show_address_bar)
  @show_menu_bar = args[:show_menu_bar] if args.key?(:show_menu_bar)
  @show_scroll_bar = args[:show_scroll_bar] if args.key?(:show_scroll_bar)
  @show_status_bar = args[:show_status_bar] if args.key?(:show_status_bar)
  @show_tool_bar = args[:show_tool_bar] if args.key?(:show_tool_bar)
  @title = args[:title] if args.key?(:title)
end