Class: Google::Apis::DfareportingV4::PostalCode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains information about a postal code that can be targeted by ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostalCode

Returns a new instance of PostalCode.



10807
10808
10809
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Postal code. This is equivalent to the id field. Corresponds to the JSON property code

Returns:

  • (String)


10784
10785
10786
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10784

def code
  @code
end

#country_codeString

Country code of the country to which this postal code belongs. Corresponds to the JSON property countryCode

Returns:

  • (String)


10789
10790
10791
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10789

def country_code
  @country_code
end

#country_dart_idFixnum

DART ID of the country to which this postal code belongs. Corresponds to the JSON property countryDartId

Returns:

  • (Fixnum)


10794
10795
10796
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10794

def country_dart_id
  @country_dart_id
end

#idString

ID of this postal code. Corresponds to the JSON property id

Returns:

  • (String)


10799
10800
10801
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10799

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#postalCode". Corresponds to the JSON property kind

Returns:

  • (String)


10805
10806
10807
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10805

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10812
10813
10814
10815
10816
10817
10818
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 10812

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @country_code = args[:country_code] if args.key?(:country_code)
  @country_dart_id = args[:country_dart_id] if args.key?(:country_dart_id)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
end