Class: Google::Apis::DfareportingV4::Project
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::Project
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains properties of a Planning project.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this project.
-
#advertiser_id ⇒ Fixnum
Advertiser ID of this project.
-
#audience_age_group ⇒ String
Audience age group of this project.
-
#audience_gender ⇒ String
Audience gender of this project.
-
#budget ⇒ Fixnum
Budget of this project in the currency specified by the current account.
-
#client_billing_code ⇒ String
Client billing code of this project.
-
#client_name ⇒ String
Name of the project client.
-
#end_date ⇒ Date
Corresponds to the JSON property
endDate. -
#id ⇒ Fixnum
ID of this project.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#last_modified_info ⇒ Google::Apis::DfareportingV4::LastModifiedInfo
Modification timestamp.
-
#name ⇒ String
Name of this project.
-
#overview ⇒ String
Overview of this project.
-
#start_date ⇒ Date
Corresponds to the JSON property
startDate. -
#subaccount_id ⇒ Fixnum
Subaccount ID of this project.
-
#target_clicks ⇒ Fixnum
Number of clicks that the advertiser is targeting.
-
#target_conversions ⇒ Fixnum
Number of conversions that the advertiser is targeting.
-
#target_cpa_nanos ⇒ Fixnum
CPA that the advertiser is targeting.
-
#target_cpc_nanos ⇒ Fixnum
CPC that the advertiser is targeting.
-
#target_cpm_active_view_nanos ⇒ Fixnum
vCPM from Active View that the advertiser is targeting.
-
#target_cpm_nanos ⇒ Fixnum
CPM that the advertiser is targeting.
-
#target_impressions ⇒ Fixnum
Number of impressions that the advertiser is targeting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Project
constructor
A new instance of Project.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Project
Returns a new instance of Project.
11131 11132 11133 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11131 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this project.
Corresponds to the JSON property accountId
11020 11021 11022 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11020 def account_id @account_id end |
#advertiser_id ⇒ Fixnum
Advertiser ID of this project.
Corresponds to the JSON property advertiserId
11025 11026 11027 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11025 def advertiser_id @advertiser_id end |
#audience_age_group ⇒ String
Audience age group of this project.
Corresponds to the JSON property audienceAgeGroup
11030 11031 11032 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11030 def audience_age_group @audience_age_group end |
#audience_gender ⇒ String
Audience gender of this project.
Corresponds to the JSON property audienceGender
11035 11036 11037 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11035 def audience_gender @audience_gender end |
#budget ⇒ Fixnum
Budget of this project in the currency specified by the current account. The
value stored in this field represents only the non-fractional amount. For
example, for USD, the smallest value that can be represented by this field is
1 US dollar.
Corresponds to the JSON property budget
11043 11044 11045 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11043 def budget @budget end |
#client_billing_code ⇒ String
Client billing code of this project.
Corresponds to the JSON property clientBillingCode
11048 11049 11050 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11048 def client_billing_code @client_billing_code end |
#client_name ⇒ String
Name of the project client.
Corresponds to the JSON property clientName
11053 11054 11055 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11053 def client_name @client_name end |
#end_date ⇒ Date
Corresponds to the JSON property endDate
11058 11059 11060 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11058 def end_date @end_date end |
#id ⇒ Fixnum
ID of this project. This is a read-only, auto-generated field.
Corresponds to the JSON property id
11063 11064 11065 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11063 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#project".
Corresponds to the JSON property kind
11069 11070 11071 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11069 def kind @kind end |
#last_modified_info ⇒ Google::Apis::DfareportingV4::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property lastModifiedInfo
11074 11075 11076 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11074 def last_modified_info @last_modified_info end |
#name ⇒ String
Name of this project.
Corresponds to the JSON property name
11079 11080 11081 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11079 def name @name end |
#overview ⇒ String
Overview of this project.
Corresponds to the JSON property overview
11084 11085 11086 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11084 def overview @overview end |
#start_date ⇒ Date
Corresponds to the JSON property startDate
11089 11090 11091 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11089 def start_date @start_date end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this project.
Corresponds to the JSON property subaccountId
11094 11095 11096 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11094 def subaccount_id @subaccount_id end |
#target_clicks ⇒ Fixnum
Number of clicks that the advertiser is targeting.
Corresponds to the JSON property targetClicks
11099 11100 11101 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11099 def target_clicks @target_clicks end |
#target_conversions ⇒ Fixnum
Number of conversions that the advertiser is targeting.
Corresponds to the JSON property targetConversions
11104 11105 11106 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11104 def target_conversions @target_conversions end |
#target_cpa_nanos ⇒ Fixnum
CPA that the advertiser is targeting.
Corresponds to the JSON property targetCpaNanos
11109 11110 11111 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11109 def target_cpa_nanos @target_cpa_nanos end |
#target_cpc_nanos ⇒ Fixnum
CPC that the advertiser is targeting.
Corresponds to the JSON property targetCpcNanos
11114 11115 11116 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11114 def target_cpc_nanos @target_cpc_nanos end |
#target_cpm_active_view_nanos ⇒ Fixnum
vCPM from Active View that the advertiser is targeting.
Corresponds to the JSON property targetCpmActiveViewNanos
11119 11120 11121 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11119 def target_cpm_active_view_nanos @target_cpm_active_view_nanos end |
#target_cpm_nanos ⇒ Fixnum
CPM that the advertiser is targeting.
Corresponds to the JSON property targetCpmNanos
11124 11125 11126 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11124 def target_cpm_nanos @target_cpm_nanos end |
#target_impressions ⇒ Fixnum
Number of impressions that the advertiser is targeting.
Corresponds to the JSON property targetImpressions
11129 11130 11131 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11129 def target_impressions @target_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11136 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @audience_age_group = args[:audience_age_group] if args.key?(:audience_age_group) @audience_gender = args[:audience_gender] if args.key?(:audience_gender) @budget = args[:budget] if args.key?(:budget) @client_billing_code = args[:client_billing_code] if args.key?(:client_billing_code) @client_name = args[:client_name] if args.key?(:client_name) @end_date = args[:end_date] if args.key?(:end_date) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info) @name = args[:name] if args.key?(:name) @overview = args[:overview] if args.key?(:overview) @start_date = args[:start_date] if args.key?(:start_date) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) @target_clicks = args[:target_clicks] if args.key?(:target_clicks) @target_conversions = args[:target_conversions] if args.key?(:target_conversions) @target_cpa_nanos = args[:target_cpa_nanos] if args.key?(:target_cpa_nanos) @target_cpc_nanos = args[:target_cpc_nanos] if args.key?(:target_cpc_nanos) @target_cpm_active_view_nanos = args[:target_cpm_active_view_nanos] if args.key?(:target_cpm_active_view_nanos) @target_cpm_nanos = args[:target_cpm_nanos] if args.key?(:target_cpm_nanos) @target_impressions = args[:target_impressions] if args.key?(:target_impressions) end |