Class: Google::Apis::DfareportingV4::ReachReportCompatibleFields

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Represents fields that are compatible to be selected for a report of type " REACH".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReachReportCompatibleFields

Returns a new instance of ReachReportCompatibleFields.



11272
11273
11274
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_filtersArray<Google::Apis::DfareportingV4::Dimension>

Dimensions which are compatible to be selected in the "dimensionFilters" section of the report. Corresponds to the JSON property dimensionFilters



11240
11241
11242
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11240

def dimension_filters
  @dimension_filters
end

#dimensionsArray<Google::Apis::DfareportingV4::Dimension>

Dimensions which are compatible to be selected in the "dimensions" section of the report. Corresponds to the JSON property dimensions



11246
11247
11248
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11246

def dimensions
  @dimensions
end

#kindString

The kind of resource this is, in this case dfareporting# reachReportCompatibleFields. Corresponds to the JSON property kind

Returns:

  • (String)


11252
11253
11254
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11252

def kind
  @kind
end

#metricsArray<Google::Apis::DfareportingV4::Metric>

Metrics which are compatible to be selected in the "metricNames" section of the report. Corresponds to the JSON property metrics



11258
11259
11260
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11258

def metrics
  @metrics
end

#pivoted_activity_metricsArray<Google::Apis::DfareportingV4::Metric>

Metrics which are compatible to be selected as activity metrics to pivot on in the "activities" section of the report. Corresponds to the JSON property pivotedActivityMetrics



11264
11265
11266
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11264

def pivoted_activity_metrics
  @pivoted_activity_metrics
end

#reach_by_frequency_metricsArray<Google::Apis::DfareportingV4::Metric>

Metrics which are compatible to be selected in the " reachByFrequencyMetricNames" section of the report. Corresponds to the JSON property reachByFrequencyMetrics



11270
11271
11272
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11270

def reach_by_frequency_metrics
  @reach_by_frequency_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11277
11278
11279
11280
11281
11282
11283
11284
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11277

def update!(**args)
  @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @kind = args[:kind] if args.key?(:kind)
  @metrics = args[:metrics] if args.key?(:metrics)
  @pivoted_activity_metrics = args[:pivoted_activity_metrics] if args.key?(:pivoted_activity_metrics)
  @reach_by_frequency_metrics = args[:reach_by_frequency_metrics] if args.key?(:reach_by_frequency_metrics)
end