Class: Google::Apis::DfareportingV4::Recipient
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::Recipient
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Represents a recipient.
Instance Attribute Summary collapse
-
#delivery_type ⇒ String
The delivery type for the recipient.
-
#email ⇒ String
The email address of the recipient.
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting#recipient.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Recipient
constructor
A new instance of Recipient.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Recipient
Returns a new instance of Recipient.
11306 11307 11308 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11306 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delivery_type ⇒ String
The delivery type for the recipient.
Corresponds to the JSON property deliveryType
11294 11295 11296 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11294 def delivery_type @delivery_type end |
#email ⇒ String
The email address of the recipient.
Corresponds to the JSON property email
11299 11300 11301 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11299 def email @email end |
#kind ⇒ String
The kind of resource this is, in this case dfareporting#recipient.
Corresponds to the JSON property kind
11304 11305 11306 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11304 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11311 11312 11313 11314 11315 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11311 def update!(**args) @delivery_type = args[:delivery_type] if args.key?(:delivery_type) @email = args[:email] if args.key?(:email) @kind = args[:kind] if args.key?(:kind) end |