Class: Google::Apis::DfareportingV4::Region
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::Region
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains information about a region that can be targeted by ads.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Country code of the country to which this region belongs.
-
#country_dart_id ⇒ Fixnum
DART ID of the country to which this region belongs.
-
#dart_id ⇒ Fixnum
DART ID of this region.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this region.
-
#region_code ⇒ String
Region code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Region
constructor
A new instance of Region.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Region
Returns a new instance of Region.
11353 11354 11355 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11353 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Country code of the country to which this region belongs.
Corresponds to the JSON property countryCode
11325 11326 11327 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11325 def country_code @country_code end |
#country_dart_id ⇒ Fixnum
DART ID of the country to which this region belongs.
Corresponds to the JSON property countryDartId
11330 11331 11332 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11330 def country_dart_id @country_dart_id end |
#dart_id ⇒ Fixnum
DART ID of this region.
Corresponds to the JSON property dartId
11335 11336 11337 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11335 def dart_id @dart_id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#region".
Corresponds to the JSON property kind
11341 11342 11343 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11341 def kind @kind end |
#name ⇒ String
Name of this region.
Corresponds to the JSON property name
11346 11347 11348 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11346 def name @name end |
#region_code ⇒ String
Region code.
Corresponds to the JSON property regionCode
11351 11352 11353 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11351 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11358 11359 11360 11361 11362 11363 11364 11365 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11358 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @country_dart_id = args[:country_dart_id] if args.key?(:country_dart_id) @dart_id = args[:dart_id] if args.key?(:dart_id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region_code = args[:region_code] if args.key?(:region_code) end |