Class: Google::Apis::DfareportingV4::RemarketingListsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::RemarketingListsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Remarketing list response
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
-
#remarketing_lists ⇒ Array<Google::Apis::DfareportingV4::RemarketingList>
Remarketing list collection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemarketingListsListResponse
constructor
A new instance of RemarketingListsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemarketingListsListResponse
Returns a new instance of RemarketingListsListResponse.
11558 11559 11560 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#remarketingListsListResponse".
Corresponds to the JSON property kind
11546 11547 11548 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11546 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
11551 11552 11553 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11551 def next_page_token @next_page_token end |
#remarketing_lists ⇒ Array<Google::Apis::DfareportingV4::RemarketingList>
Remarketing list collection.
Corresponds to the JSON property remarketingLists
11556 11557 11558 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11556 def remarketing_lists @remarketing_lists end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11563 11564 11565 11566 11567 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11563 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @remarketing_lists = args[:remarketing_lists] if args.key?(:remarketing_lists) end |