Class: Google::Apis::DfareportingV4::Report

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Represents a Report resource.

Defined Under Namespace

Classes: Criteria, CrossDimensionReachCriteria, CrossMediaReachCriteria, Delivery, FloodlightCriteria, PathToConversionCriteria, ReachCriteria, Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Report

Returns a new instance of Report.



11699
11700
11701
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

The account ID to which this report belongs. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


11602
11603
11604
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11602

def 
  @account_id
end

#criteriaGoogle::Apis::DfareportingV4::Report::Criteria

The report criteria for a report of type "STANDARD". Corresponds to the JSON property criteria



11607
11608
11609
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11607

def criteria
  @criteria
end

#cross_dimension_reach_criteriaGoogle::Apis::DfareportingV4::Report::CrossDimensionReachCriteria

The report criteria for a report of type "CROSS_DIMENSION_REACH". Corresponds to the JSON property crossDimensionReachCriteria



11612
11613
11614
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11612

def cross_dimension_reach_criteria
  @cross_dimension_reach_criteria
end

#cross_media_reach_criteriaGoogle::Apis::DfareportingV4::Report::CrossMediaReachCriteria

Optional. The report criteria for a report of type "CROSS_MEDIA_REACH". Corresponds to the JSON property crossMediaReachCriteria



11617
11618
11619
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11617

def cross_media_reach_criteria
  @cross_media_reach_criteria
end

#deliveryGoogle::Apis::DfareportingV4::Report::Delivery

The report's email delivery settings. Corresponds to the JSON property delivery



11622
11623
11624
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11622

def delivery
  @delivery
end

#etagString

The eTag of this response for caching purposes. Corresponds to the JSON property etag

Returns:

  • (String)


11627
11628
11629
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11627

def etag
  @etag
end

#file_nameString

The filename used when generating report files for this report. Corresponds to the JSON property fileName

Returns:

  • (String)


11632
11633
11634
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11632

def file_name
  @file_name
end

#floodlight_criteriaGoogle::Apis::DfareportingV4::Report::FloodlightCriteria

The report criteria for a report of type "FLOODLIGHT". Corresponds to the JSON property floodlightCriteria



11637
11638
11639
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11637

def floodlight_criteria
  @floodlight_criteria
end

#formatString

The output format of the report. If not specified, default format is "CSV". Note that the actual format in the completed report file might differ if for instance the report's size exceeds the format's capabilities. "CSV" will then be the fallback format. Corresponds to the JSON property format

Returns:

  • (String)


11645
11646
11647
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11645

def format
  @format
end

#idFixnum

The unique ID identifying this report resource. Corresponds to the JSON property id

Returns:

  • (Fixnum)


11650
11651
11652
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11650

def id
  @id
end

#kindString

The kind of resource this is, in this case dfareporting#report. Corresponds to the JSON property kind

Returns:

  • (String)


11655
11656
11657
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11655

def kind
  @kind
end

#last_modified_timeFixnum

The timestamp (in milliseconds since epoch) of when this report was last modified. Corresponds to the JSON property lastModifiedTime

Returns:

  • (Fixnum)


11661
11662
11663
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11661

def last_modified_time
  @last_modified_time
end

#nameString

The name of the report. Corresponds to the JSON property name

Returns:

  • (String)


11666
11667
11668
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11666

def name
  @name
end

#owner_profile_idFixnum

The user profile id of the owner of this report. Corresponds to the JSON property ownerProfileId

Returns:

  • (Fixnum)


11671
11672
11673
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11671

def owner_profile_id
  @owner_profile_id
end

#path_to_conversion_criteriaGoogle::Apis::DfareportingV4::Report::PathToConversionCriteria

The report criteria for a report of type "PATH_TO_CONVERSION". Corresponds to the JSON property pathToConversionCriteria



11676
11677
11678
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11676

def path_to_conversion_criteria
  @path_to_conversion_criteria
end

#reach_criteriaGoogle::Apis::DfareportingV4::Report::ReachCriteria

The report criteria for a report of type "REACH". Corresponds to the JSON property reachCriteria



11681
11682
11683
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11681

def reach_criteria
  @reach_criteria
end

#scheduleGoogle::Apis::DfareportingV4::Report::Schedule

The report's schedule. Can only be set if the report's 'dateRange' is a relative date range and the relative date range is not "TODAY". Corresponds to the JSON property schedule



11687
11688
11689
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11687

def schedule
  @schedule
end

#sub_account_idFixnum

The subaccount ID to which this report belongs if applicable. Corresponds to the JSON property subAccountId

Returns:

  • (Fixnum)


11692
11693
11694
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11692

def 
  @sub_account_id
end

#typeString

The type of the report. Corresponds to the JSON property type

Returns:

  • (String)


11697
11698
11699
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11697

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
11720
11721
11722
11723
11724
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11704

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @criteria = args[:criteria] if args.key?(:criteria)
  @cross_dimension_reach_criteria = args[:cross_dimension_reach_criteria] if args.key?(:cross_dimension_reach_criteria)
  @cross_media_reach_criteria = args[:cross_media_reach_criteria] if args.key?(:cross_media_reach_criteria)
  @delivery = args[:delivery] if args.key?(:delivery)
  @etag = args[:etag] if args.key?(:etag)
  @file_name = args[:file_name] if args.key?(:file_name)
  @floodlight_criteria = args[:floodlight_criteria] if args.key?(:floodlight_criteria)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @name = args[:name] if args.key?(:name)
  @owner_profile_id = args[:owner_profile_id] if args.key?(:owner_profile_id)
  @path_to_conversion_criteria = args[:path_to_conversion_criteria] if args.key?(:path_to_conversion_criteria)
  @reach_criteria = args[:reach_criteria] if args.key?(:reach_criteria)
  @schedule = args[:schedule] if args.key?(:schedule)
  @sub_account_id = args[:sub_account_id] if args.key?(:sub_account_id)
  @type = args[:type] if args.key?(:type)
end