Class: Google::Apis::DfareportingV4::Report::Criteria
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::Report::Criteria
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
The report criteria for a report of type "STANDARD".
Instance Attribute Summary collapse
-
#activities ⇒ Google::Apis::DfareportingV4::Activities
Represents an activity group.
-
#custom_rich_media_events ⇒ Google::Apis::DfareportingV4::CustomRichMediaEvents
Represents a Custom Rich Media Events group.
-
#date_range ⇒ Google::Apis::DfareportingV4::DateRange
Represents a date range.
-
#dimension_filters ⇒ Array<Google::Apis::DfareportingV4::DimensionValue>
The list of filters on which dimensions are filtered.
-
#dimensions ⇒ Array<Google::Apis::DfareportingV4::SortedDimension>
The list of standard dimensions the report should include.
-
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Criteria
constructor
A new instance of Criteria.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Criteria
Returns a new instance of Criteria.
11762 11763 11764 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activities ⇒ Google::Apis::DfareportingV4::Activities
Represents an activity group.
Corresponds to the JSON property activities
11733 11734 11735 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11733 def activities @activities end |
#custom_rich_media_events ⇒ Google::Apis::DfareportingV4::CustomRichMediaEvents
Represents a Custom Rich Media Events group.
Corresponds to the JSON property customRichMediaEvents
11738 11739 11740 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11738 def custom_rich_media_events @custom_rich_media_events end |
#date_range ⇒ Google::Apis::DfareportingV4::DateRange
Represents a date range.
Corresponds to the JSON property dateRange
11743 11744 11745 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11743 def date_range @date_range end |
#dimension_filters ⇒ Array<Google::Apis::DfareportingV4::DimensionValue>
The list of filters on which dimensions are filtered. Filters for different
dimensions are ANDed, filters for the same dimension are grouped together and
ORed.
Corresponds to the JSON property dimensionFilters
11750 11751 11752 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11750 def dimension_filters @dimension_filters end |
#dimensions ⇒ Array<Google::Apis::DfareportingV4::SortedDimension>
The list of standard dimensions the report should include.
Corresponds to the JSON property dimensions
11755 11756 11757 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11755 def dimensions @dimensions end |
#metric_names ⇒ Array<String>
The list of names of metrics the report should include.
Corresponds to the JSON property metricNames
11760 11761 11762 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11760 def metric_names @metric_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11767 11768 11769 11770 11771 11772 11773 11774 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11767 def update!(**args) @activities = args[:activities] if args.key?(:activities) @custom_rich_media_events = args[:custom_rich_media_events] if args.key?(:custom_rich_media_events) @date_range = args[:date_range] if args.key?(:date_range) @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters) @dimensions = args[:dimensions] if args.key?(:dimensions) @metric_names = args[:metric_names] if args.key?(:metric_names) end |