Class: Google::Apis::DfareportingV4::Report::CrossDimensionReachCriteria

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

The report criteria for a report of type "CROSS_DIMENSION_REACH".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossDimensionReachCriteria

Returns a new instance of CrossDimensionReachCriteria.



11817
11818
11819
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#breakdownArray<Google::Apis::DfareportingV4::SortedDimension>

The list of dimensions the report should include. Corresponds to the JSON property breakdown



11784
11785
11786
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11784

def breakdown
  @breakdown
end

#date_rangeGoogle::Apis::DfareportingV4::DateRange

Represents a date range. Corresponds to the JSON property dateRange



11789
11790
11791
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11789

def date_range
  @date_range
end

#dimensionString

The dimension option. Corresponds to the JSON property dimension

Returns:

  • (String)


11794
11795
11796
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11794

def dimension
  @dimension
end

#dimension_filtersArray<Google::Apis::DfareportingV4::DimensionValue>

The list of filters on which dimensions are filtered. Corresponds to the JSON property dimensionFilters



11799
11800
11801
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11799

def dimension_filters
  @dimension_filters
end

#metric_namesArray<String>

The list of names of metrics the report should include. Corresponds to the JSON property metricNames

Returns:

  • (Array<String>)


11804
11805
11806
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11804

def metric_names
  @metric_names
end

#overlap_metric_namesArray<String>

The list of names of overlap metrics the report should include. Corresponds to the JSON property overlapMetricNames

Returns:

  • (Array<String>)


11809
11810
11811
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11809

def overlap_metric_names
  @overlap_metric_names
end

#pivotedBoolean Also known as: pivoted?

Whether the report is pivoted or not. Defaults to true. Corresponds to the JSON property pivoted

Returns:

  • (Boolean)


11814
11815
11816
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11814

def pivoted
  @pivoted
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11822
11823
11824
11825
11826
11827
11828
11829
11830
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11822

def update!(**args)
  @breakdown = args[:breakdown] if args.key?(:breakdown)
  @date_range = args[:date_range] if args.key?(:date_range)
  @dimension = args[:dimension] if args.key?(:dimension)
  @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters)
  @metric_names = args[:metric_names] if args.key?(:metric_names)
  @overlap_metric_names = args[:overlap_metric_names] if args.key?(:overlap_metric_names)
  @pivoted = args[:pivoted] if args.key?(:pivoted)
end