Class: Google::Apis::DfareportingV4::Report::FloodlightCriteria

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

The report criteria for a report of type "FLOODLIGHT".

Defined Under Namespace

Classes: ReportProperties

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightCriteria

Returns a new instance of FloodlightCriteria.



11951
11952
11953
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11951

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_rich_media_eventsArray<Google::Apis::DfareportingV4::DimensionValue>

The list of custom rich media events to include. Corresponds to the JSON property customRichMediaEvents



11917
11918
11919
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11917

def custom_rich_media_events
  @custom_rich_media_events
end

#date_rangeGoogle::Apis::DfareportingV4::DateRange

Represents a date range. Corresponds to the JSON property dateRange



11922
11923
11924
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11922

def date_range
  @date_range
end

#dimension_filtersArray<Google::Apis::DfareportingV4::DimensionValue>

The list of filters on which dimensions are filtered. Filters for different dimensions are ANDed, filters for the same dimension are grouped together and ORed. Corresponds to the JSON property dimensionFilters



11929
11930
11931
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11929

def dimension_filters
  @dimension_filters
end

#dimensionsArray<Google::Apis::DfareportingV4::SortedDimension>

The list of dimensions the report should include. Corresponds to the JSON property dimensions



11934
11935
11936
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11934

def dimensions
  @dimensions
end

#floodlight_config_idGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightConfigId



11939
11940
11941
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11939

def floodlight_config_id
  @floodlight_config_id
end

#metric_namesArray<String>

The list of names of metrics the report should include. Corresponds to the JSON property metricNames

Returns:

  • (Array<String>)


11944
11945
11946
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11944

def metric_names
  @metric_names
end

#report_propertiesGoogle::Apis::DfareportingV4::Report::FloodlightCriteria::ReportProperties

The properties of the report. Corresponds to the JSON property reportProperties



11949
11950
11951
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11949

def report_properties
  @report_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11956
11957
11958
11959
11960
11961
11962
11963
11964
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11956

def update!(**args)
  @custom_rich_media_events = args[:custom_rich_media_events] if args.key?(:custom_rich_media_events)
  @date_range = args[:date_range] if args.key?(:date_range)
  @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @floodlight_config_id = args[:floodlight_config_id] if args.key?(:floodlight_config_id)
  @metric_names = args[:metric_names] if args.key?(:metric_names)
  @report_properties = args[:report_properties] if args.key?(:report_properties)
end