Class: Google::Apis::DfareportingV4::Report::PathToConversionCriteria

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

The report criteria for a report of type "PATH_TO_CONVERSION".

Defined Under Namespace

Classes: ReportProperties

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PathToConversionCriteria

Returns a new instance of PathToConversionCriteria.



12054
12055
12056
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12054

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activity_filtersArray<Google::Apis::DfareportingV4::DimensionValue>

The list of 'dfa:activity' values to filter on. Corresponds to the JSON property activityFilters



12012
12013
12014
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12012

def activity_filters
  @activity_filters
end

#conversion_dimensionsArray<Google::Apis::DfareportingV4::SortedDimension>

The list of conversion dimensions the report should include. Corresponds to the JSON property conversionDimensions



12017
12018
12019
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12017

def conversion_dimensions
  @conversion_dimensions
end

#custom_floodlight_variablesArray<Google::Apis::DfareportingV4::SortedDimension>

The list of custom floodlight variables the report should include. Corresponds to the JSON property customFloodlightVariables



12022
12023
12024
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12022

def custom_floodlight_variables
  @custom_floodlight_variables
end

#custom_rich_media_eventsArray<Google::Apis::DfareportingV4::DimensionValue>

The list of custom rich media events to include. Corresponds to the JSON property customRichMediaEvents



12027
12028
12029
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12027

def custom_rich_media_events
  @custom_rich_media_events
end

#date_rangeGoogle::Apis::DfareportingV4::DateRange

Represents a date range. Corresponds to the JSON property dateRange



12032
12033
12034
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12032

def date_range
  @date_range
end

#floodlight_config_idGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightConfigId



12037
12038
12039
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12037

def floodlight_config_id
  @floodlight_config_id
end

#metric_namesArray<String>

The list of names of metrics the report should include. Corresponds to the JSON property metricNames

Returns:

  • (Array<String>)


12042
12043
12044
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12042

def metric_names
  @metric_names
end

#per_interaction_dimensionsArray<Google::Apis::DfareportingV4::SortedDimension>

The list of per interaction dimensions the report should include. Corresponds to the JSON property perInteractionDimensions



12047
12048
12049
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12047

def per_interaction_dimensions
  @per_interaction_dimensions
end

#report_propertiesGoogle::Apis::DfareportingV4::Report::PathToConversionCriteria::ReportProperties

The properties of the report. Corresponds to the JSON property reportProperties



12052
12053
12054
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12052

def report_properties
  @report_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12059
12060
12061
12062
12063
12064
12065
12066
12067
12068
12069
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12059

def update!(**args)
  @activity_filters = args[:activity_filters] if args.key?(:activity_filters)
  @conversion_dimensions = args[:conversion_dimensions] if args.key?(:conversion_dimensions)
  @custom_floodlight_variables = args[:custom_floodlight_variables] if args.key?(:custom_floodlight_variables)
  @custom_rich_media_events = args[:custom_rich_media_events] if args.key?(:custom_rich_media_events)
  @date_range = args[:date_range] if args.key?(:date_range)
  @floodlight_config_id = args[:floodlight_config_id] if args.key?(:floodlight_config_id)
  @metric_names = args[:metric_names] if args.key?(:metric_names)
  @per_interaction_dimensions = args[:per_interaction_dimensions] if args.key?(:per_interaction_dimensions)
  @report_properties = args[:report_properties] if args.key?(:report_properties)
end