Class: Google::Apis::DfareportingV4::Report::ReachCriteria

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

The report criteria for a report of type "REACH".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReachCriteria

Returns a new instance of ReachCriteria.



12207
12208
12209
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activitiesGoogle::Apis::DfareportingV4::Activities

Represents an activity group. Corresponds to the JSON property activities



12165
12166
12167
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12165

def activities
  @activities
end

#custom_rich_media_eventsGoogle::Apis::DfareportingV4::CustomRichMediaEvents

Represents a Custom Rich Media Events group. Corresponds to the JSON property customRichMediaEvents



12170
12171
12172
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12170

def custom_rich_media_events
  @custom_rich_media_events
end

#date_rangeGoogle::Apis::DfareportingV4::DateRange

Represents a date range. Corresponds to the JSON property dateRange



12175
12176
12177
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12175

def date_range
  @date_range
end

#dimension_filtersArray<Google::Apis::DfareportingV4::DimensionValue>

The list of filters on which dimensions are filtered. Filters for different dimensions are ANDed, filters for the same dimension are grouped together and ORed. Corresponds to the JSON property dimensionFilters



12182
12183
12184
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12182

def dimension_filters
  @dimension_filters
end

#dimensionsArray<Google::Apis::DfareportingV4::SortedDimension>

The list of dimensions the report should include. Corresponds to the JSON property dimensions



12187
12188
12189
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12187

def dimensions
  @dimensions
end

#enable_all_dimension_combinationsBoolean Also known as: enable_all_dimension_combinations?

Whether to enable all reach dimension combinations in the report. Defaults to false. If enabled, the date range of the report should be within the last 42 days. Corresponds to the JSON property enableAllDimensionCombinations

Returns:

  • (Boolean)


12194
12195
12196
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12194

def enable_all_dimension_combinations
  @enable_all_dimension_combinations
end

#metric_namesArray<String>

The list of names of metrics the report should include. Corresponds to the JSON property metricNames

Returns:

  • (Array<String>)


12200
12201
12202
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12200

def metric_names
  @metric_names
end

#reach_by_frequency_metric_namesArray<String>

The list of names of Reach By Frequency metrics the report should include. Corresponds to the JSON property reachByFrequencyMetricNames

Returns:

  • (Array<String>)


12205
12206
12207
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12205

def reach_by_frequency_metric_names
  @reach_by_frequency_metric_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12212
12213
12214
12215
12216
12217
12218
12219
12220
12221
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12212

def update!(**args)
  @activities = args[:activities] if args.key?(:activities)
  @custom_rich_media_events = args[:custom_rich_media_events] if args.key?(:custom_rich_media_events)
  @date_range = args[:date_range] if args.key?(:date_range)
  @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @enable_all_dimension_combinations = args[:enable_all_dimension_combinations] if args.key?(:enable_all_dimension_combinations)
  @metric_names = args[:metric_names] if args.key?(:metric_names)
  @reach_by_frequency_metric_names = args[:reach_by_frequency_metric_names] if args.key?(:reach_by_frequency_metric_names)
end