Class: Google::Apis::DfareportingV4::Report::Schedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

The report's schedule. Can only be set if the report's 'dateRange' is a relative date range and the relative date range is not "TODAY".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schedule

Returns a new instance of Schedule.



12279
12280
12281
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12279

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Whether the schedule is active or not. Must be set to either true or false. Corresponds to the JSON property active

Returns:

  • (Boolean)


12232
12233
12234
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12232

def active
  @active
end

#everyFixnum

Defines every how many days, weeks or months the report should be run. Needs to be set when "repeats" is either "DAILY", "WEEKLY" or "MONTHLY". Corresponds to the JSON property every

Returns:

  • (Fixnum)


12239
12240
12241
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12239

def every
  @every
end

#expiration_dateDate

Corresponds to the JSON property expirationDate

Returns:

  • (Date)


12244
12245
12246
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12244

def expiration_date
  @expiration_date
end

#repeatsString

The interval for which the report is repeated. Note: - "DAILY" also requires field "every" to be set. - "WEEKLY" also requires fields "every" and " repeatsOnWeekDays" to be set. - "MONTHLY" also requires fields "every" and " runsOnDayOfMonth" to be set. Corresponds to the JSON property repeats

Returns:

  • (String)


12252
12253
12254
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12252

def repeats
  @repeats
end

#repeats_on_week_daysArray<String>

List of week days "WEEKLY" on which scheduled reports should run. Corresponds to the JSON property repeatsOnWeekDays

Returns:

  • (Array<String>)


12257
12258
12259
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12257

def repeats_on_week_days
  @repeats_on_week_days
end

#runs_on_day_of_monthString

Enum to define for "MONTHLY" scheduled reports whether reports should be repeated on the same day of the month as "startDate" or the same day of the week of the month. Example: If 'startDate' is Monday, April 2nd 2012 (2012-04- 02), "DAY_OF_MONTH" would run subsequent reports on the 2nd of every Month, and "WEEK_OF_MONTH" would run subsequent reports on the first Monday of the month. Corresponds to the JSON property runsOnDayOfMonth

Returns:

  • (String)


12267
12268
12269
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12267

def runs_on_day_of_month
  @runs_on_day_of_month
end

#start_dateDate

Corresponds to the JSON property startDate

Returns:

  • (Date)


12272
12273
12274
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12272

def start_date
  @start_date
end

#timezoneString

The timezone when the report will run. Corresponds to the JSON property timezone

Returns:

  • (String)


12277
12278
12279
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12277

def timezone
  @timezone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12284
12285
12286
12287
12288
12289
12290
12291
12292
12293
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12284

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @every = args[:every] if args.key?(:every)
  @expiration_date = args[:expiration_date] if args.key?(:expiration_date)
  @repeats = args[:repeats] if args.key?(:repeats)
  @repeats_on_week_days = args[:repeats_on_week_days] if args.key?(:repeats_on_week_days)
  @runs_on_day_of_month = args[:runs_on_day_of_month] if args.key?(:runs_on_day_of_month)
  @start_date = args[:start_date] if args.key?(:start_date)
  @timezone = args[:timezone] if args.key?(:timezone)
end