Class: Google::Apis::DfareportingV4::ReportCompatibleFields
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::ReportCompatibleFields
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Represents fields that are compatible to be selected for a report of type " STANDARD".
Instance Attribute Summary collapse
-
#dimension_filters ⇒ Array<Google::Apis::DfareportingV4::Dimension>
Dimensions which are compatible to be selected in the "dimensionFilters" section of the report.
-
#dimensions ⇒ Array<Google::Apis::DfareportingV4::Dimension>
Dimensions which are compatible to be selected in the "dimensions" section of the report.
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting#reportCompatibleFields.
-
#metrics ⇒ Array<Google::Apis::DfareportingV4::Metric>
Metrics which are compatible to be selected in the "metricNames" section of the report.
-
#pivoted_activity_metrics ⇒ Array<Google::Apis::DfareportingV4::Metric>
Metrics which are compatible to be selected as activity metrics to pivot on in the "activities" section of the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportCompatibleFields
constructor
A new instance of ReportCompatibleFields.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportCompatibleFields
Returns a new instance of ReportCompatibleFields.
12331 12332 12333 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension_filters ⇒ Array<Google::Apis::DfareportingV4::Dimension>
Dimensions which are compatible to be selected in the "dimensionFilters"
section of the report.
Corresponds to the JSON property dimensionFilters
12306 12307 12308 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12306 def dimension_filters @dimension_filters end |
#dimensions ⇒ Array<Google::Apis::DfareportingV4::Dimension>
Dimensions which are compatible to be selected in the "dimensions" section of
the report.
Corresponds to the JSON property dimensions
12312 12313 12314 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12312 def dimensions @dimensions end |
#kind ⇒ String
The kind of resource this is, in this case dfareporting#reportCompatibleFields.
Corresponds to the JSON property kind
12317 12318 12319 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12317 def kind @kind end |
#metrics ⇒ Array<Google::Apis::DfareportingV4::Metric>
Metrics which are compatible to be selected in the "metricNames" section of
the report.
Corresponds to the JSON property metrics
12323 12324 12325 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12323 def metrics @metrics end |
#pivoted_activity_metrics ⇒ Array<Google::Apis::DfareportingV4::Metric>
Metrics which are compatible to be selected as activity metrics to pivot on in
the "activities" section of the report.
Corresponds to the JSON property pivotedActivityMetrics
12329 12330 12331 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12329 def pivoted_activity_metrics @pivoted_activity_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12336 12337 12338 12339 12340 12341 12342 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12336 def update!(**args) @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters) @dimensions = args[:dimensions] if args.key?(:dimensions) @kind = args[:kind] if args.key?(:kind) @metrics = args[:metrics] if args.key?(:metrics) @pivoted_activity_metrics = args[:pivoted_activity_metrics] if args.key?(:pivoted_activity_metrics) end |