Class: Google::Apis::DfareportingV4::Rule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

A rule associates an asset with a targeting template for asset-level targeting. Applicable to INSTREAM_VIDEO creatives.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rule

Returns a new instance of Rule.



12522
12523
12524
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_idFixnum

A creativeAssets[].id. This should refer to one of the parent assets in this creative. This is a required field. Corresponds to the JSON property assetId

Returns:

  • (Fixnum)


12508
12509
12510
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12508

def asset_id
  @asset_id
end

#nameString

A user-friendly name for this rule. This is a required field. Corresponds to the JSON property name

Returns:

  • (String)


12513
12514
12515
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12513

def name
  @name
end

#targeting_template_idFixnum

A targeting template ID. The targeting from the targeting template will be used to determine whether this asset should be served. This is a required field. Corresponds to the JSON property targetingTemplateId

Returns:

  • (Fixnum)


12520
12521
12522
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12520

def targeting_template_id
  @targeting_template_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12527
12528
12529
12530
12531
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12527

def update!(**args)
  @asset_id = args[:asset_id] if args.key?(:asset_id)
  @name = args[:name] if args.key?(:name)
  @targeting_template_id = args[:targeting_template_id] if args.key?(:targeting_template_id)
end