Class: Google::Apis::DfareportingV4::Site
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::Site
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains properties of a site.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this site.
-
#ad_serving_platform_id ⇒ Fixnum
Optional.
-
#approved ⇒ Boolean
(also: #approved?)
Whether this site is approved.
-
#directory_site_id ⇒ Fixnum
Directory site associated with this site.
-
#directory_site_id_dimension_value ⇒ Google::Apis::DfareportingV4::DimensionValue
Represents a DimensionValue resource.
-
#id ⇒ Fixnum
ID of this site.
-
#id_dimension_value ⇒ Google::Apis::DfareportingV4::DimensionValue
Represents a DimensionValue resource.
-
#key_name ⇒ String
Key name of this site.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this site.This is a required field.
-
#site_contacts ⇒ Array<Google::Apis::DfareportingV4::SiteContact>
Site contacts.
-
#site_settings ⇒ Google::Apis::DfareportingV4::SiteSettings
Site Settings Corresponds to the JSON property
siteSettings. -
#subaccount_id ⇒ Fixnum
Subaccount ID of this site.
-
#video_settings ⇒ Google::Apis::DfareportingV4::SiteVideoSettings
Video Settings Corresponds to the JSON property
videoSettings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Site
constructor
A new instance of Site.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Site
Returns a new instance of Site.
12642 12643 12644 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this site. This is a read-only field that can be left blank.
Corresponds to the JSON property accountId
12560 12561 12562 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12560 def account_id @account_id end |
#ad_serving_platform_id ⇒ Fixnum
Optional. Ad serving platform ID to identify the ad serving platform used by
the site. Measurement partners can use this field to add ad-server specific
macros. If set, this value acts as the default during placement creation.
Possible values are: * 1, Adelphic * 2, Adform * 3, Adobe * 4, Amobee *
5, Basis (Centro) * 6, Beeswax * 7, Amazon * 8, DV360 (DBM) * 9,
Innovid * 10, MediaMath * 11, Roku OneView DSP * 12, TabMo Hawk * 13,
The Trade Desk * 14, Xandr Invest DSP * 15, Yahoo DSP * 16, Zeta Global *
17, Scaleout * 18, Bidtellect * 19, Unicorn * 20, Teads * 21,
Quantcast * 22, Cognitiv * 23, AdTheorent * 24, DeepIntent * 25,
Pulsepoint
Corresponds to the JSON property adServingPlatformId
12574 12575 12576 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12574 def ad_serving_platform_id @ad_serving_platform_id end |
#approved ⇒ Boolean Also known as: approved?
Whether this site is approved.
Corresponds to the JSON property approved
12579 12580 12581 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12579 def approved @approved end |
#directory_site_id ⇒ Fixnum
Directory site associated with this site. This is a required field that is
read-only after insertion.
Corresponds to the JSON property directorySiteId
12586 12587 12588 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12586 def directory_site_id @directory_site_id end |
#directory_site_id_dimension_value ⇒ Google::Apis::DfareportingV4::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property directorySiteIdDimensionValue
12591 12592 12593 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12591 def directory_site_id_dimension_value @directory_site_id_dimension_value end |
#id ⇒ Fixnum
ID of this site. This is a read-only, auto-generated field.
Corresponds to the JSON property id
12596 12597 12598 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12596 def id @id end |
#id_dimension_value ⇒ Google::Apis::DfareportingV4::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property idDimensionValue
12601 12602 12603 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12601 def id_dimension_value @id_dimension_value end |
#key_name ⇒ String
Key name of this site. This is a read-only, auto-generated field.
Corresponds to the JSON property keyName
12606 12607 12608 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12606 def key_name @key_name end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#site".
Corresponds to the JSON property kind
12612 12613 12614 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12612 def kind @kind end |
#name ⇒ String
Name of this site.This is a required field. Must be less than 128 characters
long. If this site is under a subaccount, the name must be unique among sites
of the same subaccount. Otherwise, this site is a top-level site, and the name
must be unique among top-level sites of the same account.
Corresponds to the JSON property name
12620 12621 12622 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12620 def name @name end |
#site_contacts ⇒ Array<Google::Apis::DfareportingV4::SiteContact>
Site contacts.
Corresponds to the JSON property siteContacts
12625 12626 12627 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12625 def site_contacts @site_contacts end |
#site_settings ⇒ Google::Apis::DfareportingV4::SiteSettings
Site Settings
Corresponds to the JSON property siteSettings
12630 12631 12632 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12630 def site_settings @site_settings end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this site. This is a read-only field that can be left blank.
Corresponds to the JSON property subaccountId
12635 12636 12637 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12635 def subaccount_id @subaccount_id end |
#video_settings ⇒ Google::Apis::DfareportingV4::SiteVideoSettings
Video Settings
Corresponds to the JSON property videoSettings
12640 12641 12642 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12640 def video_settings @video_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12647 12648 12649 12650 12651 12652 12653 12654 12655 12656 12657 12658 12659 12660 12661 12662 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12647 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @ad_serving_platform_id = args[:ad_serving_platform_id] if args.key?(:ad_serving_platform_id) @approved = args[:approved] if args.key?(:approved) @directory_site_id = args[:directory_site_id] if args.key?(:directory_site_id) @directory_site_id_dimension_value = args[:directory_site_id_dimension_value] if args.key?(:directory_site_id_dimension_value) @id = args[:id] if args.key?(:id) @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value) @key_name = args[:key_name] if args.key?(:key_name) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @site_contacts = args[:site_contacts] if args.key?(:site_contacts) @site_settings = args[:site_settings] if args.key?(:site_settings) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) @video_settings = args[:video_settings] if args.key?(:video_settings) end |