Class: Google::Apis::DfareportingV4::SiteSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Site Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SiteSettings

Returns a new instance of SiteSettings.



12818
12819
12820
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_view_opt_outBoolean Also known as: active_view_opt_out?

Whether active view creatives are disabled for this site. Corresponds to the JSON property activeViewOptOut

Returns:

  • (Boolean)


12774
12775
12776
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12774

def active_view_opt_out
  @active_view_opt_out
end

#ad_blocking_opt_outBoolean Also known as: ad_blocking_opt_out?

Whether this site opts out of ad blocking. When true, ad blocking is disabled for all placements under the site, regardless of the individual placement settings. When false, the campaign and placement settings take effect. Corresponds to the JSON property adBlockingOptOut

Returns:

  • (Boolean)


12782
12783
12784
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12782

def ad_blocking_opt_out
  @ad_blocking_opt_out
end

Whether new cookies are disabled for this site. Corresponds to the JSON property disableNewCookie

Returns:

  • (Boolean)


12788
12789
12790
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12788

def disable_new_cookie
  @disable_new_cookie
end

#tag_settingGoogle::Apis::DfareportingV4::TagSetting

Tag Settings Corresponds to the JSON property tagSetting



12794
12795
12796
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12794

def tag_setting
  @tag_setting
end

#video_active_view_opt_out_templateBoolean Also known as: video_active_view_opt_out_template?

Whether Verification and ActiveView for in-stream video creatives are disabled by default for new placements created under this site. This value will be used to populate the placement.videoActiveViewOptOut field, when no value is specified for the new placement. Corresponds to the JSON property videoActiveViewOptOutTemplate

Returns:

  • (Boolean)


12802
12803
12804
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12802

def video_active_view_opt_out_template
  @video_active_view_opt_out_template
end

#vpaid_adapter_choice_templateString

Default VPAID adapter setting for new placements created under this site. This value will be used to populate the placements.vpaidAdapterChoice field, when no value is specified for the new placement. Controls which VPAID format the measurement adapter will use for in-stream video creatives assigned to the placement. The publisher's specifications will typically determine this setting. For VPAID creatives, the adapter format will match the VPAID format ( HTML5 VPAID creatives use the HTML5 adapter). Note: Flash is no longer supported. This field now defaults to HTML5 when the following values are provided: FLASH, BOTH. Corresponds to the JSON property vpaidAdapterChoiceTemplate

Returns:

  • (String)


12816
12817
12818
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12816

def vpaid_adapter_choice_template
  @vpaid_adapter_choice_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12823
12824
12825
12826
12827
12828
12829
12830
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12823

def update!(**args)
  @active_view_opt_out = args[:active_view_opt_out] if args.key?(:active_view_opt_out)
  @ad_blocking_opt_out = args[:ad_blocking_opt_out] if args.key?(:ad_blocking_opt_out)
  @disable_new_cookie = args[:disable_new_cookie] if args.key?(:disable_new_cookie)
  @tag_setting = args[:tag_setting] if args.key?(:tag_setting)
  @video_active_view_opt_out_template = args[:video_active_view_opt_out_template] if args.key?(:video_active_view_opt_out_template)
  @vpaid_adapter_choice_template = args[:vpaid_adapter_choice_template] if args.key?(:vpaid_adapter_choice_template)
end