Class: Google::Apis::DfareportingV4::SiteSkippableSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::SiteSkippableSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Skippable Settings
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#progress_offset ⇒ Google::Apis::DfareportingV4::VideoOffset
Video Offset Corresponds to the JSON property
progressOffset. -
#skip_offset ⇒ Google::Apis::DfareportingV4::VideoOffset
Video Offset Corresponds to the JSON property
skipOffset. -
#skippable ⇒ Boolean
(also: #skippable?)
Whether the user can skip creatives served to this site.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SiteSkippableSetting
constructor
A new instance of SiteSkippableSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SiteSkippableSetting
Returns a new instance of SiteSkippableSetting.
12860 12861 12862 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12860 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#siteSkippableSetting".
Corresponds to the JSON property kind
12841 12842 12843 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12841 def kind @kind end |
#progress_offset ⇒ Google::Apis::DfareportingV4::VideoOffset
Video Offset
Corresponds to the JSON property progressOffset
12846 12847 12848 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12846 def progress_offset @progress_offset end |
#skip_offset ⇒ Google::Apis::DfareportingV4::VideoOffset
Video Offset
Corresponds to the JSON property skipOffset
12851 12852 12853 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12851 def skip_offset @skip_offset end |
#skippable ⇒ Boolean Also known as: skippable?
Whether the user can skip creatives served to this site. This will act as
default for new placements created under this site.
Corresponds to the JSON property skippable
12857 12858 12859 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12857 def skippable @skippable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12865 12866 12867 12868 12869 12870 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12865 def update!(**args) @kind = args[:kind] if args.key?(:kind) @progress_offset = args[:progress_offset] if args.key?(:progress_offset) @skip_offset = args[:skip_offset] if args.key?(:skip_offset) @skippable = args[:skippable] if args.key?(:skippable) end |