Class: Google::Apis::DfareportingV4::SiteTranscodeSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::SiteTranscodeSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Transcode Settings
Instance Attribute Summary collapse
-
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this site template.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SiteTranscodeSetting
constructor
A new instance of SiteTranscodeSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SiteTranscodeSetting
Returns a new instance of SiteTranscodeSetting.
12889 12890 12891 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this site template. Set this list
to null or empty to serve all video formats.
Corresponds to the JSON property enabledVideoFormats
12881 12882 12883 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12881 def enabled_video_formats @enabled_video_formats end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#siteTranscodeSetting".
Corresponds to the JSON property kind
12887 12888 12889 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12887 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12894 12895 12896 12897 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12894 def update!(**args) @enabled_video_formats = args[:enabled_video_formats] if args.key?(:enabled_video_formats) @kind = args[:kind] if args.key?(:kind) end |