Class: Google::Apis::DfareportingV4::SiteVideoSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Video Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SiteVideoSettings

Returns a new instance of SiteVideoSettings.



12957
12958
12959
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#companion_settingsGoogle::Apis::DfareportingV4::SiteCompanionSetting

Companion Settings Corresponds to the JSON property companionSettings



12907
12908
12909
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12907

def companion_settings
  @companion_settings
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#siteVideoSettings". Corresponds to the JSON property kind

Returns:

  • (String)


12913
12914
12915
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12913

def kind
  @kind
end

#oba_enabledBoolean Also known as: oba_enabled?

Whether OBA icons are enabled for this placement. Corresponds to the JSON property obaEnabled

Returns:

  • (Boolean)


12918
12919
12920
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12918

def oba_enabled
  @oba_enabled
end

#oba_settingsGoogle::Apis::DfareportingV4::ObaIcon

Online Behavioral Advertiser icon. Corresponds to the JSON property obaSettings



12924
12925
12926
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12924

def oba_settings
  @oba_settings
end

#orientationString

Orientation of a site template used for video. This will act as default for new placements created under this site. Corresponds to the JSON property orientation

Returns:

  • (String)


12930
12931
12932
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12930

def orientation
  @orientation
end

#publisher_specification_idFixnum

Publisher specification ID used to identify site-associated publisher requirements and automatically populate transcode settings. If publisher specification ID is specified, it will take precedence over transcode settings. Possible values are: * 1, Hulu * 2, NBC * 3, CBS * 4, CBS Desktop * 5, Discovery * 6, VEVO HD * 7, VEVO Vertical * 8, Fox * 9, CW Network

  • 10, Disney * 11, IGN * 12, NFL.com * 13, Turner Broadcasting * 14, Tubi on Fox * 15, Hearst Corporation * 16, Twitch Desktop * 17, ABC * 18, Univision * 19, MLB.com * 20, MLB.com Mobile * 21, MLB.com OTT * 22, Polsat * 23, TVN * 24, Mediaset * 25, Antena 3 * 26, Mediamond * 27, Sky Italia * 28, Tubi on CBS * 29, Spotify * 30, Paramount * 31, Max Corresponds to the JSON property publisherSpecificationId

Returns:

  • (Fixnum)


12945
12946
12947
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12945

def publisher_specification_id
  @publisher_specification_id
end

#skippable_settingsGoogle::Apis::DfareportingV4::SiteSkippableSetting

Skippable Settings Corresponds to the JSON property skippableSettings



12950
12951
12952
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12950

def skippable_settings
  @skippable_settings
end

#transcode_settingsGoogle::Apis::DfareportingV4::SiteTranscodeSetting

Transcode Settings Corresponds to the JSON property transcodeSettings



12955
12956
12957
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12955

def transcode_settings
  @transcode_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12962
12963
12964
12965
12966
12967
12968
12969
12970
12971
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12962

def update!(**args)
  @companion_settings = args[:companion_settings] if args.key?(:companion_settings)
  @kind = args[:kind] if args.key?(:kind)
  @oba_enabled = args[:oba_enabled] if args.key?(:oba_enabled)
  @oba_settings = args[:oba_settings] if args.key?(:oba_settings)
  @orientation = args[:orientation] if args.key?(:orientation)
  @publisher_specification_id = args[:publisher_specification_id] if args.key?(:publisher_specification_id)
  @skippable_settings = args[:skippable_settings] if args.key?(:skippable_settings)
  @transcode_settings = args[:transcode_settings] if args.key?(:transcode_settings)
end