Class: Google::Apis::DfareportingV4::StudioCreative

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains studio creative information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StudioCreative

Returns a new instance of StudioCreative.



13225
13226
13227
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_idsArray<Fixnum>

List of assets associated with this studio creative. It is a required field on insertion. Corresponds to the JSON property assetIds

Returns:

  • (Array<Fixnum>)


13157
13158
13159
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13157

def asset_ids
  @asset_ids
end

#backup_image_asset_idFixnum

Backup image asset ID of this studio creative. It is a required field on insertion. Corresponds to the JSON property backupImageAssetId

Returns:

  • (Fixnum)


13163
13164
13165
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13163

def backup_image_asset_id
  @backup_image_asset_id
end

#created_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createdInfo



13168
13169
13170
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13168

def created_info
  @created_info
end

#dimensionGoogle::Apis::DfareportingV4::StudioCreativeDimension

Dimension information for a studio creative. Corresponds to the JSON property dimension



13173
13174
13175
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13173

def dimension
  @dimension
end

#dynamic_profile_idFixnum

Dynamic profile ID of this studio creative. Corresponds to the JSON property dynamicProfileId

Returns:

  • (Fixnum)


13178
13179
13180
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13178

def dynamic_profile_id
  @dynamic_profile_id
end

#formatString

Format of this studio creative. This is a required field on insertion. Corresponds to the JSON property format

Returns:

  • (String)


13183
13184
13185
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13183

def format
  @format
end

#idFixnum

Output only. Unique ID of this studio creative. This is a read-only, auto- generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13189
13190
13191
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13189

def id
  @id
end

#last_modified_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



13194
13195
13196
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13194

def last_modified_info
  @last_modified_info
end

#nameString

Identifier. Name of this studio creative. This is a required field on insertion. Corresponds to the JSON property name

Returns:

  • (String)


13200
13201
13202
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13200

def name
  @name
end

#statusString

Output only. Status of this studio creative. It is a read-only field. Corresponds to the JSON property status

Returns:

  • (String)


13205
13206
13207
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13205

def status
  @status
end

#studio_account_idFixnum

Studio account ID of this creative. This field, if left unset, will be auto- populated. Corresponds to the JSON property studioAccountId

Returns:

  • (Fixnum)


13211
13212
13213
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13211

def 
  @studio_account_id
end

#studio_advertiser_idFixnum

Studio advertiser ID of this studio creative. This is a required field on insertion. Corresponds to the JSON property studioAdvertiserId

Returns:

  • (Fixnum)


13217
13218
13219
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13217

def studio_advertiser_id
  @studio_advertiser_id
end

#studio_campaign_idFixnum

Studio campaign ID of this studio creative. This is a required field on insertion. Corresponds to the JSON property studioCampaignId

Returns:

  • (Fixnum)


13223
13224
13225
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13223

def studio_campaign_id
  @studio_campaign_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13230
13231
13232
13233
13234
13235
13236
13237
13238
13239
13240
13241
13242
13243
13244
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13230

def update!(**args)
  @asset_ids = args[:asset_ids] if args.key?(:asset_ids)
  @backup_image_asset_id = args[:backup_image_asset_id] if args.key?(:backup_image_asset_id)
  @created_info = args[:created_info] if args.key?(:created_info)
  @dimension = args[:dimension] if args.key?(:dimension)
  @dynamic_profile_id = args[:dynamic_profile_id] if args.key?(:dynamic_profile_id)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @studio_account_id = args[:studio_account_id] if args.key?(:studio_account_id)
  @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id)
  @studio_campaign_id = args[:studio_campaign_id] if args.key?(:studio_campaign_id)
end