Class: Google::Apis::DfareportingV4::StudioCreativeAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Beta: This API resource is available only to a very limited number of customers. If you'd like to use this resource, please reach out to your Google sales representative. Contains studio creative asset information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StudioCreativeAsset

Returns a new instance of StudioCreativeAsset.



13308
13309
13310
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createInfo



13256
13257
13258
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13256

def create_info
  @create_info
end

#filenameString

The filename of the studio creative asset. It is default to the original filename of the asset. Corresponds to the JSON property filename

Returns:

  • (String)


13262
13263
13264
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13262

def filename
  @filename
end

#filesizeFixnum

The filesize of the studio creative asset. This is a read-only field. Corresponds to the JSON property filesize

Returns:

  • (Fixnum)


13267
13268
13269
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13267

def filesize
  @filesize
end

#idFixnum

Output only. Unique ID of this studio creative asset. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13273
13274
13275
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13273

def id
  @id
end

#last_modified_infoGoogle::Apis::DfareportingV4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



13278
13279
13280
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13278

def last_modified_info
  @last_modified_info
end

#studio_account_idFixnum

Studio account ID of this studio creative asset. This field, if left unset, will be auto-populated.. Corresponds to the JSON property studioAccountId

Returns:

  • (Fixnum)


13284
13285
13286
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13284

def 
  @studio_account_id
end

#studio_advertiser_idFixnum

Studio advertiser ID of this studio creative asset. This is a required field on insertion. Corresponds to the JSON property studioAdvertiserId

Returns:

  • (Fixnum)


13290
13291
13292
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13290

def studio_advertiser_id
  @studio_advertiser_id
end

#studio_creative_idFixnum

Studio creative ID of this studio creative asset. The asset will be associated to the creative if creative id is set. Corresponds to the JSON property studioCreativeId

Returns:

  • (Fixnum)


13296
13297
13298
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13296

def studio_creative_id
  @studio_creative_id
end

#typeString

The type of the studio creative asset. It is a auto-generated, read-only field. Corresponds to the JSON property type

Returns:

  • (String)


13301
13302
13303
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13301

def type
  @type
end

#video_processing_dataGoogle::Apis::DfareportingV4::VideoProcessingData

Contains processing data for a video asset. Corresponds to the JSON property videoProcessingData



13306
13307
13308
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13306

def video_processing_data
  @video_processing_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13313
13314
13315
13316
13317
13318
13319
13320
13321
13322
13323
13324
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13313

def update!(**args)
  @create_info = args[:create_info] if args.key?(:create_info)
  @filename = args[:filename] if args.key?(:filename)
  @filesize = args[:filesize] if args.key?(:filesize)
  @id = args[:id] if args.key?(:id)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @studio_account_id = args[:studio_account_id] if args.key?(:studio_account_id)
  @studio_advertiser_id = args[:studio_advertiser_id] if args.key?(:studio_advertiser_id)
  @studio_creative_id = args[:studio_creative_id] if args.key?(:studio_creative_id)
  @type = args[:type] if args.key?(:type)
  @video_processing_data = args[:video_processing_data] if args.key?(:video_processing_data)
end