Class: Google::Apis::DfareportingV4::SubaccountsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::SubaccountsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Subaccount List Response
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
-
#subaccounts ⇒ Array<Google::Apis::DfareportingV4::Subaccount>
Subaccount collection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubaccountsListResponse
constructor
A new instance of SubaccountsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubaccountsListResponse
Returns a new instance of SubaccountsListResponse.
13437 13438 13439 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#subaccountsListResponse".
Corresponds to the JSON property kind
13425 13426 13427 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13425 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
13430 13431 13432 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13430 def next_page_token @next_page_token end |
#subaccounts ⇒ Array<Google::Apis::DfareportingV4::Subaccount>
Subaccount collection.
Corresponds to the JSON property subaccounts
13435 13436 13437 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13435 def subaccounts @subaccounts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13442 13443 13444 13445 13446 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13442 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @subaccounts = args[:subaccounts] if args.key?(:subaccounts) end |