Class: Google::Apis::DfareportingV4::TargetWindow
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::TargetWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Target Window.
Instance Attribute Summary collapse
-
#custom_html ⇒ String
User-entered value.
-
#target_window_option ⇒ String
Type of browser window for which the backup image of the flash creative can be displayed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetWindow
constructor
A new instance of TargetWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetWindow
Returns a new instance of TargetWindow.
13590 13591 13592 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_html ⇒ String
User-entered value.
Corresponds to the JSON property customHtml
13582 13583 13584 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13582 def custom_html @custom_html end |
#target_window_option ⇒ String
Type of browser window for which the backup image of the flash creative can be
displayed.
Corresponds to the JSON property targetWindowOption
13588 13589 13590 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13588 def target_window_option @target_window_option end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13595 13596 13597 13598 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13595 def update!(**args) @custom_html = args[:custom_html] if args.key?(:custom_html) @target_window_option = args[:target_window_option] if args.key?(:target_window_option) end |