Class: Google::Apis::DfareportingV4::TargetableRemarketingList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains properties of a targetable remarketing list. Remarketing enables you to create lists of users who have performed specific actions on a site, then target ads to members of those lists. This resource is a read-only view of a remarketing list to be used to facilitate targeting ads to specific lists. Remarketing lists that are owned by your advertisers and those that are shared to your advertisers or account are accessible via this resource. To manage remarketing lists that are owned by your advertisers, use the RemarketingLists resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetableRemarketingList

Returns a new instance of TargetableRemarketingList.



13679
13680
13681
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this remarketing list. This is a read-only, auto-generated field that is only returned in GET requests. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


13616
13617
13618
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13616

def 
  @account_id
end

#activeBoolean Also known as: active?

Whether this targetable remarketing list is active. Corresponds to the JSON property active

Returns:

  • (Boolean)


13621
13622
13623
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13621

def active
  @active
end

#advertiser_idFixnum

Dimension value for the advertiser ID that owns this targetable remarketing list. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


13628
13629
13630
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13628

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



13633
13634
13635
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13633

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#descriptionString

Targetable remarketing list description. Corresponds to the JSON property description

Returns:

  • (String)


13638
13639
13640
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13638

def description
  @description
end

#idFixnum

Targetable remarketing list ID. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13643
13644
13645
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13643

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#targetableRemarketingList". Corresponds to the JSON property kind

Returns:

  • (String)


13649
13650
13651
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13649

def kind
  @kind
end

#life_spanFixnum

Number of days that a user should remain in the targetable remarketing list without an impression. Corresponds to the JSON property lifeSpan

Returns:

  • (Fixnum)


13655
13656
13657
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13655

def life_span
  @life_span
end

#list_sizeFixnum

Number of users currently in the list. This is a read-only field. Corresponds to the JSON property listSize

Returns:

  • (Fixnum)


13660
13661
13662
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13660

def list_size
  @list_size
end

#list_sourceString

Product from which this targetable remarketing list was originated. Corresponds to the JSON property listSource

Returns:

  • (String)


13665
13666
13667
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13665

def list_source
  @list_source
end

#nameString

Name of the targetable remarketing list. Is no greater than 128 characters long. Corresponds to the JSON property name

Returns:

  • (String)


13671
13672
13673
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13671

def name
  @name
end

#subaccount_idFixnum

Subaccount ID of this remarketing list. This is a read-only, auto-generated field that is only returned in GET requests. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


13677
13678
13679
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13677

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
13694
13695
13696
13697
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13684

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @active = args[:active] if args.key?(:active)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @life_span = args[:life_span] if args.key?(:life_span)
  @list_size = args[:list_size] if args.key?(:list_size)
  @list_source = args[:list_source] if args.key?(:list_source)
  @name = args[:name] if args.key?(:name)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end