Class: Google::Apis::DfareportingV4::TargetingTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

Contains properties of a targeting template. A targeting template encapsulates targeting information which can be reused across multiple ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetingTemplate

Returns a new instance of TargetingTemplate.



13812
13813
13814
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this targeting template. This field, if left unset, will be auto- generated on insert and is read-only after insert. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


13741
13742
13743
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13741

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this targeting template. This is a required field on insert and is read-only after insert. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


13747
13748
13749
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13747

def advertiser_id
  @advertiser_id
end

#advertiser_id_dimension_valueGoogle::Apis::DfareportingV4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property advertiserIdDimensionValue



13752
13753
13754
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13752

def advertiser_id_dimension_value
  @advertiser_id_dimension_value
end

#contextual_keyword_targetingGoogle::Apis::DfareportingV4::ContextualKeywordTargeting

Contextual Keyword Targeting. Corresponds to the JSON property contextualKeywordTargeting



13757
13758
13759
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13757

def contextual_keyword_targeting
  @contextual_keyword_targeting
end

#day_part_targetingGoogle::Apis::DfareportingV4::DayPartTargeting

Day Part Targeting. Corresponds to the JSON property dayPartTargeting



13762
13763
13764
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13762

def day_part_targeting
  @day_part_targeting
end

#geo_targetingGoogle::Apis::DfareportingV4::GeoTargeting

Geographical Targeting. Corresponds to the JSON property geoTargeting



13767
13768
13769
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13767

def geo_targeting
  @geo_targeting
end

#idFixnum

ID of this targeting template. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13772
13773
13774
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13772

def id
  @id
end

#key_value_targeting_expressionGoogle::Apis::DfareportingV4::KeyValueTargetingExpression

Key Value Targeting Expression. Corresponds to the JSON property keyValueTargetingExpression



13777
13778
13779
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13777

def key_value_targeting_expression
  @key_value_targeting_expression
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#targetingTemplate". Corresponds to the JSON property kind

Returns:

  • (String)


13783
13784
13785
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13783

def kind
  @kind
end

#language_targetingGoogle::Apis::DfareportingV4::LanguageTargeting

Language Targeting. Corresponds to the JSON property languageTargeting



13788
13789
13790
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13788

def language_targeting
  @language_targeting
end

#list_targeting_expressionGoogle::Apis::DfareportingV4::ListTargetingExpression

Remarketing List Targeting Expression. Corresponds to the JSON property listTargetingExpression



13793
13794
13795
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13793

def list_targeting_expression
  @list_targeting_expression
end

#nameString

Name of this targeting template. This field is required. It must be less than 256 characters long and unique within an advertiser. Corresponds to the JSON property name

Returns:

  • (String)


13799
13800
13801
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13799

def name
  @name
end

#subaccount_idFixnum

Subaccount ID of this targeting template. This field, if left unset, will be auto-generated on insert and is read-only after insert. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


13805
13806
13807
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13805

def subaccount_id
  @subaccount_id
end

#technology_targetingGoogle::Apis::DfareportingV4::TechnologyTargeting

Technology Targeting. Corresponds to the JSON property technologyTargeting



13810
13811
13812
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13810

def technology_targeting
  @technology_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13817
13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
13829
13830
13831
13832
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13817

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value)
  @contextual_keyword_targeting = args[:contextual_keyword_targeting] if args.key?(:contextual_keyword_targeting)
  @day_part_targeting = args[:day_part_targeting] if args.key?(:day_part_targeting)
  @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting)
  @id = args[:id] if args.key?(:id)
  @key_value_targeting_expression = args[:key_value_targeting_expression] if args.key?(:key_value_targeting_expression)
  @kind = args[:kind] if args.key?(:kind)
  @language_targeting = args[:language_targeting] if args.key?(:language_targeting)
  @list_targeting_expression = args[:list_targeting_expression] if args.key?(:list_targeting_expression)
  @name = args[:name] if args.key?(:name)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @technology_targeting = args[:technology_targeting] if args.key?(:technology_targeting)
end