Class: Google::Apis::DfareportingV4::TvCampaignTimepoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb

Overview

A single data point for TvCampaignDetail, which holds information about the TV campaign for a specific start date and date window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TvCampaignTimepoint

Returns a new instance of TvCampaignTimepoint.



14161
14162
14163
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_windowString

The date window of the timepoint. Corresponds to the JSON property dateWindow

Returns:

  • (String)


14149
14150
14151
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14149

def date_window
  @date_window
end

#spendFloat

The spend within the time range of the timepoint. Corresponds to the JSON property spend

Returns:

  • (Float)


14154
14155
14156
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14154

def spend
  @spend
end

#start_dateString

The start date of the timepoint. A string in the format of "yyyy-MM-dd". Corresponds to the JSON property startDate

Returns:

  • (String)


14159
14160
14161
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14159

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14166
14167
14168
14169
14170
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14166

def update!(**args)
  @date_window = args[:date_window] if args.key?(:date_window)
  @spend = args[:spend] if args.key?(:spend)
  @start_date = args[:start_date] if args.key?(:start_date)
end