Class: Google::Apis::DfareportingV4::UserRolePermission
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::UserRolePermission
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains properties of a user role permission.
Instance Attribute Summary collapse
-
#availability ⇒ String
Levels of availability for a user role permission.
-
#id ⇒ Fixnum
ID of this user role permission.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this user role permission.
-
#permission_group_id ⇒ Fixnum
ID of the permission group that this user role permission belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserRolePermission
constructor
A new instance of UserRolePermission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserRolePermission
Returns a new instance of UserRolePermission.
14463 14464 14465 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability ⇒ String
Levels of availability for a user role permission.
Corresponds to the JSON property availability
14440 14441 14442 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14440 def availability @availability end |
#id ⇒ Fixnum
ID of this user role permission.
Corresponds to the JSON property id
14445 14446 14447 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14445 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#userRolePermission".
Corresponds to the JSON property kind
14451 14452 14453 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14451 def kind @kind end |
#name ⇒ String
Name of this user role permission.
Corresponds to the JSON property name
14456 14457 14458 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14456 def name @name end |
#permission_group_id ⇒ Fixnum
ID of the permission group that this user role permission belongs to.
Corresponds to the JSON property permissionGroupId
14461 14462 14463 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14461 def @permission_group_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14468 14469 14470 14471 14472 14473 14474 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14468 def update!(**args) @availability = args[:availability] if args.key?(:availability) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @permission_group_id = args[:permission_group_id] if args.key?(:permission_group_id) end |