Class: Google::Apis::DfareportingV4::UserRolesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::UserRolesListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
User Role List Response
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
-
#user_roles ⇒ Array<Google::Apis::DfareportingV4::UserRole>
User role collection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserRolesListResponse
constructor
A new instance of UserRolesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserRolesListResponse
Returns a new instance of UserRolesListResponse.
14581 14582 14583 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14581 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#userRolesListResponse".
Corresponds to the JSON property kind
14569 14570 14571 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14569 def kind @kind end |
#next_page_token ⇒ String
Pagination token to be used for the next list operation.
Corresponds to the JSON property nextPageToken
14574 14575 14576 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14574 def next_page_token @next_page_token end |
#user_roles ⇒ Array<Google::Apis::DfareportingV4::UserRole>
User role collection.
Corresponds to the JSON property userRoles
14579 14580 14581 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14579 def user_roles @user_roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14586 14587 14588 14589 14590 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14586 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @user_roles = args[:user_roles] if args.key?(:user_roles) end |