Class: Google::Apis::DfareportingV4::VideoFormat
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::VideoFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains information about supported video formats.
Instance Attribute Summary collapse
-
#file_type ⇒ String
File type of the video format.
-
#id ⇒ Fixnum
ID of the video format.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#resolution ⇒ Google::Apis::DfareportingV4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#target_bit_rate ⇒ Fixnum
The target bit rate of this video format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoFormat
constructor
A new instance of VideoFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoFormat
Returns a new instance of VideoFormat.
14623 14624 14625 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_type ⇒ String
File type of the video format.
Corresponds to the JSON property fileType
14600 14601 14602 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14600 def file_type @file_type end |
#id ⇒ Fixnum
ID of the video format.
Corresponds to the JSON property id
14605 14606 14607 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14605 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#videoFormat".
Corresponds to the JSON property kind
14611 14612 14613 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14611 def kind @kind end |
#resolution ⇒ Google::Apis::DfareportingV4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property resolution
14616 14617 14618 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14616 def resolution @resolution end |
#target_bit_rate ⇒ Fixnum
The target bit rate of this video format.
Corresponds to the JSON property targetBitRate
14621 14622 14623 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14621 def target_bit_rate @target_bit_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14628 14629 14630 14631 14632 14633 14634 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14628 def update!(**args) @file_type = args[:file_type] if args.key?(:file_type) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @resolution = args[:resolution] if args.key?(:resolution) @target_bit_rate = args[:target_bit_rate] if args.key?(:target_bit_rate) end |