Class: Google::Apis::DfareportingV4::ChangeLog
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::ChangeLog
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Describes a change that a user has made to a resource.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of the modified object.
-
#action ⇒ String
Action which caused the change.
-
#change_time ⇒ DateTime
Corresponds to the JSON property
changeTime. -
#field_name ⇒ String
Field name of the object which changed.
-
#id ⇒ Fixnum
ID of this change log.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#new_value ⇒ String
New value of the object field.
-
#object_id_prop ⇒ Fixnum
ID of the object of this change log.
-
#object_type ⇒ String
Object type of the change log.
-
#old_value ⇒ String
Old value of the object field.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of the modified object.
-
#transaction_id ⇒ Fixnum
Transaction ID of this change log.
-
#user_profile_id ⇒ Fixnum
ID of the user who modified the object.
-
#user_profile_name ⇒ String
User profile name of the user who modified the object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChangeLog
constructor
A new instance of ChangeLog.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChangeLog
Returns a new instance of ChangeLog.
2266 2267 2268 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of the modified object.
Corresponds to the JSON property accountId
2195 2196 2197 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2195 def account_id @account_id end |
#action ⇒ String
Action which caused the change.
Corresponds to the JSON property action
2200 2201 2202 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2200 def action @action end |
#change_time ⇒ DateTime
Corresponds to the JSON property changeTime
2205 2206 2207 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2205 def change_time @change_time end |
#field_name ⇒ String
Field name of the object which changed.
Corresponds to the JSON property fieldName
2210 2211 2212 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2210 def field_name @field_name end |
#id ⇒ Fixnum
ID of this change log.
Corresponds to the JSON property id
2215 2216 2217 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2215 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#changeLog".
Corresponds to the JSON property kind
2221 2222 2223 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2221 def kind @kind end |
#new_value ⇒ String
New value of the object field.
Corresponds to the JSON property newValue
2226 2227 2228 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2226 def new_value @new_value end |
#object_id_prop ⇒ Fixnum
ID of the object of this change log. The object could be a campaign, placement,
ad, or other type.
Corresponds to the JSON property objectId
2232 2233 2234 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2232 def object_id_prop @object_id_prop end |
#object_type ⇒ String
Object type of the change log.
Corresponds to the JSON property objectType
2237 2238 2239 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2237 def object_type @object_type end |
#old_value ⇒ String
Old value of the object field.
Corresponds to the JSON property oldValue
2242 2243 2244 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2242 def old_value @old_value end |
#subaccount_id ⇒ Fixnum
Subaccount ID of the modified object.
Corresponds to the JSON property subaccountId
2247 2248 2249 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2247 def subaccount_id @subaccount_id end |
#transaction_id ⇒ Fixnum
Transaction ID of this change log. When a single API call results in many
changes, each change will have a separate ID in the change log but will share
the same transactionId.
Corresponds to the JSON property transactionId
2254 2255 2256 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2254 def transaction_id @transaction_id end |
#user_profile_id ⇒ Fixnum
ID of the user who modified the object.
Corresponds to the JSON property userProfileId
2259 2260 2261 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2259 def user_profile_id @user_profile_id end |
#user_profile_name ⇒ String
User profile name of the user who modified the object.
Corresponds to the JSON property userProfileName
2264 2265 2266 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2264 def user_profile_name @user_profile_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 2271 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @action = args[:action] if args.key?(:action) @change_time = args[:change_time] if args.key?(:change_time) @field_name = args[:field_name] if args.key?(:field_name) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @new_value = args[:new_value] if args.key?(:new_value) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @object_type = args[:object_type] if args.key?(:object_type) @old_value = args[:old_value] if args.key?(:old_value) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) @transaction_id = args[:transaction_id] if args.key?(:transaction_id) @user_profile_id = args[:user_profile_id] if args.key?(:user_profile_id) @user_profile_name = args[:user_profile_name] if args.key?(:user_profile_name) end |