Class: Google::Apis::DfareportingV4::CrossDimensionReachReportCompatibleFields
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::CrossDimensionReachReportCompatibleFields
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Represents fields that are compatible to be selected for a report of type " CROSS_DIMENSION_REACH".
Instance Attribute Summary collapse
-
#breakdown ⇒ Array<Google::Apis::DfareportingV4::Dimension>
Dimensions which are compatible to be selected in the "breakdown" section of the report.
-
#dimension_filters ⇒ Array<Google::Apis::DfareportingV4::Dimension>
Dimensions which are compatible to be selected in the "dimensionFilters" section of the report.
-
#kind ⇒ String
The kind of resource this is, in this case dfareporting# crossDimensionReachReportCompatibleFields.
-
#metrics ⇒ Array<Google::Apis::DfareportingV4::Metric>
Metrics which are compatible to be selected in the "metricNames" section of the report.
-
#overlap_metrics ⇒ Array<Google::Apis::DfareportingV4::Metric>
Metrics which are compatible to be selected in the "overlapMetricNames" section of the report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrossDimensionReachReportCompatibleFields
constructor
A new instance of CrossDimensionReachReportCompatibleFields.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrossDimensionReachReportCompatibleFields
Returns a new instance of CrossDimensionReachReportCompatibleFields.
5160 5161 5162 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#breakdown ⇒ Array<Google::Apis::DfareportingV4::Dimension>
Dimensions which are compatible to be selected in the "breakdown" section of
the report.
Corresponds to the JSON property breakdown
5134 5135 5136 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5134 def breakdown @breakdown end |
#dimension_filters ⇒ Array<Google::Apis::DfareportingV4::Dimension>
Dimensions which are compatible to be selected in the "dimensionFilters"
section of the report.
Corresponds to the JSON property dimensionFilters
5140 5141 5142 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5140 def dimension_filters @dimension_filters end |
#kind ⇒ String
The kind of resource this is, in this case dfareporting#
crossDimensionReachReportCompatibleFields.
Corresponds to the JSON property kind
5146 5147 5148 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5146 def kind @kind end |
#metrics ⇒ Array<Google::Apis::DfareportingV4::Metric>
Metrics which are compatible to be selected in the "metricNames" section of
the report.
Corresponds to the JSON property metrics
5152 5153 5154 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5152 def metrics @metrics end |
#overlap_metrics ⇒ Array<Google::Apis::DfareportingV4::Metric>
Metrics which are compatible to be selected in the "overlapMetricNames"
section of the report.
Corresponds to the JSON property overlapMetrics
5158 5159 5160 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5158 def overlap_metrics @overlap_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5165 def update!(**args) @breakdown = args[:breakdown] if args.key?(:breakdown) @dimension_filters = args[:dimension_filters] if args.key?(:dimension_filters) @kind = args[:kind] if args.key?(:kind) @metrics = args[:metrics] if args.key?(:metrics) @overlap_metrics = args[:overlap_metrics] if args.key?(:overlap_metrics) end |