Class: Google::Apis::DfareportingV4::DayPartTargeting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::DayPartTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Day Part Targeting.
Instance Attribute Summary collapse
-
#days_of_week ⇒ Array<String>
Days of the week when the ad will serve.
-
#hours_of_day ⇒ Array<Fixnum>
Hours of the day when the ad will serve, where 0 is midnight to 1 AM and 23 is 11 PM to midnight.
-
#user_local_time ⇒ Boolean
(also: #user_local_time?)
Whether or not to use the user's local time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DayPartTargeting
constructor
A new instance of DayPartTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DayPartTargeting
Returns a new instance of DayPartTargeting.
5474 5475 5476 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#days_of_week ⇒ Array<String>
Days of the week when the ad will serve. Acceptable values are: - "SUNDAY" - "
MONDAY" - "TUESDAY" - "WEDNESDAY" - "THURSDAY" - "FRIDAY" - "SATURDAY"
Corresponds to the JSON property daysOfWeek
5455 5456 5457 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5455 def days_of_week @days_of_week end |
#hours_of_day ⇒ Array<Fixnum>
Hours of the day when the ad will serve, where 0 is midnight to 1 AM and 23 is
11 PM to midnight. Can be specified with days of week, in which case the ad
would serve during these hours on the specified days. For example if Monday,
Wednesday, Friday are the days of week specified and 9-10am, 3-5pm (hours 9,
15, and 16) is specified, the ad would serve Monday, Wednesdays, and Fridays
at 9-10am and 3-5pm. Acceptable values are 0 to 23, inclusive.
Corresponds to the JSON property hoursOfDay
5465 5466 5467 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5465 def hours_of_day @hours_of_day end |
#user_local_time ⇒ Boolean Also known as: user_local_time?
Whether or not to use the user's local time. If false, the America/New York
time zone applies.
Corresponds to the JSON property userLocalTime
5471 5472 5473 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5471 def user_local_time @user_local_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5479 5480 5481 5482 5483 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 5479 def update!(**args) @days_of_week = args[:days_of_week] if args.key?(:days_of_week) @hours_of_day = args[:hours_of_day] if args.key?(:hours_of_day) @user_local_time = args[:user_local_time] if args.key?(:user_local_time) end |