Class: Google::Apis::DfareportingV4::FeedField
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::FeedField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Each field of the element. This is a required field.
Instance Attribute Summary collapse
-
#default_value ⇒ String
Optional.
-
#filterable ⇒ Boolean
(also: #filterable?)
Optional.
-
#id ⇒ Fixnum
Required.
-
#name ⇒ String
Required.
-
#renderable ⇒ Boolean
(also: #renderable?)
Optional.
-
#required ⇒ Boolean
(also: #required?)
Optional.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FeedField
constructor
A new instance of FeedField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FeedField
Returns a new instance of FeedField.
6867 6868 6869 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ String
Optional. The default value of the field.
Corresponds to the JSON property defaultValue
6819 6820 6821 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6819 def default_value @default_value end |
#filterable ⇒ Boolean Also known as: filterable?
Optional. Whether the field is filterable. Could be set as true when the field
type is any of the following and is not renderable: - STRING - BOOL -
COUNTRY_CODE_ISO - CM360_SITE_ID - CM360_KEYWORD - CM360_CREATIVE_ID -
CM360_PLACEMENT_ID - CM360_AD_ID - CM360_ADVERTISER_ID - CM360_CAMPAIGN_ID -
CITY - REGION - POSTAL_CODE - METRO - CUSTOM_VALUE - REMARKETING_VALUE -
GEO_CANONICAL - STRING_LIST - CREATIVE_DIMENSION - USERLIST_ID -
CM360_DYNAMIC_TARGETING_KEY - DV360_LINE_ITEM_ID
Corresponds to the JSON property filterable
6830 6831 6832 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6830 def filterable @filterable end |
#id ⇒ Fixnum
Required. The ID of the field. The ID is based on the column index starting
from 0, and it should match the column index in the resource link.
Corresponds to the JSON property id
6837 6838 6839 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6837 def id @id end |
#name ⇒ String
Required. The name of the field.
Corresponds to the JSON property name
6842 6843 6844 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6842 def name @name end |
#renderable ⇒ Boolean Also known as: renderable?
Optional. Whether the field is able to display. Could be set as true when the
field type is not in any of the following and the field is not filterable: -
COUNTRY_CODE_ISO - CITY - REGION - POSTAL_CODE - METRO - GEO_CANONICAL -
USERLIST_ID - CONTEXTUAL_KEYWORD - CM360_DYNAMIC_TARGETING_KEY - WEIGHT
Corresponds to the JSON property renderable
6850 6851 6852 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6850 def renderable @renderable end |
#required ⇒ Boolean Also known as: required?
Optional. Whether the field is required and should not be empty in the feed.
Could be set as true when the field type is any of the following: -
GPA_SERVED_IMAGE_URL - GPA_SERVED_ASSET_URL - ASSET_LIBRARY_HANDLE -
ASSET_LIBRARY_VIDEO_HANDLE - ASSET_LIBRARY_DIRECTORY_HANDLE
Corresponds to the JSON property required
6859 6860 6861 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6859 def required @required end |
#type ⇒ String
Required. The type of the field.
Corresponds to the JSON property type
6865 6866 6867 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6865 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6872 6873 6874 6875 6876 6877 6878 6879 6880 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6872 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @filterable = args[:filterable] if args.key?(:filterable) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @renderable = args[:renderable] if args.key?(:renderable) @required = args[:required] if args.key?(:required) @type = args[:type] if args.key?(:type) end |