Class: Google::Apis::DfareportingV4::FeedIngestionStatus
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::FeedIngestionStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains the ingestion status of the dynamic feed. Feed ingestion is an asynchronous process. If the feed create request is successful, feed ingestion will be processed in the background, including validation, assets retrieval, and saving the data from the resource link. The processing time is dependent on the data size in the resource link. This read-only status field contains the current stage of that processing and its ingestion state.
Instance Attribute Summary collapse
-
#ingestion_error_records ⇒ Array<Google::Apis::DfareportingV4::IngestionErrorRecord>
Output only.
-
#ingestion_status ⇒ Google::Apis::DfareportingV4::IngestionStatus
Contains the ingestion status of the dynamic feed.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FeedIngestionStatus
constructor
A new instance of FeedIngestionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FeedIngestionStatus
Returns a new instance of FeedIngestionStatus.
6907 6908 6909 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6907 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ingestion_error_records ⇒ Array<Google::Apis::DfareportingV4::IngestionErrorRecord>
Output only. The ingestion error records of the feed.
Corresponds to the JSON property ingestionErrorRecords
6895 6896 6897 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6895 def ingestion_error_records @ingestion_error_records end |
#ingestion_status ⇒ Google::Apis::DfareportingV4::IngestionStatus
Contains the ingestion status of the dynamic feed.
Corresponds to the JSON property ingestionStatus
6900 6901 6902 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6900 def ingestion_status @ingestion_status end |
#state ⇒ String
Output only. The processing state of the feed.
Corresponds to the JSON property state
6905 6906 6907 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6905 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6912 6913 6914 6915 6916 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 6912 def update!(**args) @ingestion_error_records = args[:ingestion_error_records] if args.key?(:ingestion_error_records) @ingestion_status = args[:ingestion_status] if args.key?(:ingestion_status) @state = args[:state] if args.key?(:state) end |