Class: Google::Apis::DfareportingV4::IngestionErrorRecord
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::IngestionErrorRecord
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains the ingestion error record of the dynamic feed. limited to 100 records.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::DfareportingV4::FieldError>
Output only.
-
#record_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngestionErrorRecord
constructor
A new instance of IngestionErrorRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngestionErrorRecord
Returns a new instance of IngestionErrorRecord.
8098 8099 8100 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::DfareportingV4::FieldError>
Output only. The list of field errors of the ingestion error record.
Corresponds to the JSON property errors
8091 8092 8093 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8091 def errors @errors end |
#record_id ⇒ String
Output only. The record ID of the ingestion error record.
Corresponds to the JSON property recordId
8096 8097 8098 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8096 def record_id @record_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8103 8104 8105 8106 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8103 def update!(**args) @errors = args[:errors] if args.key?(:errors) @record_id = args[:record_id] if args.key?(:record_id) end |