Class: Google::Apis::DfareportingV4::InventoryItem
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::InventoryItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Represents a buy from the Planning inventory store.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this inventory item.
-
#ad_slots ⇒ Array<Google::Apis::DfareportingV4::AdSlot>
Ad slots of this inventory item.
-
#advertiser_id ⇒ Fixnum
Advertiser ID of this inventory item.
-
#content_category_id ⇒ Fixnum
Content category ID of this inventory item.
-
#estimated_click_through_rate ⇒ Fixnum
Estimated click-through rate of this inventory item.
-
#estimated_conversion_rate ⇒ Fixnum
Estimated conversion rate of this inventory item.
-
#id ⇒ Fixnum
ID of this inventory item.
-
#in_plan ⇒ Boolean
(also: #in_plan?)
Whether this inventory item is in plan.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#last_modified_info ⇒ Google::Apis::DfareportingV4::LastModifiedInfo
Modification timestamp.
-
#name ⇒ String
Name of this inventory item.
-
#negotiation_channel_id ⇒ Fixnum
Negotiation channel ID of this inventory item.
-
#order_id ⇒ Fixnum
Order ID of this inventory item.
-
#placement_strategy_id ⇒ Fixnum
Placement strategy ID of this inventory item.
-
#pricing ⇒ Google::Apis::DfareportingV4::Pricing
Pricing of this inventory item.
-
#project_id ⇒ Fixnum
Project ID of this inventory item.
-
#rfp_id ⇒ Fixnum
RFP ID of this inventory item.
-
#site_id ⇒ Fixnum
ID of the site this inventory item is associated with.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this inventory item.
-
#type ⇒ String
Type of inventory item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InventoryItem
constructor
A new instance of InventoryItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InventoryItem
Returns a new instance of InventoryItem.
8263 8264 8265 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8263 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this inventory item.
Corresponds to the JSON property accountId
8159 8160 8161 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8159 def account_id @account_id end |
#ad_slots ⇒ Array<Google::Apis::DfareportingV4::AdSlot>
Ad slots of this inventory item. If this inventory item represents a
standalone placement, there will be exactly one ad slot. If this inventory
item represents a placement group, there will be more than one ad slot, each
representing one child placement in that placement group.
Corresponds to the JSON property adSlots
8167 8168 8169 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8167 def ad_slots @ad_slots end |
#advertiser_id ⇒ Fixnum
Advertiser ID of this inventory item.
Corresponds to the JSON property advertiserId
8172 8173 8174 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8172 def advertiser_id @advertiser_id end |
#content_category_id ⇒ Fixnum
Content category ID of this inventory item.
Corresponds to the JSON property contentCategoryId
8177 8178 8179 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8177 def content_category_id @content_category_id end |
#estimated_click_through_rate ⇒ Fixnum
Estimated click-through rate of this inventory item.
Corresponds to the JSON property estimatedClickThroughRate
8182 8183 8184 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8182 def estimated_click_through_rate @estimated_click_through_rate end |
#estimated_conversion_rate ⇒ Fixnum
Estimated conversion rate of this inventory item.
Corresponds to the JSON property estimatedConversionRate
8187 8188 8189 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8187 def estimated_conversion_rate @estimated_conversion_rate end |
#id ⇒ Fixnum
ID of this inventory item.
Corresponds to the JSON property id
8192 8193 8194 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8192 def id @id end |
#in_plan ⇒ Boolean Also known as: in_plan?
Whether this inventory item is in plan.
Corresponds to the JSON property inPlan
8197 8198 8199 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8197 def in_plan @in_plan end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#inventoryItem".
Corresponds to the JSON property kind
8204 8205 8206 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8204 def kind @kind end |
#last_modified_info ⇒ Google::Apis::DfareportingV4::LastModifiedInfo
Modification timestamp.
Corresponds to the JSON property lastModifiedInfo
8209 8210 8211 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8209 def last_modified_info @last_modified_info end |
#name ⇒ String
Name of this inventory item. For standalone inventory items, this is the same
name as that of its only ad slot. For group inventory items, this can differ
from the name of any of its ad slots.
Corresponds to the JSON property name
8216 8217 8218 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8216 def name @name end |
#negotiation_channel_id ⇒ Fixnum
Negotiation channel ID of this inventory item.
Corresponds to the JSON property negotiationChannelId
8221 8222 8223 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8221 def negotiation_channel_id @negotiation_channel_id end |
#order_id ⇒ Fixnum
Order ID of this inventory item.
Corresponds to the JSON property orderId
8226 8227 8228 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8226 def order_id @order_id end |
#placement_strategy_id ⇒ Fixnum
Placement strategy ID of this inventory item.
Corresponds to the JSON property placementStrategyId
8231 8232 8233 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8231 def placement_strategy_id @placement_strategy_id end |
#pricing ⇒ Google::Apis::DfareportingV4::Pricing
Pricing of this inventory item.
Corresponds to the JSON property pricing
8236 8237 8238 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8236 def pricing @pricing end |
#project_id ⇒ Fixnum
Project ID of this inventory item.
Corresponds to the JSON property projectId
8241 8242 8243 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8241 def project_id @project_id end |
#rfp_id ⇒ Fixnum
RFP ID of this inventory item.
Corresponds to the JSON property rfpId
8246 8247 8248 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8246 def rfp_id @rfp_id end |
#site_id ⇒ Fixnum
ID of the site this inventory item is associated with.
Corresponds to the JSON property siteId
8251 8252 8253 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8251 def site_id @site_id end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this inventory item.
Corresponds to the JSON property subaccountId
8256 8257 8258 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8256 def subaccount_id @subaccount_id end |
#type ⇒ String
Type of inventory item.
Corresponds to the JSON property type
8261 8262 8263 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8261 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8268 8269 8270 8271 8272 8273 8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 8268 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @ad_slots = args[:ad_slots] if args.key?(:ad_slots) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @content_category_id = args[:content_category_id] if args.key?(:content_category_id) @estimated_click_through_rate = args[:estimated_click_through_rate] if args.key?(:estimated_click_through_rate) @estimated_conversion_rate = args[:estimated_conversion_rate] if args.key?(:estimated_conversion_rate) @id = args[:id] if args.key?(:id) @in_plan = args[:in_plan] if args.key?(:in_plan) @kind = args[:kind] if args.key?(:kind) @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info) @name = args[:name] if args.key?(:name) @negotiation_channel_id = args[:negotiation_channel_id] if args.key?(:negotiation_channel_id) @order_id = args[:order_id] if args.key?(:order_id) @placement_strategy_id = args[:placement_strategy_id] if args.key?(:placement_strategy_id) @pricing = args[:pricing] if args.key?(:pricing) @project_id = args[:project_id] if args.key?(:project_id) @rfp_id = args[:rfp_id] if args.key?(:rfp_id) @site_id = args[:site_id] if args.key?(:site_id) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) @type = args[:type] if args.key?(:type) end |