Class: Google::Apis::DfareportingV4::OfflineUserAddressInfo
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::OfflineUserAddressInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Identify a user by name and address.
Instance Attribute Summary collapse
-
#city ⇒ String
City of the address.
-
#country_code ⇒ String
2-letter country code in ISO-3166-1 alpha-2 of the user's address.
-
#hashed_first_name ⇒ String
First name of the user, which is hashed as SHA-256 after normalized (Lowercase all characters; Remove any extra spaces before, after, and in between).
-
#hashed_last_name ⇒ String
Last name of the user, which is hashed as SHA-256 after normalized (lower case only and no punctuation).
-
#hashed_street_address ⇒ String
The street address of the user hashed using SHA-256 hash function after normalization (lower case only).
-
#postal_code ⇒ String
Postal code of the user's address.
-
#state ⇒ String
State code of the address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OfflineUserAddressInfo
constructor
A new instance of OfflineUserAddressInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OfflineUserAddressInfo
Returns a new instance of OfflineUserAddressInfo.
9315 9316 9317 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#city ⇒ String
City of the address.
Corresponds to the JSON property city
9280 9281 9282 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9280 def city @city end |
#country_code ⇒ String
2-letter country code in ISO-3166-1 alpha-2 of the user's address.
Corresponds to the JSON property countryCode
9285 9286 9287 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9285 def country_code @country_code end |
#hashed_first_name ⇒ String
First name of the user, which is hashed as SHA-256 after normalized (Lowercase
all characters; Remove any extra spaces before, after, and in between).
Corresponds to the JSON property hashedFirstName
9291 9292 9293 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9291 def hashed_first_name @hashed_first_name end |
#hashed_last_name ⇒ String
Last name of the user, which is hashed as SHA-256 after normalized (lower case
only and no punctuation).
Corresponds to the JSON property hashedLastName
9297 9298 9299 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9297 def hashed_last_name @hashed_last_name end |
#hashed_street_address ⇒ String
The street address of the user hashed using SHA-256 hash function after
normalization (lower case only).
Corresponds to the JSON property hashedStreetAddress
9303 9304 9305 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9303 def hashed_street_address @hashed_street_address end |
#postal_code ⇒ String
Postal code of the user's address.
Corresponds to the JSON property postalCode
9308 9309 9310 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9308 def postal_code @postal_code end |
#state ⇒ String
State code of the address.
Corresponds to the JSON property state
9313 9314 9315 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9313 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9320 9321 9322 9323 9324 9325 9326 9327 9328 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 9320 def update!(**args) @city = args[:city] if args.key?(:city) @country_code = args[:country_code] if args.key?(:country_code) @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name) @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name) @hashed_street_address = args[:hashed_street_address] if args.key?(:hashed_street_address) @postal_code = args[:postal_code] if args.key?(:postal_code) @state = args[:state] if args.key?(:state) end |