Class: Google::Apis::DfareportingV4::RemarketingList
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::RemarketingList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains properties of a remarketing list. Remarketing enables you to create lists of users who have performed specific actions on a site, then target ads to members of those lists. This resource can be used to manage remarketing lists that are owned by your advertisers. To see all remarketing lists that are visible to your advertisers, including those that are shared to your advertiser or account, use the TargetableRemarketingLists resource.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this remarketing list.
-
#active ⇒ Boolean
(also: #active?)
Whether this remarketing list is active.
-
#advertiser_id ⇒ Fixnum
Dimension value for the advertiser ID that owns this remarketing list.
-
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV4::DimensionValue
Represents a DimensionValue resource.
-
#description ⇒ String
Remarketing list description.
-
#id ⇒ Fixnum
Remarketing list ID.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#life_span ⇒ Fixnum
Number of days that a user should remain in the remarketing list without an impression.
-
#list_population_rule ⇒ Google::Apis::DfareportingV4::ListPopulationRule
Remarketing List Population Rule.
-
#list_size ⇒ Fixnum
Number of users currently in the list.
-
#list_source ⇒ String
Product from which this remarketing list was originated.
-
#name ⇒ String
Name of the remarketing list.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this remarketing list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemarketingList
constructor
A new instance of RemarketingList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemarketingList
Returns a new instance of RemarketingList.
11475 11476 11477 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11475 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this remarketing list. This is a read-only, auto-generated field
that is only returned in GET requests.
Corresponds to the JSON property accountId
11407 11408 11409 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11407 def account_id @account_id end |
#active ⇒ Boolean Also known as: active?
Whether this remarketing list is active.
Corresponds to the JSON property active
11412 11413 11414 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11412 def active @active end |
#advertiser_id ⇒ Fixnum
Dimension value for the advertiser ID that owns this remarketing list. This is
a required field.
Corresponds to the JSON property advertiserId
11419 11420 11421 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11419 def advertiser_id @advertiser_id end |
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV4::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property advertiserIdDimensionValue
11424 11425 11426 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11424 def advertiser_id_dimension_value @advertiser_id_dimension_value end |
#description ⇒ String
Remarketing list description.
Corresponds to the JSON property description
11429 11430 11431 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11429 def description @description end |
#id ⇒ Fixnum
Remarketing list ID. This is a read-only, auto-generated field.
Corresponds to the JSON property id
11434 11435 11436 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11434 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#remarketingList".
Corresponds to the JSON property kind
11440 11441 11442 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11440 def kind @kind end |
#life_span ⇒ Fixnum
Number of days that a user should remain in the remarketing list without an
impression. Acceptable values are 1 to 540, inclusive.
Corresponds to the JSON property lifeSpan
11446 11447 11448 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11446 def life_span @life_span end |
#list_population_rule ⇒ Google::Apis::DfareportingV4::ListPopulationRule
Remarketing List Population Rule.
Corresponds to the JSON property listPopulationRule
11451 11452 11453 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11451 def list_population_rule @list_population_rule end |
#list_size ⇒ Fixnum
Number of users currently in the list. This is a read-only field.
Corresponds to the JSON property listSize
11456 11457 11458 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11456 def list_size @list_size end |
#list_source ⇒ String
Product from which this remarketing list was originated.
Corresponds to the JSON property listSource
11461 11462 11463 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11461 def list_source @list_source end |
#name ⇒ String
Name of the remarketing list. This is a required field. Must be no greater
than 128 characters long.
Corresponds to the JSON property name
11467 11468 11469 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11467 def name @name end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this remarketing list. This is a read-only, auto-generated
field that is only returned in GET requests.
Corresponds to the JSON property subaccountId
11473 11474 11475 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11473 def subaccount_id @subaccount_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11480 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @active = args[:active] if args.key?(:active) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @life_span = args[:life_span] if args.key?(:life_span) @list_population_rule = args[:list_population_rule] if args.key?(:list_population_rule) @list_size = args[:list_size] if args.key?(:list_size) @list_source = args[:list_source] if args.key?(:list_source) @name = args[:name] if args.key?(:name) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) end |