Class: Google::Apis::DfareportingV4::RemarketingListShare
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::RemarketingListShare
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Contains properties of a remarketing list's sharing information. Sharing allows other accounts or advertisers to target to your remarketing lists. This resource can be used to manage remarketing list sharing to other accounts and advertisers.
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#remarketing_list_id ⇒ Fixnum
Remarketing list ID.
-
#shared_account_ids ⇒ Array<Fixnum>
Accounts that the remarketing list is shared with.
-
#shared_advertiser_ids ⇒ Array<Fixnum>
Advertisers that the remarketing list is shared with.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemarketingListShare
constructor
A new instance of RemarketingListShare.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemarketingListShare
Returns a new instance of RemarketingListShare.
11525 11526 11527 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11525 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#remarketingListShare".
Corresponds to the JSON property kind
11508 11509 11510 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11508 def kind @kind end |
#remarketing_list_id ⇒ Fixnum
Remarketing list ID. This is a read-only, auto-generated field.
Corresponds to the JSON property remarketingListId
11513 11514 11515 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11513 def remarketing_list_id @remarketing_list_id end |
#shared_account_ids ⇒ Array<Fixnum>
Accounts that the remarketing list is shared with.
Corresponds to the JSON property sharedAccountIds
11518 11519 11520 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11518 def shared_account_ids @shared_account_ids end |
#shared_advertiser_ids ⇒ Array<Fixnum>
Advertisers that the remarketing list is shared with.
Corresponds to the JSON property sharedAdvertiserIds
11523 11524 11525 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11523 def shared_advertiser_ids @shared_advertiser_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11530 11531 11532 11533 11534 11535 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 11530 def update!(**args) @kind = args[:kind] if args.key?(:kind) @remarketing_list_id = args[:remarketing_list_id] if args.key?(:remarketing_list_id) @shared_account_ids = args[:shared_account_ids] if args.key?(:shared_account_ids) @shared_advertiser_ids = args[:shared_advertiser_ids] if args.key?(:shared_advertiser_ids) end |