Class: Google::Apis::DfareportingV4::ReportList
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::ReportList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Represents the list of reports.
Instance Attribute Summary collapse
-
#etag ⇒ String
The eTag of this response for caching purposes.
-
#items ⇒ Array<Google::Apis::DfareportingV4::Report>
The reports returned in this response.
-
#kind ⇒ String
The kind of list this is, in this case dfareporting#reportList.
-
#next_page_token ⇒ String
Continuation token used to page through reports.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportList
constructor
A new instance of ReportList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportList
Returns a new instance of ReportList.
12372 12373 12374 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
The eTag of this response for caching purposes.
Corresponds to the JSON property etag
12352 12353 12354 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12352 def etag @etag end |
#items ⇒ Array<Google::Apis::DfareportingV4::Report>
The reports returned in this response.
Corresponds to the JSON property items
12357 12358 12359 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12357 def items @items end |
#kind ⇒ String
The kind of list this is, in this case dfareporting#reportList.
Corresponds to the JSON property kind
12362 12363 12364 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12362 def kind @kind end |
#next_page_token ⇒ String
Continuation token used to page through reports. To retrieve the next page of
results, set the next request's "pageToken" to the value of this field. The
page token is only valid for a limited amount of time and should not be
persisted.
Corresponds to the JSON property nextPageToken
12370 12371 12372 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12370 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12377 12378 12379 12380 12381 12382 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12377 def update!(**args) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |