Class: Google::Apis::DfareportingV4::SiteCompanionSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::SiteCompanionSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Companion Settings
Instance Attribute Summary collapse
-
#companions_disabled ⇒ Boolean
(also: #companions_disabled?)
Whether companions are disabled for this site template.
-
#enabled_sizes ⇒ Array<Google::Apis::DfareportingV4::Size>
Allowlist of companion sizes to be served via this site template.
-
#image_only ⇒ Boolean
(also: #image_only?)
Whether to serve only static images as companions.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SiteCompanionSetting
constructor
A new instance of SiteCompanionSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SiteCompanionSetting
Returns a new instance of SiteCompanionSetting.
12693 12694 12695 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#companions_disabled ⇒ Boolean Also known as: companions_disabled?
Whether companions are disabled for this site template.
Corresponds to the JSON property companionsDisabled
12672 12673 12674 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12672 def companions_disabled @companions_disabled end |
#enabled_sizes ⇒ Array<Google::Apis::DfareportingV4::Size>
Allowlist of companion sizes to be served via this site template. Set this
list to null or empty to serve all companion sizes.
Corresponds to the JSON property enabledSizes
12679 12680 12681 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12679 def enabled_sizes @enabled_sizes end |
#image_only ⇒ Boolean Also known as: image_only?
Whether to serve only static images as companions.
Corresponds to the JSON property imageOnly
12684 12685 12686 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12684 def image_only @image_only end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#siteCompanionSetting".
Corresponds to the JSON property kind
12691 12692 12693 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12691 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12698 12699 12700 12701 12702 12703 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 12698 def update!(**args) @companions_disabled = args[:companions_disabled] if args.key?(:companions_disabled) @enabled_sizes = args[:enabled_sizes] if args.key?(:enabled_sizes) @image_only = args[:image_only] if args.key?(:image_only) @kind = args[:kind] if args.key?(:kind) end |