Class: Google::Apis::DfareportingV4::TechnologyTargeting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::TechnologyTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Technology Targeting.
Instance Attribute Summary collapse
-
#browsers ⇒ Array<Google::Apis::DfareportingV4::Browser>
Browsers that this ad targets.
-
#connection_types ⇒ Array<Google::Apis::DfareportingV4::ConnectionType>
Connection types that this ad targets.
-
#mobile_carriers ⇒ Array<Google::Apis::DfareportingV4::MobileCarrier>
Mobile carriers that this ad targets.
-
#operating_system_versions ⇒ Array<Google::Apis::DfareportingV4::OperatingSystemVersion>
Operating system versions that this ad targets.
-
#operating_systems ⇒ Array<Google::Apis::DfareportingV4::OperatingSystem>
Operating systems that this ad targets.
-
#platform_types ⇒ Array<Google::Apis::DfareportingV4::PlatformType>
Platform types that this ad targets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TechnologyTargeting
constructor
A new instance of TechnologyTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TechnologyTargeting
Returns a new instance of TechnologyTargeting.
13919 13920 13921 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#browsers ⇒ Array<Google::Apis::DfareportingV4::Browser>
Browsers that this ad targets. For each browser either set browserVersionId or
dartId along with the version numbers. If both are specified, only
browserVersionId will be used. The other fields are populated automatically
when the ad is inserted or updated.
Corresponds to the JSON property browsers
13877 13878 13879 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13877 def browsers @browsers end |
#connection_types ⇒ Array<Google::Apis::DfareportingV4::ConnectionType>
Connection types that this ad targets. For each connection type only id is
required. The other fields are populated automatically when the ad is inserted
or updated.
Corresponds to the JSON property connectionTypes
13884 13885 13886 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13884 def connection_types @connection_types end |
#mobile_carriers ⇒ Array<Google::Apis::DfareportingV4::MobileCarrier>
Mobile carriers that this ad targets. For each mobile carrier only id is
required, and the other fields are populated automatically when the ad is
inserted or updated. If targeting a mobile carrier, do not set targeting for
any zip codes.
Corresponds to the JSON property mobileCarriers
13892 13893 13894 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13892 def mobile_carriers @mobile_carriers end |
#operating_system_versions ⇒ Array<Google::Apis::DfareportingV4::OperatingSystemVersion>
Operating system versions that this ad targets. To target all versions, use
operatingSystems. For each operating system version, only id is required. The
other fields are populated automatically when the ad is inserted or updated.
If targeting an operating system version, do not set targeting for the
corresponding operating system in operatingSystems.
Corresponds to the JSON property operatingSystemVersions
13901 13902 13903 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13901 def @operating_system_versions end |
#operating_systems ⇒ Array<Google::Apis::DfareportingV4::OperatingSystem>
Operating systems that this ad targets. To target specific versions, use
operatingSystemVersions. For each operating system only dartId is required.
The other fields are populated automatically when the ad is inserted or
updated. If targeting an operating system, do not set targeting for operating
system versions for the same operating system.
Corresponds to the JSON property operatingSystems
13910 13911 13912 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13910 def @operating_systems end |
#platform_types ⇒ Array<Google::Apis::DfareportingV4::PlatformType>
Platform types that this ad targets. For example, desktop, mobile, or tablet.
For each platform type, only id is required, and the other fields are
populated automatically when the ad is inserted or updated.
Corresponds to the JSON property platformTypes
13917 13918 13919 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13917 def platform_types @platform_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13924 13925 13926 13927 13928 13929 13930 13931 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13924 def update!(**args) @browsers = args[:browsers] if args.key?(:browsers) @connection_types = args[:connection_types] if args.key?(:connection_types) @mobile_carriers = args[:mobile_carriers] if args.key?(:mobile_carriers) @operating_system_versions = args[:operating_system_versions] if args.key?(:operating_system_versions) @operating_systems = args[:operating_systems] if args.key?(:operating_systems) @platform_types = args[:platform_types] if args.key?(:platform_types) end |