Class: Google::Apis::DfareportingV4::TranscodeSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV4::TranscodeSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v4/classes.rb,
lib/google/apis/dfareporting_v4/representations.rb,
lib/google/apis/dfareporting_v4/representations.rb
Overview
Transcode Settings
Instance Attribute Summary collapse
-
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this placement.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TranscodeSetting
constructor
A new instance of TranscodeSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TranscodeSetting
Returns a new instance of TranscodeSetting.
14001 14002 14003 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14001 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this placement. Set this list to
null or empty to serve all video formats.
Corresponds to the JSON property enabledVideoFormats
13993 13994 13995 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13993 def enabled_video_formats @enabled_video_formats end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#transcodeSetting".
Corresponds to the JSON property kind
13999 14000 14001 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 13999 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14006 14007 14008 14009 |
# File 'lib/google/apis/dfareporting_v4/classes.rb', line 14006 def update!(**args) @enabled_video_formats = args[:enabled_video_formats] if args.key?(:enabled_video_formats) @kind = args[:kind] if args.key?(:kind) end |